@@ -25,22 +25,15 @@
 //#
 //# $Id$
 
-#ifndef CASA_ARRAYLOGICAL_H
-#define CASA_ARRAYLOGICAL_H
+#ifndef CASA_ARRAYLOGICAL_2_H
+#define CASA_ARRAYLOGICAL_2_H
 
 //# Includes
-#include <casacore/casa/aips.h>
-#include <casacore/casa/Arrays/Array.h>
-#include <casacore/casa/Arrays/LogiArray.h>
-#include <casacore/casa/Arrays/ArrayMathBase.h>
+#include "ArrayFwd.h"
+#include "IPosition.h"
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
-//# Forward Declarations
-template <class T> class Vector;
-template <class T> class Matrix;
-template <class T> class Cube;
-
 // <summary>
 //    Logical operations for Arrays.
 // </summary>
@@ -58,15 +51,15 @@ template <class T> class Cube;
 // <synopsis>
 // These functions perform element by element logical operations on
 // arrays.  The two arrays must conform, except for allEQ which returns
-// False if the arrays do not conform.
+// false if the arrays do not conform.
 //
 // There are two classes of functions.  One class returns a LogicalArray.
 // In these functions, the value of an element of the LogicalArray is
 // the value of the logical operation applied to the corresponding elements
 // of the input Arrays.  The other class of functions returns a single
-// Bool.  The return value is True if the logical operation returns True for
+// bool.  The return value is true if the logical operation returns true for
 // all elements of the input arrays for the "all" functions
-// (e.g. allLE()), and returns True if the logical operation returns True for
+// (e.g. allLE()), and returns true if the logical operation returns true for
 // any elements of the input arrays for the "any" functions
 // (e.g. anyLE()).
 //
@@ -82,8 +75,8 @@ template <class T> class Cube;
 //
 // <example>
 // <srcblock>
-//   Vector<Int> a(10);
-//   Vector<Int> b(10);
+//   Vector<int> a(10);
+//   Vector<int> b(10);
 //   LogicalVector l(10);
 //      . . .
 //   l = a < b;
@@ -94,13 +87,13 @@ template <class T> class Cube;
 //
 // <example>
 // <srcblock>
-//   Vector<Int> a(10);
-//   Vector<Int> b(10);
-//   Bool result;
+//   Vector<int> a(10);
+//   Vector<int> b(10);
+//   bool result;
 //      . . .
 //   result = allLT (a, b);
 // </srcblock>
-// This example sets result to True if, for all elements, a<b.
+// This example sets result to true if, for all elements, a<b.
 // </example>
 //
 // <motivation>
@@ -119,7 +112,7 @@ template <class T> class Cube;
 // <group name="Array logical operations">
 
 
-// Determine if the comparisons between corresponding array elements yield True.
+// Determine if the comparisons between corresponding array elements yield true.
 // <group>
 template<typename T, typename CompareOperator>
 bool arrayCompareAll (const Array<T>& left, const Array<T>& right,
@@ -132,7 +125,7 @@ bool arrayCompareAll (T left, const Array<T>& right,
                       CompareOperator op);
 // </group>
 
-// Determine if the comparisons between corresponding array elements yield True.
+// Determine if the comparisons between corresponding array elements yield true.
 // <group>
 template<typename T, typename CompareOperator>
 bool arrayCompareAny (const Array<T>& left, const Array<T>& right,
@@ -149,11 +142,11 @@ bool arrayCompareAny (T left, const Array<T>& right,
 // Element by element comparisons between the "l" and "r" arrays. The result
 // is true only if the comparison is true for every element of the arrays.
 //
-// The operator forms of array logical operations which return a single Bool
+// The operator forms of array logical operations which return a single bool
 // have been replaced by these "all" functions.
 // The operator forms of array logical operations now return a LogicalArray.
 //
-// The arrays must conform except for allEQ, which will return False if the
+// The arrays must conform except for allEQ, which will return false if the
 // arrays have different shapes.
 //
 // <thrown>
@@ -161,21 +154,21 @@ bool arrayCompareAny (T left, const Array<T>& right,
 // </thrown>
 //
 // <group>
-template<class T> Bool allLE (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allLT (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allGE (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allGT (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allEQ (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allNE (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allNear (const Array<T> &l, const Array<T> &r,
-				Double tol);
-template<class T> Bool allNearAbs (const Array<T> &l, const Array<T> &r,
-				   Double tol);
+template<class T> bool allLE (const Array<T> &l, const Array<T> &r);
+template<class T> bool allLT (const Array<T> &l, const Array<T> &r);
+template<class T> bool allGE (const Array<T> &l, const Array<T> &r);
+template<class T> bool allGT (const Array<T> &l, const Array<T> &r);
+template<class T> bool allEQ (const Array<T> &l, const Array<T> &r);
+template<class T> bool allNE (const Array<T> &l, const Array<T> &r);
+template<class T> bool allNear (const Array<T> &l, const Array<T> &r,
+				double tol);
+template<class T> bool allNearAbs (const Array<T> &l, const Array<T> &r,
+				   double tol);
 //
 // This only makes sense if the array element type is logical valued.
 // <group>
-template<class T> Bool allAND (const Array<T> &l, const Array<T> &r);
-template<class T> Bool allOR (const Array<T> &l, const Array<T> &r);
+template<class T> bool allAND (const Array<T> &l, const Array<T> &r);
+template<class T> bool allOR (const Array<T> &l, const Array<T> &r);
 // </group>
 //
 // </group>
@@ -188,7 +181,7 @@ template<class T> Bool allOR (const Array<T> &l, const Array<T> &r);
 //
 // The Vector, Matrix and Cube version are present to bypass the problems
 // due to the existence of automatic comparison inline templates in standard
-// algorithm library, producing a single Bool value.
+// algorithm library, producing a single bool value.
 //
 // <group>
 template<class T> LogicalArray operator <= (const Array<T> &l,
@@ -205,9 +198,9 @@ template<class T> LogicalArray operator != (const Array<T> &l,
 					    const Array<T> &r);
 
 template<class T> LogicalArray near(const Array<T> &l, const Array<T> &r,
-				    Double tol);
+				    double tol);
 template<class T> LogicalArray nearAbs(const Array<T> &l, const Array<T> &r,
-                                       Double tol);
+                                       double tol);
 //
 // This only makes sense if the array element type is logical valued.
 // <group>
@@ -230,38 +223,38 @@ template<class T> LogicalArray operator ! (const Array<T> &l);
 // The result is true only if the comparison is true for every element
 // of the array.
 // <group>
-template<class T> Bool allLE (const Array<T> &array, const T &val);
-template<class T> Bool allLE (const T &val, const Array<T> &array);
-template<class T> Bool allLT (const Array<T> &array, const T &val);
-template<class T> Bool allLT (const T &val, const Array<T> &array);
-template<class T> Bool allGE (const Array<T> &array, const T &val);
-template<class T> Bool allGE (const T &val, const Array<T> &array);
-template<class T> Bool allGT (const Array<T> &array, const T &val);
-template<class T> Bool allGT (const T &val, const Array<T> &array);
-template<class T> Bool allEQ (const Array<T> &array, const T &val);
-template<class T> Bool allEQ (const T &val, const Array<T> &array);
-template<class T> Bool allNE (const Array<T> &array, const T &val);
-template<class T> Bool allNE (const T &val, const Array<T> &array);
-template<class T> Bool allNear (const Array<T> &array, const T &val, Double tol);
-template<class T> Bool allNear (const T &val, const Array<T> &array, Double tol);
-template<class T> Bool allNearAbs (const Array<T> &array, const T &val,
-				   Double tol);
-template<class T> Bool allNearAbs (const T &val, const Array<T> &array,
-				   Double tol);
+template<class T> bool allLE (const Array<T> &array, const T &val);
+template<class T> bool allLE (const T &val, const Array<T> &array);
+template<class T> bool allLT (const Array<T> &array, const T &val);
+template<class T> bool allLT (const T &val, const Array<T> &array);
+template<class T> bool allGE (const Array<T> &array, const T &val);
+template<class T> bool allGE (const T &val, const Array<T> &array);
+template<class T> bool allGT (const Array<T> &array, const T &val);
+template<class T> bool allGT (const T &val, const Array<T> &array);
+template<class T> bool allEQ (const Array<T> &array, const T &val);
+template<class T> bool allEQ (const T &val, const Array<T> &array);
+template<class T> bool allNE (const Array<T> &array, const T &val);
+template<class T> bool allNE (const T &val, const Array<T> &array);
+template<class T> bool allNear (const Array<T> &array, const T &val, double tol);
+template<class T> bool allNear (const T &val, const Array<T> &array, double tol);
+template<class T> bool allNearAbs (const Array<T> &array, const T &val,
+				   double tol);
+template<class T> bool allNearAbs (const T &val, const Array<T> &array,
+				   double tol);
 //
 // This only makes sense if the array element type is logical valued.
 // <group>
-template<class T> Bool allAND (const Array<T> &array, const T &val);
-template<class T> Bool allAND (const T &val, const Array<T> &array);
-template<class T> Bool allOR (const Array<T> &array, const T &val);
-template<class T> Bool allOR (const T &val, const Array<T> &array);
+template<class T> bool allAND (const Array<T> &array, const T &val);
+template<class T> bool allAND (const T &val, const Array<T> &array);
+template<class T> bool allOR (const Array<T> &array, const T &val);
+template<class T> bool allOR (const T &val, const Array<T> &array);
 // </group>
 //
 // </group>
 
 
 // Test if all elements in an array are the same.
-template<class T> Bool allSame (const Array<T> &a)
+template<class T> bool allSame (const Array<T> &a)
   { return a.size() <= 1  ||  allEQ(*a.data(), a); }
 
 
@@ -295,13 +288,13 @@ template<class T> LogicalArray operator == (const T &val, const Array<T> &array)
 template<class T> LogicalArray operator != (const Array<T> &array, const T &val);
 template<class T> LogicalArray operator != (const T &val, const Array<T> &array);
 template<class T> LogicalArray near (const Array<T> &array, const T &val,
-				     Double tol);
+				     double tol);
 template<class T> LogicalArray near (const T &val, const Array<T> &array,
-				      Double tol);
+				      double tol);
 template<class T> LogicalArray nearAbs (const Array<T> &array, const T &val,
-				     Double tol);
+				     double tol);
 template<class T> LogicalArray nearAbs (const T &val, const Array<T> &array,
-				      Double tol);
+				      double tol);
 //
 // This only makes sense if the array element type is logical valued.
 // <group>
@@ -330,21 +323,21 @@ template<class T> LogicalArray operator || (const T &val, const Array<T> &array)
 //
 // <group>
 
-template<class T> Bool anyLE (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyLT (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyGE (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyGT (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyEQ (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyNE (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyNear (const Array<T> &l, const Array<T> &r, 
-				Double tol);
-template<class T> Bool anyNearAbs (const Array<T> &l, const Array<T> &r,
-				   Double tol);
+template<class T> bool anyLE (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyLT (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyGE (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyGT (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyEQ (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyNE (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyNear (const Array<T> &l, const Array<T> &r, 
+				double tol);
+template<class T> bool anyNearAbs (const Array<T> &l, const Array<T> &r,
+				   double tol);
 //
 // This only makes sense if the array element type is logical valued.
 // <group>
-template<class T> Bool anyAND (const Array<T> &l, const Array<T> &r);
-template<class T> Bool anyOR (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyAND (const Array<T> &l, const Array<T> &r);
+template<class T> bool anyOR (const Array<T> &l, const Array<T> &r);
 // </group>
 //
 // </group>
@@ -357,53 +350,55 @@ template<class T> Bool anyOR (const Array<T> &l, const Array<T> &r);
 // comparison is true.
 // <group>
 
-template<class T> Bool anyLE (const Array<T> &array, const T &val);
-template<class T> Bool anyLE (const T &val, const Array<T> &array);
-template<class T> Bool anyLT (const Array<T> &array, const T &val);
-template<class T> Bool anyLT (const T &val, const Array<T> &array);
-template<class T> Bool anyGE (const Array<T> &array, const T &val);
-template<class T> Bool anyGE (const T &val, const Array<T> &array);
-template<class T> Bool anyGT (const Array<T> &array, const T &val);
-template<class T> Bool anyGT (const T &val, const Array<T> &array);
-template<class T> Bool anyEQ (const Array<T> &array, const T &val);
-template<class T> Bool anyEQ (const T &val, const Array<T> &array);
-template<class T> Bool anyNE (const Array<T> &array, const T &val);
-template<class T> Bool anyNE (const T &val, const Array<T> &array);
-template<class T> Bool anyNear (const Array<T> &array, const T &val, Double tol);
-template<class T> Bool anyNear (const T &val, const Array<T> &array, Double tol);
-template<class T> Bool anyNearAbs (const Array<T> &array, const T &val,
-				   Double tol);
-template<class T> Bool anyNearAbs (const T &val, const Array<T> &array,
-				   Double tol);
+template<class T> bool anyLE (const Array<T> &array, const T &val);
+template<class T> bool anyLE (const T &val, const Array<T> &array);
+template<class T> bool anyLT (const Array<T> &array, const T &val);
+template<class T> bool anyLT (const T &val, const Array<T> &array);
+template<class T> bool anyGE (const Array<T> &array, const T &val);
+template<class T> bool anyGE (const T &val, const Array<T> &array);
+template<class T> bool anyGT (const Array<T> &array, const T &val);
+template<class T> bool anyGT (const T &val, const Array<T> &array);
+template<class T> bool anyEQ (const Array<T> &array, const T &val);
+template<class T> bool anyEQ (const T &val, const Array<T> &array);
+template<class T> bool anyNE (const Array<T> &array, const T &val);
+template<class T> bool anyNE (const T &val, const Array<T> &array);
+template<class T> bool anyNear (const Array<T> &array, const T &val, double tol);
+template<class T> bool anyNear (const T &val, const Array<T> &array, double tol);
+template<class T> bool anyNearAbs (const Array<T> &array, const T &val,
+				   double tol);
+template<class T> bool anyNearAbs (const T &val, const Array<T> &array,
+				   double tol);
 //
 // This only makes sense if the array element type is logical valued.
 // <group>
-template<class T> Bool anyAND (const Array<T> &array, const T &val);
-template<class T> Bool anyAND (const T &val, const Array<T> &array);
-template<class T> Bool anyOR (const Array<T> &array, const T &val);
-template<class T> Bool anyOR (const T &val, const Array<T> &array);
+template<class T> bool anyAND (const Array<T> &array, const T &val);
+template<class T> bool anyAND (const T &val, const Array<T> &array);
+template<class T> bool anyOR (const Array<T> &array, const T &val);
+template<class T> bool anyOR (const T &val, const Array<T> &array);
 // </group>
 //
 // </group>
 
 
 // Are all elements true?
-inline Bool allTrue (const Array<Bool>& array)
-  { return allEQ (array, True); }
+template<typename Alloc>
+inline bool allTrue (const Array<bool, Alloc>& array)
+  { return allEQ (array, true); }
 
 // Is any element true?
-inline Bool anyTrue (const Array<Bool>& array)
-  { return anyEQ (array, True); }
+template<typename Alloc>
+inline bool anyTrue (const Array<bool, Alloc>& array)
+  { return anyEQ (array, true); }
 
 // The same functions as above, but for selected axes.
-Array<Bool> partialAllTrue (const Array<Bool>& array,
+Array<bool> partialAllTrue (const Array<bool>& array,
                             const IPosition& collapseAxes);
-Array<Bool> partialAnyTrue (const Array<Bool>& array,
+Array<bool> partialAnyTrue (const Array<bool>& array,
                             const IPosition& collapseAxes);
 
 // Determine the number of true or false elements.
-// Note: it is meant for Bool arrays, but can also be used for
-// e.g. Int arrays.
+// Note: it is meant for bool arrays, but can also be used for
+// e.g. int arrays.
 // <group>
 
 // Determine it for the full array.
@@ -422,47 +417,49 @@ template<class T> size_t ntrue (const Array<T> &array)
 // Summing for axes 0 and 2 results in an array with shape [4] containing
 // ntrue or nfalse for each XZ plane.
 // <group>
-template<class T> Array<uInt> partialNTrue (const Array<T>& array,
+template<class T> Array<size_t> partialNTrue (const Array<T>& array,
 					    const IPosition& collapseAxes);
-template<class T> Array<uInt> partialNFalse (const Array<T>& array,
+template<class T> Array<size_t> partialNFalse (const Array<T>& array,
 					     const IPosition& collapseAxes);
 // </group>
 
 // </group>
 
 // </group>
+} //# end of casacore namespace
 
-// Define logical Functors.
-// <group>
-template<typename T> class AllFunc : public ArrayFunctorBase<T,Bool> {
+#include "ArrayMathBase.h"
+
+namespace casacore {
+
+// Logical functor to test if all elements are true
+template<typename T> class AllFunc final : public ArrayFunctorBase<T,bool> {
 public:
-  virtual ~AllFunc() {}
-  virtual Bool operator() (const Array<T>& arr) const { return allTrue(arr); }
-};
-template<typename T> class AnyFunc : public ArrayFunctorBase<T,Bool> {
-public:
-  virtual ~AnyFunc() {}
-  virtual Bool operator() (const Array<T>& arr) const { return anyTrue(arr); }
+  virtual bool operator() (const Array<T>& arr) const override { return allTrue(arr); }
 };
 
+// Logical functor to test if any elements are true
+template<typename T> class AnyFunc final : public ArrayFunctorBase<T,bool> {
+public:
+  virtual bool operator() (const Array<T>& arr) const override { return anyTrue(arr); }
+};
+
+// Logical functor to count the number of true elements
 template<typename T, typename RES=size_t>
-class NTrueFunc : public ArrayFunctorBase<T,RES> {
+class NTrueFunc final : public ArrayFunctorBase<T,RES> {
 public:
-  virtual ~NTrueFunc() {}
-  virtual RES operator() (const Array<T>& arr) const { return ntrue(arr); }
+  virtual RES operator() (const Array<T>& arr) const override { return ntrue(arr); }
 };
-template<typename T, typename RES=size_t>
-class NFalseFunc : public ArrayFunctorBase<T,RES> {
-public:
-  virtual ~NFalseFunc() {}
-  virtual RES operator() (const Array<T>& arr) const { return nfalse(arr); }
-};
-// </group>
 
+// Logical functor to count the number of false elements
+template<typename T, typename RES=size_t>
+class NFalseFunc final : public ArrayFunctorBase<T,RES> {
+public:
+  virtual RES operator() (const Array<T>& arr) const override { return nfalse(arr); }
+};
 
 } //# NAMESPACE CASACORE - END
 
-#ifndef CASACORE_NO_AUTO_TEMPLATES
-#include <casacore/casa/Arrays/ArrayLogical.tcc>
-#endif //# CASACORE_NO_AUTO_TEMPLATES
+#include "ArrayLogical.tcc"
+
 #endif
