@@ -26,14 +26,19 @@
 //# $Id$
 
 //# Includes
-#include <casacore/casa/Arrays/Array.h>
-#include <casacore/casa/Arrays/ArrayMath.h>
-#include <casacore/casa/Arrays/ArrayLogical.h>
-#include <casacore/casa/iostream.h>
+#include "../Array.h"
+#include "../ArrayMath.h"
+#include "../ArrayLogical.h"
+
+#include <cstdlib>
+
+#include <boost/test/unit_test.hpp>
 
 using namespace casacore;
 
-void doIt()
+BOOST_AUTO_TEST_SUITE(array_math_transform)
+
+BOOST_AUTO_TEST_CASE(test)
 {
   IPosition shape(3,10,11,12);
   Array<int> arr1(shape);
@@ -44,7 +49,7 @@ void doIt()
   Array<int> res(shape);
   indgen (arr1, -100);
   indgen (arr2);
-  for (uInt i=0; i<arr1.nelements(); ++i) {
+  for (size_t i=0; i<arr1.nelements(); ++i) {
     exp1.data()[i] = arr1.data()[i] + arr2.data()[i];
     exp2.data()[i] = arr1.data()[i] + 20;
     expa.data()[i] = std::abs(arr1.data()[i]);
@@ -52,41 +57,41 @@ void doIt()
 
   // First test transform of contiguous arrays.
   arrayContTransform (arr1, arr2, res, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp1));
+  BOOST_CHECK (allEQ (res, exp1));
   arrayContTransform (arr1, 20, res, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
+  BOOST_CHECK (allEQ (res, exp2));
   arrayContTransform (20, arr1, res, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
-  arrayContTransform (arr1, res, Abs<int>());
-  AlwaysAssertExit (allEQ (res, expa));
+  BOOST_CHECK (allEQ (res, exp2));
+  arrayContTransform (arr1, res, [](int a){return std::abs(a);});
+  BOOST_CHECK (allEQ (res, expa));
 
   arrayTransform (arr1, arr2, res, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp1));
+  BOOST_CHECK (allEQ (res, exp1));
   arrayTransform (arr1, 20, res, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
+  BOOST_CHECK (allEQ (res, exp2));
   arrayTransform (20, arr1, res, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
-  arrayTransform (arr1, res, Abs<int>());
-  AlwaysAssertExit (allEQ (res, expa));
+  BOOST_CHECK (allEQ (res, exp2));
+  arrayTransform (arr1, res, [](int a){return std::abs(a);});
+  BOOST_CHECK (allEQ (res, expa));
 
-  AlwaysAssertExit (allEQ (exp1, arrayTransformResult (arr1, arr2,
+  BOOST_CHECK (allEQ (exp1, arrayTransformResult (arr1, arr2,
                                                        std::plus<int>())));
-  AlwaysAssertExit (allEQ (exp2, arrayTransformResult (arr1, 20,
+  BOOST_CHECK (allEQ (exp2, arrayTransformResult (arr1, 20,
                                                        std::plus<int>())));
-  AlwaysAssertExit (allEQ (exp2, arrayTransformResult (20, arr1,
+  BOOST_CHECK (allEQ (exp2, arrayTransformResult (20, arr1,
                                                        std::plus<int>())));
-  AlwaysAssertExit (allEQ (expa, arrayTransformResult (arr1,
-                                                       Abs<int>())));
+  BOOST_CHECK (allEQ (expa, arrayTransformResult (arr1,
+    [](int a){return std::abs(a);})));
 
-  res = arr1;
+  res.assign_conforming(arr1);
   arrayTransformInPlace (res, arr2, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp1));
-  res = arr1;
+  BOOST_CHECK (allEQ (res, exp1));
+  res.assign_conforming(arr1);
   arrayTransformInPlace (res, 20, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
-  res = arr1;
-  arrayTransformInPlace (res, Abs<int>());
-  AlwaysAssertExit (allEQ (res, expa));
+  BOOST_CHECK (allEQ (res, exp2));
+  res.assign_conforming(arr1);
+  arrayTransformInPlace (res, [](int a){return std::abs(a);});
+  BOOST_CHECK (allEQ (res, expa));
 
   // Now test non-contiguous arrays.
   Slicer slicer(IPosition(3,1,2,3), IPosition(3,7,8,9), IPosition(3,2),
@@ -98,49 +103,39 @@ void doIt()
   Array<int> exp2sl (exp2(slicer));
   Array<int> expasl (expa(slicer));
 
-  res = exp1;
+  res.assign_conforming(exp1);
   arrayTransform (arr1sl, arr2sl, ressl, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp1));
-  res = exp2;
+  BOOST_CHECK (allEQ (res, exp1));
+  res.assign_conforming(exp2);
   arrayTransform (arr1sl, 20, ressl, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
+  BOOST_CHECK (allEQ (res, exp2));
   arrayTransform (20, arr1sl, ressl, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
-  res = expa;
-  arrayTransform (arr1sl, ressl, Abs<int>());
-  AlwaysAssertExit (allEQ (res, expa));
+  BOOST_CHECK (allEQ (res, exp2));
+  res.assign_conforming(expa);
+  arrayTransform (arr1sl, ressl, [](int a){return std::abs(a);});
+  BOOST_CHECK (allEQ (res, expa));
 
-  AlwaysAssertExit (allEQ (exp1sl, arrayTransformResult (arr1sl, arr2sl,
+  BOOST_CHECK (allEQ (exp1sl, arrayTransformResult (arr1sl, arr2sl,
                                                          std::plus<int>())));
-  AlwaysAssertExit (allEQ (exp2sl, arrayTransformResult (arr1sl, 20,
+  BOOST_CHECK (allEQ (exp2sl, arrayTransformResult (arr1sl, 20,
                                                          std::plus<int>())));
-  AlwaysAssertExit (allEQ (exp2sl, arrayTransformResult (20, arr1sl,
+  BOOST_CHECK (allEQ (exp2sl, arrayTransformResult (20, arr1sl,
                                                          std::plus<int>())));
-  AlwaysAssertExit (allEQ (expasl, arrayTransformResult (arr1sl,
-                                                         Abs<int>())));
+  BOOST_CHECK (allEQ (expasl, arrayTransformResult (arr1sl,
+    [](int a){return std::abs(a);})));
 
-  res   = exp1;
-  ressl = arr1sl;
+  res.assign_conforming(exp1);
+  ressl.assign_conforming(arr1sl);
   arrayTransformInPlace (ressl, arr2sl, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp1));
-  res   = exp2;
-  ressl = arr1sl;
+  BOOST_CHECK (allEQ (res, exp1));
+  res.assign_conforming(exp2);
+  ressl.assign_conforming(arr1sl);
   arrayTransformInPlace (ressl, 20, std::plus<int>());
-  AlwaysAssertExit (allEQ (res, exp2));
-  res   = expa;
-  ressl = arr1sl;
-  arrayTransformInPlace (res, Abs<int>());
-  AlwaysAssertExit (allEQ (res, expa));
+  BOOST_CHECK (allEQ (res, exp2));
+  res.assign_conforming(expa);
+  ressl.assign_conforming(arr1sl);
+  arrayTransformInPlace (res, [](int a){return std::abs(a);});
+  BOOST_CHECK (allEQ (res, expa));
 }
 
-int main()
-{
-  try {
-    doIt();
-  } catch (AipsError& x) {
-    cout << "Unexpected exception: " << x.getMesg() << endl;
-    return 1;
-  }
-  cout << "OK" << endl;
-  return 0;
-}
+BOOST_AUTO_TEST_SUITE_END()
