@@ -43,7 +43,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
 //# Forward Declarations
 class String;
-class RegexBase;
+class Regex;
 
 // <summary> SubString help class to be used in at, before, ... </summary>
 // <synopsis>
@@ -100,7 +100,7 @@ private:
 // </reviewed>
 
 // <prerequisite>
-//   <li> RegexBase - the regular expressions class
+//   <li> Regex - the regular expressions class
 //   <li> the std string class
 // </prerequisite>
 //
@@ -170,7 +170,7 @@ private:
 // </ol>
 // The Casacore additions are:
 // <ol>
-// <li> To standard: some Char function arguments where appropriate; RegexBase
+// <li> To standard: some Char function arguments where appropriate; Regex
 //		arguments in search like methods.
 // <li> Substring additions: at, before, after, from, through functions taking
 //		search String, Char* as arguments can give (hidden) substrings
@@ -639,7 +639,7 @@ class String : public string {
     { return find(beginString) == 0; }
 
   // Search functions. Returns either npos (if not found); else position.
-  // <note role=warning> The RegexBase ones are ** Casacore additions</note>
+  // <note role=warning> The Regex ones are ** Casacore additions</note>
   // <group>
   size_type find(const string &str, size_type pos=0) const {
     return string::find(str, pos); }
@@ -649,7 +649,7 @@ class String : public string {
     return string::find(s, pos, n); }
   size_type find(Char c, size_type pos=0) const {
     return string::find(c, pos); }
-  size_type find(const RegexBase &r, size_type pos=0) const;
+  size_type find(const Regex &r, size_type pos=0) const;
   size_type rfind(const string &str, size_type pos=npos) const {
     return string::rfind(str, pos); }
   size_type rfind(const Char *s, size_type pos=npos) const {
@@ -658,7 +658,6 @@ class String : public string {
     return string::rfind(s, pos, n); }
   size_type rfind(Char c, size_type pos=npos) const {
     return string::rfind(c, pos); }
-  size_type rfind(const RegexBase &r, size_type pos=npos) const;
   size_type find_first_of(const string &str, size_type pos=0) const {
     return string::find_first_of(str, pos); }
   size_type find_first_of(const Char *s, size_type pos=0) const {
@@ -701,7 +700,7 @@ class String : public string {
     return (find(str) != npos); }
   Bool contains(const Char *s) const {
     return (find(s) != npos); }
-  Bool contains(const RegexBase &r) const;
+  Bool contains(const Regex &r) const;
   // </group>
   // Does the string starting at the given position contain the given substring?
   // If the position is negative, it is counted from the end.
@@ -710,7 +709,7 @@ class String : public string {
   Bool contains(Char c, Int pos) const;
   Bool contains(const string &str, Int pos) const;
   Bool contains(const Char *s, Int pos) const;
-  Bool contains(const RegexBase &r, Int pos) const;
+  Bool contains(const Regex &r, Int pos) const;
   // </group>
 
   // Matches entire string from pos
@@ -721,7 +720,7 @@ class String : public string {
     return matches(String(c), pos); };
   Bool matches(const Char *s, Int pos = 0) const {
     return matches(String(s), pos); };
-  Bool matches(const RegexBase &r, Int pos = 0) const;
+  Bool matches(const Regex &r, Int pos = 0) const;
   // </group>
 
   // Concatenate by prepending the argument onto String. ** Casacore addition
@@ -743,7 +742,7 @@ class String : public string {
   size_type index(const Char *s, Int startpos = 0) const {
     return ((startpos >= 0) ? find(s, startpos) :
 	    rfind(s, length() + startpos - traits_type::length(s))); }
-  size_type index(const RegexBase &r, Int startpos = 0) const;
+  size_type index(const Regex &r, Int startpos = 0) const;
   // </group>
 
   //  Return the number of occurences of target in String. ** Casacore addition
@@ -764,8 +763,8 @@ class String : public string {
   String at(const Char *s, Int startpos = 0) const;
   SubString at(Char c, Int startpos = 0);
   String at(Char c, Int startpos = 0) const;
-  SubString at(const RegexBase &r, Int startpos = 0); 
-  String at(const RegexBase &r, Int startpos = 0) const; 
+  SubString at(const Regex &r, Int startpos = 0); 
+  String at(const Regex &r, Int startpos = 0) const; 
   // Next ones for overloading reasons. 
   // <note role=tip> It is better to use the <src>substr()</src> method
   // in stead. </note>
@@ -792,7 +791,7 @@ class String : public string {
   SubString before(const string &str, size_type startpos = 0) const;
   SubString before(const Char *s, size_type startpos = 0) const;
   SubString before(Char c, size_type startpos = 0) const;
-  SubString before(const RegexBase &r, size_type startpos = 0) const;
+  SubString before(const Regex &r, size_type startpos = 0) const;
   // Next one for overloading reasons
   SubString before(Int pos) const {
     return before(static_cast<size_type>(pos)); };    
@@ -805,7 +804,7 @@ class String : public string {
   SubString through(const string &str, size_type startpos = 0);
   SubString through(const Char *s, size_type startpos = 0);
   SubString through(Char c, size_type startpos = 0);
-  SubString through(const RegexBase &r, size_type startpos = 0);
+  SubString through(const Regex &r, size_type startpos = 0);
   // Next one for overloading reasons
   SubString through(Int pos) {
     return through(static_cast<size_type>(pos)); }
@@ -818,7 +817,7 @@ class String : public string {
   SubString from(const string &str, size_type startpos = 0);
   SubString from(const Char *s, size_type startpos = 0);
   SubString from(Char c, size_type startpos = 0);
-  SubString from(const RegexBase &r, size_type startpos = 0);
+  SubString from(const Regex &r, size_type startpos = 0);
   // Next one for overloading reasons
   SubString from(Int pos) {
     return from(static_cast<size_type>(pos));
@@ -832,7 +831,7 @@ class String : public string {
   SubString after(const string &str, size_type startpos = 0);
   SubString after(const Char *s, size_type startpos = 0);
   SubString after(Char c, size_type startpos = 0);
-  SubString after(const RegexBase &r, size_type startpos = 0);
+  SubString after(const Regex &r, size_type startpos = 0);
   // Next one for overloading reasons
   SubString after(Int pos) {
     return after(static_cast<size_type>(pos));
@@ -859,7 +858,7 @@ class String : public string {
   void del(const string &str, size_type startpos = 0);
   void del(const Char *s, size_type startpos = 0);
   void del(Char c, size_type startpos = 0);
-  void del(const RegexBase &r, size_type startpos = 0);
+  void del(const Regex &r, size_type startpos = 0);
   // Overload problem
   void del(Int pos, Int len) {
     del(static_cast<size_type>(pos), static_cast<size_type>(len)); }
@@ -872,7 +871,7 @@ class String : public string {
   Int gsub(const string &pat, const string &repl);
   Int gsub(const Char *pat, const string &repl);
   Int gsub(const Char *pat, const Char *repl);
-  Int gsub(const RegexBase &pat, const string &repl);
+  Int gsub(const Regex &pat, const string &repl);
   //</group>
 
 private:
@@ -970,7 +969,7 @@ Int split(const string &str, string res[], Int maxn,
 Int split(const string &str, string res[], Int maxn,
 	  const Char sep);
 Int split(const string &str, string res[], Int maxn,
-	  const RegexBase &sep);
+	  const Regex &sep);
 //</group> 
 
 // <summary> Some general functions </summary>
@@ -1025,7 +1024,7 @@ inline Bool String::contains(const string &str, Int pos) const {
   return (index(str, pos) != npos); }
 inline Bool String::contains(const Char *s, Int pos) const {
   return (index(s, pos) != npos); }
-inline Bool String::contains(const RegexBase &r, Int pos) const {
+inline Bool String::contains(const Regex &r, Int pos) const {
   return (index(r, pos) != npos); }
 
 inline ostream &operator<<(ostream &s, const String &x) {
