@@ -45,8 +45,8 @@ int main (int argc, const char*[])
   try {
     a (argc<2);
     b (argc<2);
-  } catch (AipsError& x) {
-    cout << "Caught an exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Caught an exception: " << x.what() << endl;
     return 1;
   } 
   return 0;                           // exit with success status
