@@ -189,8 +189,8 @@ int main ()
 	    RegularFileIO regularFileIO (Path("tByteSinkSource_tmp.dat"),
 					 ByteIO::NewNoReplace);
 	} 
-	catch (AipsError& x)  {
-	    cout << x.getMesg () << endl;
+	catch (std::exception& x)  {
+	    cout << x.what () << endl;
 	} 
     }
     return 0;
