@@ -64,18 +64,18 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    RegularFile rf ("tRegularFile_tmp/a/b");         // not creatable
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;
 	} 
 	try {
 	    RegularFile rf ("tRegularFile_tmp");             // directory
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;
 	} 
 	try {
 	    RegularFile rf ("tRegularFile_tmp/isLink2");     // symlink to dir
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;
 	} 
     }
     // Assignment.
@@ -91,8 +91,8 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    risFile.create (False);                         // already exists
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;
 	} 
     }
     // Do a valid create and assure its timestamp is greater and it is empty.
@@ -117,21 +117,21 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    risFile1.copy (Path("tRegularFile_tmp/aa/bb/cc"));
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;         // non-writable directory
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;         // non-writable directory
 	} 
 	try {
 	    risFile1.copy (Path("tRegularFile_tmp/isFile"), False);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;         // already exists
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;         // already exists
 	} 
     }
     risCopy.setPermissions (0444);
     if (doExcp) {
 	try {
 	    risFile1.copy (Path("tRegularFile_tmp/moveto/isFile1"));
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;         // exists, non-writable
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;         // exists, non-writable
 	} 
     }
     risCopy.setPermissions (0644);
@@ -144,8 +144,8 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    file2.move ("tRegularFile_tmp/moveto/isFile1", False);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;         // already exists
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;         // already exists
 	} 
     }
     file2.move ("tRegularFile_tmp/moveto");
@@ -179,8 +179,8 @@ int main (int argc,const char*[])
 {
     try {
 	doIt ( (argc<2));
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     cout << "OK" << endl;
