@@ -62,8 +62,8 @@ int main()
     defaultValue(foo3);
     AlwaysAssert(foo3 == String("defaultval"), AipsError);
 
-    } catch (AipsError& x) {
-        cout << "\nCaught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+        cout << "\nCaught an exception: " << x.what() << endl;
     } 
  
     cout << "OK" << endl;
