@@ -31,6 +31,7 @@
 #define COORDINATES_COORDINATESYSTEM_H
 
 #include <casacore/casa/aips.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 #include <casacore/coordinates/Coordinates/Coordinate.h>
 #include <casacore/measures/Measures/MDirection.h>
 #include <casacore/measures/Measures/MFrequency.h>
@@ -41,7 +42,6 @@
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
-template<class T> class Matrix;
 class DirectionCoordinate;
 class LinearCoordinate;
 class SpectralCoordinate;
