@@ -214,8 +214,8 @@ try {
       cout << endl << endl;
    }
 
-} catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+} catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return 1;
 }
  
