@@ -343,7 +343,7 @@ int main()
         	  // expected exception not thrown if we get here
         	  AlwaysAssert(False, AipsError);
     	  }
-    	  catch (const AipsError& x) {}
+    	  catch (const std::exception& x) {}
     	  csys = CoordinateSystem();
     	  CoordinateUtil::addFreqAxis(csys);
     	  try {
@@ -351,7 +351,7 @@ int main()
     		  // expected exception not thrown if we get here
     		  AlwaysAssert(False, AipsError);
     	  }
-    	  catch (const AipsError& x) {}
+    	  catch (const std::exception& x) {}
     	  csys = CoordinateUtil::defaultCoords(4);
     	  indgen(pixelOrder);
     	  pixelOrder[0] = 1;
@@ -489,8 +489,8 @@ int main()
       }
 
    }
-   catch (const AipsError& x) {
-      cerr << "Error " << x.getMesg() << endl;
+   catch (const std::exception& x) {
+      cerr << "Error " << x.what() << endl;
       return (1);
    }
 
@@ -859,7 +859,7 @@ void doit (CoordinateSystem& cSys, uInt nCoords, const Vector<Int>& types,
 	   // this should have thrown an exception, if not, its a failure
 	   AlwaysAssert(False, AipsError);
    }
-   catch (const AipsError& x) {}
+   catch (const std::exception& x) {}
 
 //
 //
@@ -2449,7 +2449,7 @@ void doit6 ()
       Bool failed = False;
       try {
          pC = cSys.makeFourierCoordinate (axes, shape);
-      } catch (AipsError& x) {
+      } catch (std::exception& x) {
         failed = True;
       } 
       if (!failed) {
@@ -2466,7 +2466,7 @@ void doit6 ()
       Vector<Bool> axes2(20, True);
       try {
          pC = cSys.makeFourierCoordinate (axes2, shape);
-      } catch (AipsError& x) {
+      } catch (std::exception& x) {
         failed = True;
       } 
       if (!failed) {
@@ -2483,7 +2483,7 @@ void doit6 ()
       Vector<Int> shape2(20, 100);
       try {
          pC = cSys.makeFourierCoordinate (axes, shape2);
-      } catch (AipsError& x) {
+      } catch (std::exception& x) {
         failed = True;
       } 
       if (!failed) {
