@@ -41,7 +41,7 @@
 #include <casacore/casa/Arrays/Vector.h>
 #include <casacore/casa/Arrays/Slice.h>
 #include <casacore/casa/Arrays/ArrayUtil.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/BasicSL/Constants.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/Exceptions/Error.h>
@@ -228,8 +228,8 @@ LatticeExprNode ImageExprParse::command
 	if (imageExprGramParseCommand(command) != 0) {
 	    throw (AipsError("Parse error in image expression " + str));
 	}
-    } catch (AipsError& x) {
-	message = x.getMesg();
+    } catch (std::exception& x) {
+	message = x.what();
 	error = True;
     } 
     //# Save the resulting expression and clear the common node object.
