@@ -37,7 +37,7 @@
 #include <casacore/casa/Arrays/Matrix.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/Containers/Block.h>
 #include <casacore/casa/BasicSL/Constants.h>
@@ -380,8 +380,8 @@ int main (int argc, const char* argv[])
       delete tempRegs[i];
     }
 
-  } catch (AipsError& x) {
-    cerr << "aipserror: error " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << "aipserror: error " << x.what() << endl;
     foundError = True;
   } 
 
