@@ -31,7 +31,7 @@
 #include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/Inputs/Input.h>
 #include <casacore/casa/Exceptions/Error.h>
@@ -164,8 +164,8 @@ int main (int argc, const char* argv[])
       }
     }
 
-  } catch (AipsError& x) {
-    cerr << "aipserror: error " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << "aipserror: error " << x.what() << endl;
     foundError = True;
   } 
 
