@@ -399,9 +399,9 @@ int main() {
         */
 
     }
-    catch (const AipsError& x) {
+    catch (const std::exception& x) {
 
-        cerr << "Exception caught: " << x.getMesg() << endl;
+        cerr << "Exception caught: " << x.what() << endl;
         return 1;
     } 
     return 0;
