@@ -250,7 +250,7 @@ LCRegion* WCRegion::toLCRegionAxes (const CoordinateSystem& cSys,
     IPosition extendShape(ndout-ndreg);
     Vector<uInt> inx(ndreg);
     std::vector<Int> tmp(outOrder.begin(), outOrder.end());
-    GenSortIndirect<Int>::sort (inx, &(tmp[0]), ndreg);
+    GenSortIndirect<Int,uInt>::sort (inx, &(tmp[0]), ndreg);
     for (i=0; i<ndreg; i++) {
         pixAxesMap(i) = pixelAxesMap(i);
 	outOrd(inx(i)) = i;
