@@ -29,7 +29,7 @@
 #include <casacore/casa/Arrays/Vector.h>
 #include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Arrays/IPosition.h>
 //#include <casacore/casa/Arrays/Slicer.h>
@@ -606,9 +606,9 @@ int main() {
 // 	cout << "result = " << resultArray << endl;
 //       }
       }
-  } catch (AipsError& x) {
+  } catch (std::exception& x) {
     cout<< "FAIL"<< endl;
-    cerr << x.getMesg() << endl;
+    cerr << x.what() << endl;
     return 1;
   } 
   cout<< "OK"<< endl;
