@@ -210,8 +210,8 @@ int main (int argc, const char* argv[])
 	pa.showCacheStatistics(cout);
       }
     }
-  } catch (AipsError& x) {
-    cerr << "Caught exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << "Caught exception: " << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
