@@ -31,7 +31,7 @@
 #include <casacore/lattices/Lattices/LatticeStepper.h>
 #include <casacore/casa/OS/Timer.h>
 #include <casacore/casa/Arrays/Array.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/Matrix.h>
@@ -206,8 +206,8 @@ int main()
 
     cout<<"<<<"<<endl;
     cout<< "OK"<< endl;
-  } catch (AipsError& x) {
-    cerr << "Exception caught: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << "Exception caught: " << x.what() << endl;
   } 
 
   return 0;
