@@ -155,8 +155,8 @@ int main (int argc, char* argv[])
         getCube (PagedArray<Float>("tLatticePerf_tmp.tab"), argv[1]);
       }
     }
-  } catch (AipsError& x) {
-    cout << "Caught an exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Caught an exception: " << x.what() << endl;
     return 1;
   } 
   return 0;                           // exit with success status
