@@ -86,8 +86,8 @@ int main() {
       AlwaysAssertExit (! small.isPaged());
       doIt (small);
     }
-  } catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
