@@ -31,6 +31,7 @@
 
 //# Includes
 #include <casacore/casa/aips.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 #include <casacore/measures/Measures/MeasBase.h>
 #include <casacore/measures/Measures/MeasRef.h>
 #include <casacore/measures/Measures/MCBase.h>
@@ -46,8 +47,6 @@ class MCDirection;
 class MVPosition;
 class String;
 
-template <class T> class Vector;
-
 //# Typedefs
 
 // <summary> MDirection conversion routines  </summary>
