@@ -399,44 +399,31 @@ Bool MeasIERS::findTab(Table& tab, const Table *tabin, const String &rc,
         "/geodetic/"
       };
 
-      
       Bool found = False;
-      const std::list<std::string> &state_path = AppStateSource::fetch( ).dataPath( );
-      if ( state_path.size( ) > 0 ) {
-        String mdir;
-        for ( std::list<std::string>::const_iterator it=state_path.begin(); ! found && it != state_path.end(); ++it ) {
-          for (Int i=0; i<2; i++) {
-            Path mpath = Path(*it + "/" + (std::string) path[i]);
-            ldir = mpath.absoluteName()+"/";
-            searched.resize(searched.nelements()+1, True);
-            searched[searched.nelements()-1] = ldir;
-            if  (Table::isReadable(ldir+name)) {
-              found = True;
-              break;
-            }
+      const std::string &measures_data = AppStateSource::fetch( ).measuresDir( );
+      if ( measures_data.size( ) > 0 ) {
+        for (Int i=0; i<2; i++) {
+          Path mpath = Path(measures_data + "/" + (std::string) path[i]);
+          ldir = mpath.absoluteName()+"/";
+          searched.resize(searched.nelements()+1, True);
+          searched[searched.nelements()-1] = ldir;
+          if  (Table::isReadable(ldir+name)) {
+            found = True;
+            break;
           }
         }
-      } else if ( ! found ) {
-
-        if (Aipsrc::find(ldir, rc)){
-          ldir += '/';
-          searched.resize(searched.nelements() + 1, True);
-          searched[searched.nelements() - 1] = ldir;
-        }
-        else {
-          String udir;
-
-          if(!dir.empty()) {
-            udir = dir + '/';
+          if ( found == False ) {
+            throw(AipsError(std::string("Measures directory specified which does not contain the IERS data: ") + measures_data));
           }
+      }
 
+      if ( found == False ) {
+        const std::list<std::string> &state_path = AppStateSource::fetch( ).dataPath( );
+        if ( state_path.size( ) > 0 ) {
           String mdir;
-          if (Aipsrc::find(mdir, "measures.directory")) {
-            mdir.trim();
-            Path mpath = Path(mdir);
-            mpath.append(udir);
+          for ( std::list<std::string>::const_iterator it=state_path.begin(); ! found && it != state_path.end(); ++it ) {
             for (Int i=0; i<2; i++) {
-              Path mpath = Path(mdir +"/" + path[i]);
+              Path mpath = Path(*it + "/" + (std::string) path[i]);
               ldir = mpath.absoluteName()+"/";
               searched.resize(searched.nelements()+1, True);
               searched[searched.nelements()-1] = ldir;
@@ -446,18 +433,49 @@ Bool MeasIERS::findTab(Table& tab, const Table *tabin, const String &rc,
               }
             }
           }
-          if (!found) {
-            String casadata=String(CASADATA);
-            casadata.gsub("%CASAROOT%", Aipsrc::aipsRoot());
-            casadata.gsub("%CASAHOME%", Aipsrc::aipsHome());
-            Path cdatapath(casadata);
-            for (Int i=0; i<2; i++) {
-              ldir = cdatapath.absoluteName() + path[i];
-              searched.resize(searched.nelements() + 1, True);
-              searched[searched.nelements() - 1] = ldir;
-              if (Table::isReadable(ldir + name)) {
-                found = True;
-                break;
+        } else if ( ! found ) {
+
+          if (Aipsrc::find(ldir, rc)){
+            ldir += '/';
+            searched.resize(searched.nelements() + 1, True);
+            searched[searched.nelements() - 1] = ldir;
+          }
+          else {
+            String udir;
+
+            if(!dir.empty()) {
+              udir = dir + '/';
+            }
+
+            String mdir;
+            if (Aipsrc::find(mdir, "measures.directory")) {
+              mdir.trim();
+              Path mpath = Path(mdir);
+              mpath.append(udir);
+              for (Int i=0; i<2; i++) {
+                Path mpath = Path(mdir +"/" + path[i]);
+                ldir = mpath.absoluteName()+"/";
+                searched.resize(searched.nelements()+1, True);
+                searched[searched.nelements()-1] = ldir;
+                if  (Table::isReadable(ldir+name)) {
+                  found = True;
+                  break;
+                }
+              }
+            }
+            if (!found) {
+              String casadata=String(CASADATA);
+              casadata.gsub("%CASAROOT%", Aipsrc::aipsRoot());
+              casadata.gsub("%CASAHOME%", Aipsrc::aipsHome());
+              Path cdatapath(casadata);
+              for (Int i=0; i<2; i++) {
+                ldir = cdatapath.absoluteName() + path[i];
+                searched.resize(searched.nelements() + 1, True);
+                searched[searched.nelements() - 1] = ldir;
+                if (Table::isReadable(ldir + name)) {
+                  found = True;
+                  break;
+                }
               }
             }
           }
