@@ -40,7 +40,7 @@
 #include <casacore/casa/Quanta/Quantum.h>
 #include <casacore/casa/Quanta/MVEpoch.h>
 #include <casacore/casa/Arrays/Vector.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/OS/Timer.h>
 #include <casacore/casa/iostream.h>
 #include <casacore/casa/iomanip.h>
@@ -178,8 +178,8 @@ int main() {
     cout << "---------------------------------------------" << endl;
 
 
-  } catch (AipsError& x) {
-    cout << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << x.what() << endl;
   } 
 
   try {
@@ -192,8 +192,8 @@ int main() {
     Double result = pam(52230.0);
     cout << result << endl;
 
-  } catch (AipsError& x) {
-    cout << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << x.what() << endl;
   }
 
   cout << "---------------------------------------------" << endl;
