@@ -298,9 +298,9 @@ void MSLister::listHeader()
     // List the data
     listData(pagerows, listfile);
   }
-  catch (AipsError& x) {
+  catch (std::exception& x) {
     logStream_p << LogOrigin("MSLister","list",WHERE)
-            << LogIO::SEVERE << "Caught exception: " << x.getMesg()
+            << LogIO::SEVERE << "Caught exception: " << x.what()
             << LogIO::POST;
     throw(AipsError("Error in MSLister::list"));
   }
@@ -520,15 +520,15 @@ void MSLister::selectvis(const String& timerange,
   catch (MSSelectionError& x) {
     // Re-initialize with the existing MS
     logStream_p << LogOrigin("MSLister","selectvis",WHERE)
-            << LogIO::SEVERE << "Caught exception: " << x.getMesg()
+            << LogIO::SEVERE << "Caught exception: " << x.what()
             << LogIO::POST;
     //initialize(*pMS_p,False);
     throw(AipsError("Error in data selection specification."));
   }
-  catch (AipsError& x) {
+  catch (std::exception& x) {
     // Re-initialize with the existing MS
     logStream_p << LogOrigin("MSLister","selectvis",WHERE)
-            << LogIO::SEVERE << "Caught exception: " << x.getMesg()
+            << LogIO::SEVERE << "Caught exception: " << x.what()
             << LogIO::POST;
     // initialize(*pMS_p,False);
     throw(AipsError("Error in MSLister::selectvis()"));
@@ -1138,8 +1138,8 @@ void MSLister::listData(const int pageRows,
     logStream_p << LogIO::DEBUG1 << "End: MSLister::listData"
                 << LogIO::POST;
   } // end try
-  catch(AipsError& x){
-    logStream_p << LogIO::SEVERE << "Caught exception: " << x.getMesg()
+  catch(std::exception& x){
+    logStream_p << LogIO::SEVERE << "Caught exception: " << x.what()
                 << LogIO::POST;
     throw(AipsError("Error in MSLister::listData"));
   }
@@ -1322,8 +1322,8 @@ void MSLister::polarizationParse(String correlation) {
 	} // end try
 
 	// Catch an exception if a selected correlation does not exist.
-	catch(AipsError& x){
-		logStream_p << LogIO::SEVERE << "Caught exception: " << x.getMesg()
+	catch(std::exception& x){
+		logStream_p << LogIO::SEVERE << "Caught exception: " << x.what()
                 		<< LogIO::POST;
 		throw(AipsError("Error in MSLister::polarizationParse"));
 	}
