@@ -30,7 +30,7 @@
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/ms/MeasurementSets/MeasurementSet.h>
 #include <casacore/ms/MSOper/MSReader.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/iostream.h>
 #include <casacore/casa/OS/Timer.h>
 
@@ -70,8 +70,8 @@ int main(int argc, const char* argv[])
 	}
 	timer.show("read to end : ");
 	cout << "done" << endl;
-    } catch (AipsError& x) {
-	cerr << "Exception : " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cerr << "Exception : " << x.what() << endl;
     } 
  
     return 0;
