@@ -94,9 +94,9 @@ int main(int argc, const char* argv[])
       }
     delete mssel;
   }
-  catch (AipsError& x) 
+  catch (std::exception& x) 
     {
-      cout << "ERROR: " << x.getMesg() << endl;
+      cout << "ERROR: " << x.what() << endl;
       return 1;
     } 
   return 0;
