@@ -93,8 +93,8 @@ int main(int argc, const char* argv[])
     else {
       cout << "failed to parse expression" << endl;
     }
-  } catch (AipsError& x) {
-    cout << "ERROR: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "ERROR: " << x.what() << endl;
     return 1;
   } 
   return 0;
