@@ -180,7 +180,7 @@ public:
   void setPositionRef(MPosition::Types ref);
 
   // Convenience function that returns the number of rows in any of the columns
-  uInt nrow() const {return antennaId_p.nrow();}
+  rownr_t nrow() const {return antennaId_p.nrow();}
 
   // Returns the last row that contains a feed with the specified values.
   // If no matching row can be found, but a match is possible if the validity
@@ -191,22 +191,22 @@ public:
   // Ignore the Feed table rows contained in vector ignoreRows. 
   // focusLengthQ is only compared if this optional column is present and
   // if the value of focusLengthQ is not dimensionless.
-  Int matchFeed(Quantum<Double>& newTimeQ,
-		Quantum<Double>& newIntervalQ,
-		const Int& antId,
-		const Int& fId, // feedId
-		const Int& spwId, 
-		const Quantum<Double>& timeQ,
-		const Quantum<Double>& intervalQ,
-		const Int& numRec,
-		const Array<Quantum<Double> >& beamOffsetQ,
-		const Array<String>& polType,
-		const Array<Complex>& polResp,
-		const Array<Quantum<Double> >& positionQ,
-		const Array<Quantum<Double> >& receptorAngleQ,
-		const Vector<uInt>& ignoreRows,
-		const Quantum<Double>& focusLengthQ=Quantum<Double>() 
-		);
+  Int64 matchFeed(Quantum<Double>& newTimeQ,
+                  Quantum<Double>& newIntervalQ,
+                  Int antId,
+                  Int feedId,
+                  Int spwId, 
+                  const Quantum<Double>& timeQ,
+                  const Quantum<Double>& intervalQ,
+                  Int numReceptor,
+                  const Array<Quantum<Double> >& beamOffsetQ,
+                  const Array<String>& polType,
+                  const Array<Complex>& polResp,
+                  const Array<Quantum<Double> >& positionQ,
+                  const Array<Quantum<Double> >& receptorAngleQ,
+                  const RowNumbers& ignoreRows,
+                  const Quantum<Double>& focusLengthQ=Quantum<Double>() 
+                  );
 
 protected:
   //# default constructor creates a object that is not usable. Use the attach
