@@ -54,15 +54,15 @@ void MSStateColumns::attach(const MSState& msState)
   loadQuant_p.attach(msState, MSState::columnName(MSState::LOAD));
 }
 
-Int MSStateColumns::matchState(const Quantum<Double>& stateCalQ,
-                               const Quantum<Double>& stateLoadQ,
-                               const String& stateObsMode,
-                               const Bool& stateRef,
-                               const Bool& stateSig,
-                               const Int& stateSubScan,
-                               const Quantum<Double>& tolerance,
-                               Int tryRow){
-  uInt r = nrow();
+Int64 MSStateColumns::matchState(const Quantum<Double>& stateCalQ,
+                                 const Quantum<Double>& stateLoadQ,
+                                 const String& stateObsMode,
+                                 const Bool& stateRef,
+                                 const Bool& stateSig,
+                                 const Int& stateSubScan,
+                                 const Quantum<Double>& tolerance,
+                                 Int64 tryRow){
+  rownr_t r = nrow();
   if (r == 0) return -1;
   // Convert the temperatures and tolerance to Kelvin
   const Unit k("K");
@@ -74,14 +74,15 @@ Int MSStateColumns::matchState(const Quantum<Double>& stateCalQ,
   const Double loadInK = stateLoadQ.getValue(k);
   // Main matching loop
   if (tryRow >= 0) {
-    const uInt tr = tryRow;
+    const rownr_t tr = tryRow;
     if (tr >= r) {
       throw(AipsError("MSStateColumns::matchState(...) - "
-                      "the row you suggest is too big"));
+                      "row " + String::toString(tr) +
+                      " you suggest is too big"));
     }
     if (!flagRow()(tr)
-	&& fabs(calQuant()(tr).getValue(k) - calInK) < tolInK
-	&& fabs(loadQuant()(tr).getValue(k) - loadInK) < tolInK
+	&& std::fabs(calQuant()(tr).getValue(k) - calInK) < tolInK
+	&& std::fabs(loadQuant()(tr).getValue(k) - loadInK) < tolInK
 	&& obsMode()(tr) == stateObsMode
 	&& ref()(tr) == stateRef
 	&& sig()(tr) == stateSig
@@ -93,8 +94,8 @@ Int MSStateColumns::matchState(const Quantum<Double>& stateCalQ,
   while (r > 0) {
     r--;
     if (!flagRow()(r)
-	&& fabs(calQuant()(r).getValue(k) - calInK) < tolInK
-	&& fabs(loadQuant()(r).getValue(k) - loadInK) < tolInK
+	&& std::fabs(calQuant()(r).getValue(k) - calInK) < tolInK
+	&& std::fabs(loadQuant()(r).getValue(k) - loadInK) < tolInK
 	&& obsMode()(r) == stateObsMode
 	&& ref()(r) == stateRef
 	&& sig()(r) == stateSig
