@@ -91,8 +91,8 @@ int main() {
       table.markForDelete();
     }
   }
-  catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   }
