@@ -316,7 +316,7 @@ uInt tConstructors(const String& msName)
     Bool thrown=False;
     try {
 	MeasurementSet badms("tMeasurementSet_tmp.badmsTable");
-    } catch (AipsError& x) {
+    } catch (std::exception& x) {
 	thrown = True;
     } 
     if (!thrown) errCount++;
@@ -327,7 +327,7 @@ uInt tConstructors(const String& msName)
     thrown=False;
     try {
 	MeasurementSet badms("tMeasurementSet_tmp.badmsTable","");
-    } catch (AipsError& x) {
+    } catch (std::exception& x) {
 	thrown = True;
     } 
     if (!thrown) errCount++;
@@ -342,7 +342,7 @@ uInt tConstructors(const String& msName)
     try {
 	Table badtab("tMeasurementSet_tmp.badmsTab;e","");
 	MeasurementSet badms(badtab);
-    } catch (AipsError& x) {
+    } catch (std::exception& x) {
 	thrown = True;
     } 
     if (!thrown) errCount++;
@@ -379,7 +379,7 @@ uInt tConstructors(const String& msName)
 	try {
 	    MSAntenna msant2b("tMeasurementSet_tmp.msant2","badAntTD",Table::Old);
 	    msant2b.markForDelete();
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    thrown = True;
 	} 
 	// No exception is thrown here, even though the td name is wrong..
@@ -397,7 +397,7 @@ uInt tConstructors(const String& msName)
 	    SetupNewTable newtab("tMeasurementSet_tmp.msant3b",
 				 MSFeed::requiredTableDesc(),Table::New);
 	    MSAntenna msant3b(newtab,5);
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -425,7 +425,7 @@ uInt tConstructors(const String& msName)
 	    Table tab(newtab4);
 	    tab.markForDelete();
 	    MSAntenna msant4b(tab);
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -440,7 +440,7 @@ uInt tConstructors(const String& msName)
 		Table tab("tMeasurementSet_tmp.badmsantTable","badAntTD",Table::New);
 	    }
 	    MSAntenna msant5b("tMeasurementSet_tmp.badmsantTable");
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -453,7 +453,7 @@ uInt tConstructors(const String& msName)
 	    MSFeed msfeed("msfeed", Table::New);
 	    msfeed.markForDelete();
 	    MSAntenna msant6b(msfeed);
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    thrown = True;
 	} 
 	if (!thrown) errCount++;
@@ -523,7 +523,7 @@ uInt tSetupNewTabError()
     Bool thrown = False;
     try {
 	MeasurementSet ms(setup,0);
-    } catch (AipsError& x) {
+    } catch (std::exception& x) {
 	thrown = True;
     } 
     if (!thrown) {
@@ -544,7 +544,7 @@ uInt tDestructorError(const String& sdmsName)
 	MeasurementSet ms(sdmsName);
 	// remove a column
 	ms.removeColumn(MS::columnName(MS::TIME));
-    } catch (AipsError& x) {
+    } catch (std::exception& x) {
 	thrown = True;
     } 
 
@@ -628,8 +628,8 @@ int main() {
     }
 
     return errCount;
-  } catch (AipsError& x) {
-      cerr << x.getMesg() << endl;
+  } catch (std::exception& x) {
+      cerr << x.what() << endl;
   } 
   return 1;
 }
