@@ -103,7 +103,7 @@ void SDPolarizationHandler::fill(const Record &, const Vector<Int> &stokes)
     if (msPol_p) {
 	*numCorrKey_p = stokes.nelements();
 	Bool found = False;
-	Vector<uInt> foundRows = index_p->getRowNumbers();
+	Vector<rownr_t> foundRows = index_p->getRowNumbers();
 	uInt whichOne = 0;
 	while (!found && whichOne<foundRows.nelements()) {
 	    if (allEQ(stokes, msPolCols_p->corrType()(foundRows(whichOne))) &&
