@@ -59,8 +59,8 @@ int main(int argc, const char* argv[])
       msfitsin.readFitsFile();
     }
   }
-  catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "FAIL!!!" << endl;
     return 1;
   }
