@@ -26,7 +26,7 @@
 //# $Id$
 
 #include <casacore/scimath/Fitting/NonLinearFitLM.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/Matrix.h>
@@ -173,8 +173,8 @@ int main (int argc, const char* argv[])
     delete gauss;
 
     cout << "---------------------------------------------------" << endl;
-  } catch (AipsError& x) {
-    cout << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << x.what() << endl;
   }
   
   return 0;
