@@ -30,14 +30,10 @@
 #include <casacore/scimath/Functionals/Gaussian2D.h>
 #include <casacore/scimath/Functionals/Gaussian3D.h>
 #include <casacore/casa/iostream.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 
 #include <casacore/casa/namespace.h>
 
-namespace casacore {
-   template <class T> class Matrix;
-   template <class T> class Vector;
-}
-
 void printfparameters(Function<Double> &f);
 void printparameters(Matrix<Double> &m);
 void createdata(casacore::Matrix<casacore::Double> &pos, casacore::Vector<casacore::Double> &f, Float range, uInt n,
@@ -78,8 +74,8 @@ int main()
 
   try {
     solution = fitgauss.fit(pos, f);
-  } catch (AipsError& err) {
-    cout << "ERROR: " << err.getMesg() << endl;
+  } catch (std::exception& err) {
+    cout << "ERROR: " << err.what() << endl;
     fail = 1;
   }
 
@@ -118,8 +114,8 @@ int main()
   errors.resize();
   try {
     solution = fitgauss.fit(pos, f);
-  } catch (AipsError& err) {
-    cout << "ERROR: " << err.getMesg() << endl;
+  } catch (std::exception& err) {
+    cout << "ERROR: " << err.what() << endl;
     fail = 1;
   }
 
@@ -170,8 +166,8 @@ int main()
   errors.resize();
   try {
     solution = fitgauss.fit(pos, f);
-  } catch (AipsError& err) {
-    cout << "ERROR: " << err.getMesg() << endl;
+  } catch (std::exception& err) {
+    cout << "ERROR: " << err.what() << endl;
     fail = 1;
   }
 
@@ -212,8 +208,8 @@ int main()
   errors.resize();
   try {
     solution = fitgauss.fit(pos, f, 0.001);
-  } catch (AipsError& err) {
-    cout << "ERROR: " << err.getMesg() << endl;
+  } catch (std::exception& err) {
+    cout << "ERROR: " << err.what() << endl;
     fail = 1;
   }
 
@@ -270,8 +266,8 @@ int main()
 
   try {
     solution = fitgauss.fit(pos, f, 0.01, 256);
-  } catch (AipsError& err) {
-    cout << "ERROR: " << err.getMesg() << endl;
+  } catch (std::exception& err) {
+    cout << "ERROR: " << err.what() << endl;
     fail = 1;
   }
 
