@@ -290,8 +290,8 @@ int main() {
       return 0;
     }
 
-  } catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "Failed" << endl;
     return 1;
   } 
