@@ -36,7 +36,7 @@
 #include <casacore/casa/Arrays/Cube.h>
 #include <casacore/casa/Arrays/Matrix.h>
 #include <casacore/casa/Arrays/Vector.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/BasicSL/Complex.h>
@@ -538,13 +538,13 @@ template <class T, class S>
 class R2C4Doddoddoddeven1 {
 public:
   static Array<T> input() {
-      Array<T> input(IPosition(4,3,5,7,4), 0.0f);
+      Array<T> input(IPosition(4,3,5,7,4), T(0.0));
       input(IPosition(4,0)) = 1.0f;
       return input;
   }
 
     static Array<S> expectedResult() {
-        return Array<S>(IPosition(4,2,5,7,4), Complex(1, 0));
+        return Array<S>(IPosition(4,2,5,7,4), S(1, 0));
   }
 };
 
@@ -553,12 +553,12 @@ template <class T, class S>
 class R2C4Doddoddoddeven2 {
 public:
     static Array<T> input() {
-        return Array<T> (IPosition(4,3,5,7,4), 1.0f);
+        return Array<T> (IPosition(4,3,5,7,4), T(1.0));
     }
     
     static Array<S> expectedResult() {
-        Array<S> expectedResult(IPosition(4,2,5,7,4), Complex(0, 0));
-        expectedResult(IPosition(4,0)) = Complex(3*5*7*4,0);
+        Array<S> expectedResult(IPosition(4,2,5,7,4), S(0, 0));
+        expectedResult(IPosition(4,0)) = S(3*5*7*4,0);
         return expectedResult;
     }
     
@@ -585,14 +585,14 @@ template <class S, class T>
 class C2R1Deven2 {
 public:
   static Array<S> input() {
-      Vector<S> input(5, Complex(0, 0));
-      input(0) = Complex(16.0f, 0.0f);
-      input(2) = Complex(8.0f, 0.0f);
+      Vector<S> input(5, S(0, 0));
+      input(0) = S(16.0f, 0.0f);
+      input(2) = S(8.0f, 0.0f);
       return input;
   }
 
   static Array<T> expectedResult() {
-      Vector<T> expectedResult(8, 2.0f);
+      Vector<T> expectedResult(8, T(2.0));
       expectedResult(0) = 4.0f;
       expectedResult(2) = 0.0f;
       expectedResult(4) = 4.0f;
@@ -605,14 +605,14 @@ template <class S, class T>
 class C2R1Deven3 {
 public:
   static Array<S> input() {
-      Vector<S> input(5, Complex(0, 0));
+      Vector<S> input(5, S(0, 0));
       input(0) = Complex(0.0f, 0.0f);
       input(2) = Complex(0.0f, 4.0f);
       return input;
   }
 
   static Array<T> expectedResult() {
-      Vector<T> expectedResult(8, 0.0f);
+      Vector<T> expectedResult(8, T(0.0));
       expectedResult(1) = -1.0f;
       expectedResult(3) = 1.0f;
       expectedResult(5) = -1.0f;
@@ -624,12 +624,12 @@ template <class S, class T>
 class C2R1Deven4 {
 public:
   static Array<S> input() {
-      Vector<S> input(5, Complex(1, 0));
+      Vector<S> input(5, S(1, 0));
       return input;
   }
 
   static Array<T> expectedResult() {
-      Vector<T> expectedResult(8, 0.0f);
+      Vector<T> expectedResult(8, T(0.0));
       expectedResult(0) = 1.0f;
       return expectedResult;
   }
@@ -638,14 +638,14 @@ template <class S, class T>
 class C2R1Deven5 {
 public:
   static Array<S> input() {
-      Vector<S> input(5, Complex(1, 0));
+      Vector<S> input(5, S(1, 0));
       input(1) = Complex(0,0);
       input(3) = Complex(0,0);
       return input;
   }
 
   static Array<T> expectedResult() {
-      Vector<T> expectedResult(8, 0.0f);
+      Vector<T> expectedResult(8, T(0.0));
       expectedResult(0) = 0.5f;
       expectedResult(4) = 0.5f;
       return expectedResult;
@@ -657,13 +657,13 @@ template <class S, class T>
 class C2R1Dodd1 {
 public:
   static Array<S> input() {
-    Vector<S> input(5, Complex(0, 0));
+    Vector<S> input(5, S(0, 0));
     input(0) = Complex(9, 0);
     return input;
   }
 
   static Array<T> expectedResult() {
-      return Vector<T>(9, 1.0f);
+      return Vector<T>(9, T(1.0));
   }
 };
 
@@ -671,12 +671,12 @@ template <class S, class T>
 class C2R1Dodd2 {
 public:
   static Array<S> input() {
-      Vector<S> input(5, Complex(1, 0));
+      Vector<S> input(5, S(1, 0));
       return input;
   }
 
   static Array<T> expectedResult() {
-      Vector<T> expectedResult(9, 0.0f);
+      Vector<T> expectedResult(9, T(0.0));
       expectedResult(0) = 1.0f;
       return expectedResult;
   }
@@ -686,13 +686,13 @@ template <class S, class T>
 class C2R2Deveneven1 {
 public:
   static Array<S> input() {
-      Matrix<S> input(3, 6, Complex(0, 0));
+      Matrix<S> input(3, 6, S(0, 0));
       input(0,0) = Complex(4*6,0);
       return input;
   }
 
   static Array<T> expectedResult() {
-      Matrix<T> expectedResult(4, 6, 1.0f);
+      Matrix<T> expectedResult(4, 6, T(1.0));
       return expectedResult;
   }
 };
@@ -700,12 +700,12 @@ template <class S, class T>
 class C2R2Deveneven2 {
 public:
   static Array<S> input() {
-      Matrix<S> input(3, 6, Complex(1, 0));
+      Matrix<S> input(3, 6, S(1, 0));
       return input;
   }
 
   static Array<T> expectedResult() {
-      Matrix<T> expectedResult(4, 6, 0.0f);
+      Matrix<T> expectedResult(4, 6, T(0.0));
       expectedResult(0,0) = 1.0f;
       return expectedResult;
   }
@@ -714,7 +714,7 @@ template <class S, class T>
 class C2R2Deveneven3 {
 public:
   static Array<S> input() {
-      Matrix<S> input(3, 6, Complex(0, 0));
+      Matrix<S> input(3, 6, S(0, 0));
       input(0,0) = Complex(24,0);
       input(2,0) = Complex(-24,0);
       input(0,1) = Complex(-24,0);
@@ -726,7 +726,7 @@ public:
   }
 
   static Array<T> expectedResult() {
-      Matrix<T> expectedResult(4, 6, 0.0f);
+      Matrix<T> expectedResult(4, 6, T(0.0));
       expectedResult(0,0) = expectedResult(0,1) = expectedResult(0,2) 
         = expectedResult(0,4) = expectedResult(0,5) = -1.0f;
       expectedResult(0,3) = 5.0f;
@@ -747,13 +747,13 @@ template <class S, class T>
 class C2R2Doddodd1 {
 public:
   static Array<S> input() {
-      Matrix<S> input(2, 5, Complex(0, 0));
-      input(0, 0) = Complex(3*5, 0);
+      Matrix<S> input(2, 5, S(0, 0));
+      input(0, 0) = S(3*5, 0);
       return input;
   }
 
   static Array<T> expectedResult() {
-      Matrix<T> expectedResult(3, 5, 1.0f);
+      Matrix<T> expectedResult(3, 5, T(1.0));
       return expectedResult;
   }
 };
@@ -762,12 +762,12 @@ template <class S, class T>
 class C2R2Doddodd2 {
 public:
   static Array<S> input() {
-      Matrix<S> input(2, 5, Complex(1, 0));
+      Matrix<S> input(2, 5, S(1, 0));
       return input;
   }
 
   static Array<T> expectedResult() {
-      Matrix<T> expectedResult(3, 5, 0.0f);
+      Matrix<T> expectedResult(3, 5, T(0.0));
       expectedResult(0,0) = 1.0f;
       return expectedResult;
   }
@@ -777,7 +777,7 @@ template <class S, class T>
 class C2R2Doddodd3 {
 public:
   static Array<S> input() {
-      Matrix<S> input(2, 5, Complex(0, 0));
+      Matrix<S> input(2, 5, S(0, 0));
       input(1,0) = Complex(0,45);
       input(1,1) = Complex(0,45);
       input(1,2) = Complex(0,45);
@@ -787,7 +787,7 @@ public:
   }
 
   static Array<T> expectedResult() {
-      Matrix<T> expectedResult(3, 5, 0.0f);
+      Matrix<T> expectedResult(3, 5, T(0.0));
       expectedResult(1,0) = -25.9808f;
       expectedResult(2,0) = 25.9808f;
       return expectedResult;
@@ -799,13 +799,13 @@ template <class S, class T>
 class C2R2Devenodd1 {
   public:
     static Array<S> input() {
-        Matrix<S> input(3, 5, Complex(0, 0));
+        Matrix<S> input(3, 5, S(0, 0));
         input(0,0) = Complex(4*5, 0);
         return input;
     }
     
     static Array<T> expectedResult() {
-        Matrix<T> expectedResult(4, 5, 1.0f);
+        Matrix<T> expectedResult(4, 5, T(1.0));
         return expectedResult;
     }
 };
@@ -814,12 +814,12 @@ template <class S, class T>
 class C2R2Devenodd2 {
   public:
     static Array<S> input() {
-        Matrix<S> input(3, 5, Complex(1, 0));
+        Matrix<S> input(3, 5, S(1, 0));
         return input;
     }
     
     static Array<T> expectedResult() {
-        Matrix<T> expectedResult(4, 5, 0.0f);
+        Matrix<T> expectedResult(4, 5, T(0.0));
         expectedResult(0,0) = 1.0f;
         return expectedResult;
     }
@@ -830,13 +830,13 @@ template <class S, class T>
 class C2R2Doddeven1 {
   public:
     static Array<S> input() {
-        Matrix<S> input(2, 6, Complex(0, 0));
+        Matrix<S> input(2, 6, S(0, 0));
         input(0,0) = Complex(3*6, 0);
         return input;
     }
     
     static Array<T> expectedResult() {
-        Matrix<T> expectedResult(3, 6, 1.0f);
+        Matrix<T> expectedResult(3, 6, T(1.0));
         return expectedResult;
     }
 };
@@ -845,12 +845,12 @@ template <class S, class T>
 class C2R2Doddeven2 {
   public:
     static Array<S> input() {
-        Matrix<S> input(2, 6, Complex(1, 0));
+        Matrix<S> input(2, 6, S(1, 0));
         return input;
     }
     
     static Array<T> expectedResult() {
-        Matrix<T> expectedResult(3, 6, 0.0f);
+        Matrix<T> expectedResult(3, 6, T(0.0));
         expectedResult(0,0) = 1.0f;
         return expectedResult;
     }
@@ -860,13 +860,13 @@ template <class S, class T>
 class C2R3Deveneveneven1 {
   public:
     static Array<S> input() {
-        Cube<S> input(3, 6, 2, Complex(0, 0));
+        Cube<S> input(3, 6, 2, S(0, 0));
         input(0,0,0) = Complex(4*6*2,0);
         return input;
     }
     
     static Array<T> expectedResult() {
-        Cube<T> expectedResult(4, 6, 2, 1.0f);
+        Cube<T> expectedResult(4, 6, 2, T(1.0));
         return expectedResult;
     }
 };
@@ -874,12 +874,12 @@ template <class S, class T>
 class C2R3Deveneveneven2 {
   public:
     static Array<S> input() {
-        Cube<S> input(3, 6, 2, Complex(1, 0));
+        Cube<S> input(3, 6, 2, S(1, 0));
         return input;
     }
     
     static Array<T> expectedResult() {
-        Cube<T> expectedResult(4, 6, 2, 0.0f);
+        Cube<T> expectedResult(4, 6, 2, T(0.0));
         expectedResult(0,0,0) = 1.0f;
         return expectedResult;
     }
@@ -889,13 +889,13 @@ template <class S, class T>
 class C2R3Doddoddodd1 {
   public:
     static Array<S> input() {
-        Cube<S> input(2, 5, 7, Complex(0, 0));
+        Cube<S> input(2, 5, 7, S(0, 0));
         input(0,0,0) = Complex(3*5*7,0);
         return input;
     }
     
     static Array<T> expectedResult() {
-        Cube<T> expectedResult(3, 5, 7, 1.0f);
+        Cube<T> expectedResult(3, 5, 7, T(1.0));
         return expectedResult;
     }
 };
@@ -903,12 +903,12 @@ template <class S, class T>
 class C2R3Doddoddodd2 {
   public:
     static Array<S> input() {
-        Cube<S> input(2, 5, 7, Complex(1, 0));
+        Cube<S> input(2, 5, 7, S(1, 0));
         return input;
     }
     
     static Array<T> expectedResult() {
-        Cube<T> expectedResult(3, 5, 7, 0.0f);
+        Cube<T> expectedResult(3, 5, 7, T(0.0));
         expectedResult(0,0,0) = 1.0f;
         return expectedResult;
     }
@@ -921,9 +921,9 @@ class C2R4Doddoddoddeven1 {
     static Array<S> input() {
 #if PERFORMANCE_TEST
       // Useful to test how the use of threads effects CPU usage
-      Array<S> input(IPosition(4,20,500,70,20), Complex(0, 0));
+      Array<S> input(IPosition(4,20,500,70,20), S(0, 0));
 #else
-      Array<S> input(IPosition(4,2,5,7,2), Complex(0, 0));
+      Array<S> input(IPosition(4,2,5,7,2), S(0, 0));
 #endif
       input(IPosition(4,0)) = Complex(3*5*7*2,0);
       return input;
@@ -933,7 +933,7 @@ class C2R4Doddoddoddeven1 {
 #if PERFORMANCE_TEST
       Array<T> expectedResult(IPosition(4, 38, 500, 70, 20));
 #else
-      Array<T> expectedResult(IPosition(4,3,5,7,2), 1.0f);
+      Array<T> expectedResult(IPosition(4,3,5,7,2), T(1.0));
 #endif
         expectedResult = 1.0f;
         return expectedResult;
@@ -944,12 +944,12 @@ template <class S, class T>
 class C2R4Doddoddoddeven2 {
   public:
     static Array<S> input() {
-        Array<S> input(IPosition(4,2,5,7,2), Complex(1, 0));
+        Array<S> input(IPosition(4,2,5,7,2), S(1, 0));
         return input;
     }
     
     static Array<T> expectedResult() {
-        Array<T> expectedResult(IPosition(4,3,5,7,2), 0.0f);
+        Array<T> expectedResult(IPosition(4,3,5,7,2), T(0.0));
         expectedResult = 0.0f;
         expectedResult(IPosition(4,0)) = 1.0f;
         return expectedResult;
@@ -961,13 +961,13 @@ template <class S>
 class C2C1Deven1 {
   public:
     static Array<S> input() {
-        Vector<S> input(8, Complex(0, 0));
+        Vector<S> input(8, S(0, 0));
         input(0) = Complex(1.0f, 0.0f);
         return input;
     }
 
     static Array<S> expectedResult() {
-        Vector<S> expectedResult(8, Complex(1, 0));
+        Vector<S> expectedResult(8, S(1, 0));
         return expectedResult;
     }
 };
@@ -976,12 +976,12 @@ template <class S>
 class C2C1Deven2 {
   public:
     static Array<S> input() {
-        Vector<S> input(8, Complex(1, 0));
+        Vector<S> input(8, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Vector<S> expectedResult(8, Complex(0, 0));
+        Vector<S> expectedResult(8, S(0, 0));
         expectedResult(0) = Complex(8,0);
         return expectedResult;
     }
@@ -991,7 +991,7 @@ template <class S>
 class C2C1Deven3 {
   public:
     static Array<S> input() {
-        Vector<S> input(8, Complex(-1, 0));
+        Vector<S> input(8, S(-1, 0));
         input(0) = Complex(1, 0);
         input(2) = Complex(1, 0);
         input(4) = Complex(1, 0);
@@ -1000,7 +1000,7 @@ class C2C1Deven3 {
     }
 
     static Array<S> expectedResult() {
-        Vector<S> expectedResult(8, Complex(0, 0));
+        Vector<S> expectedResult(8, S(0, 0));
         expectedResult(4) = Complex(8,0);
         return expectedResult;
     }
@@ -1010,7 +1010,7 @@ template <class S>
 class C2C1Deven4 {
   public:
     static Array<S> input() {
-        Vector<S> input(8, Complex(0, 0));
+        Vector<S> input(8, S(0, 0));
         input(1) = Complex(1, 0);
         input(3) = Complex(-1,0);
         input(5) = Complex(1, 0);
@@ -1019,7 +1019,7 @@ class C2C1Deven4 {
     }
 
     static Array<S> expectedResult() {
-        Vector<S> expectedResult(8, Complex(0, 0));
+        Vector<S> expectedResult(8, S(0, 0));
         expectedResult(2) = Complex(0,-4);
         expectedResult(6) = Complex(0,4);
         return expectedResult;
@@ -1032,13 +1032,13 @@ template <class S>
 class C2C1Dodd1 {
   public:
     static Array<S> input() {
-        Vector<S> input(7, Complex(0, 0));
+        Vector<S> input(7, S(0, 0));
         input(0) = Complex(1.0f, 0.0f);
         return input;
     }
 
     static Array<S> expectedResult() {
-        Vector<S> expectedResult(7, Complex(1, 0));
+        Vector<S> expectedResult(7, S(1, 0));
         return expectedResult;
     }
 };
@@ -1047,12 +1047,12 @@ template <class S>
 class C2C1Dodd2 {
   public:
     static Array<S> input() {
-        Vector<S> input(7, Complex(1, 0));
+        Vector<S> input(7, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Vector<S> expectedResult(7, Complex(0, 0));
+        Vector<S> expectedResult(7, S(0, 0));
         expectedResult(0) = Complex(7,0);
         return expectedResult;
     }
@@ -1062,13 +1062,13 @@ template <class S>
 class C2C2Deveneven1 {
   public:
     static Array<S> input() {
-        Matrix<S> input(4, 6, Complex(0, 0));
+        Matrix<S> input(4, 6, S(0, 0));
         input(0,0) = Complex(1,0);
         return input;
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(4, 6, Complex(1, 0));
+        Matrix<S> expectedResult(4, 6, S(1, 0));
         return expectedResult;
     }
 };
@@ -1076,12 +1076,12 @@ template <class S>
 class C2C2Deveneven2 {
   public:
     static Array<S> input() {
-        Matrix<S> input(4, 6, Complex(1, 0));
+        Matrix<S> input(4, 6, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(4, 6, Complex(0, 0));
+        Matrix<S> expectedResult(4, 6, S(0, 0));
         expectedResult(0,0) = Complex(24,0);
         return expectedResult;
     }
@@ -1090,7 +1090,7 @@ template <class S>
 class C2C2Deveneven3 {
   public:
     static Array<S> input() {
-        Matrix<S> input(4, 6, Complex(0, 0));
+        Matrix<S> input(4, 6, S(0, 0));
         input(1,1) = Complex(1,1);
         input(1,3) = Complex(1,1);
         input(1,5) = Complex(1,1);
@@ -1098,7 +1098,7 @@ class C2C2Deveneven3 {
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(4, 6, Complex(0, 0));
+        Matrix<S> expectedResult(4, 6, S(0, 0));
         expectedResult(0,0) = expectedResult(2,3) = Complex(3,3);
         expectedResult(0,3) = expectedResult(2,0) = Complex(-3,-3);
         expectedResult(1,3) = expectedResult(3,0) = Complex(-3,3);
@@ -1112,13 +1112,13 @@ template <class S>
 class C2C2Doddodd1 {
   public:
     static Array<S> input() {
-        Matrix<S> input(3, 5, Complex(0, 0));
+        Matrix<S> input(3, 5, S(0, 0));
         input(0,0) = Complex(1,0);
         return input;
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(3, 5, Complex(1, 0));
+        Matrix<S> expectedResult(3, 5, S(1, 0));
         return expectedResult;
     }
 };
@@ -1126,12 +1126,12 @@ template <class S>
 class C2C2Doddodd2 {
   public:
     static Array<S> input() {
-        Matrix<S> input(3, 5, Complex(1, 0));
+        Matrix<S> input(3, 5, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(3, 5, Complex(0, 0));
+        Matrix<S> expectedResult(3, 5, S(0, 0));
         expectedResult(0,0) = Complex(15,0);
         return expectedResult;
     }
@@ -1141,13 +1141,13 @@ template <class S>
 class C2C2Devenodd1 {
   public:
     static Array<S> input() {
-        Matrix<S> input(4, 5, Complex(0, 0));
+        Matrix<S> input(4, 5, S(0, 0));
         input(0,0) = Complex(1,0);
         return input;
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(4, 5, Complex(1, 0));
+        Matrix<S> expectedResult(4, 5, S(1, 0));
         return expectedResult;
     }
 };
@@ -1155,12 +1155,12 @@ template <class S>
 class C2C2Devenodd2 {
   public:
     static Array<S> input() {
-        Matrix<S> input(4, 5, Complex(1, 0));
+        Matrix<S> input(4, 5, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Matrix<S> expectedResult(4, 5, Complex(0, 0));
+        Matrix<S> expectedResult(4, 5, S(0, 0));
         expectedResult(0,0) = Complex(20,0);
         return expectedResult;
     }
@@ -1213,12 +1213,12 @@ template <class S>
 class C2C3Doddeveneven2 {
   public:
     static Array<S> input() {
-        Cube<S> input(4, 6, 8, Complex(1, 0));
+        Cube<S> input(4, 6, 8, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Cube<S> expectedResult(4, 6, 8, Complex(0, 0));
+        Cube<S> expectedResult(4, 6, 8, S(0, 0));
         expectedResult(0,0,0) = Complex(4*6*8,0);
         return expectedResult;
     }
@@ -1228,13 +1228,13 @@ template <class S>
 class C2C3Doddoddodd1 {
   public:
     static Array<S> input() {
-        Cube<S> input(3, 5, 7, Complex(0, 0));
+        Cube<S> input(3, 5, 7, S(0, 0));
         input(0,0,0) = Complex(1,0);
         return input;
     }
 
     static Array<S> expectedResult() {
-        Cube<S> expectedResult(3, 5, 7, Complex(1, 0));
+        Cube<S> expectedResult(3, 5, 7, S(1, 0));
         return expectedResult;
     }
 };
@@ -1242,12 +1242,12 @@ template <class S>
 class C2C3Doddoddodd2 {
   public:
     static Array<S> input() {
-        Cube<S> input(3, 5, 7, Complex(1, 0));
+        Cube<S> input(3, 5, 7, S(1, 0));
         return input;
     }
 
     static Array<S> expectedResult() {
-        Cube<S> expectedResult(3, 5, 7, Complex(0, 0));
+        Cube<S> expectedResult(3, 5, 7, S(0, 0));
         expectedResult(0,0,0) = Complex(3*5*7,0);
         return expectedResult;
     }
@@ -2304,8 +2304,8 @@ int main()
       run_tests<Double, DComplex>();
 
   }
-  catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
