@@ -1286,8 +1286,8 @@ int main() {
 			      5*FLT_EPSILON), AipsError);
     }
   }
-  catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
