@@ -135,8 +135,8 @@ int main()
       s.printSummaryList(cout,"Test of s.printSummaryList");
 
 
-    } catch (AipsError& x) {
-        cout << x.getMesg() << endl;
+    } catch (std::exception& x) {
+        cout << x.what() << endl;
         return 1;                       // unexpected error
     } 
     return 0;                           // exit with success status
