@@ -57,9 +57,9 @@ public:
     virtual DataManager *clone() const;
     virtual String dataManagerType() const;
     virtual String dataManagerName() const;
-    virtual void create(uInt aNrRows);
-    virtual void open(uInt aRowNr, AipsIO &ios);
-    virtual void resync(uInt aRowNr);
+    virtual void create64(rownr_t aNrRows);
+    virtual rownr_t open64(rownr_t aRowNr, AipsIO &ios);
+    virtual rownr_t resync64(rownr_t aRowNr);
     virtual Bool flush(AipsIO &, Bool doFsync);
     virtual DataManagerColumn *makeScalarColumn(const String &aName,
                                                 int aDataType,
@@ -71,10 +71,10 @@ public:
                                                 int aDataType,
                                                 const String &aDataTypeID);
     virtual void deleteManager();
-    virtual void addRow(uInt aNrRows);
+    virtual void addRow64(rownr_t aNrRows);
     static DataManager *makeObject(const String &aDataManType,
                                    const Record &spec);
-    uInt getNrRows();
+    rownr_t getNrRows();
 
 private:
 	 class impl;
