@@ -42,7 +42,7 @@
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
 SSMColumn::SSMColumn (SSMBase* aParent, int aDataType, uInt aColNr)
-: StManColumn    (aDataType),
+: StManColumnBase(aDataType),
   itsSSMPtr      (aParent),
   itsExternalSizeBytes(0),
   itsExternalSizeBits (0),
@@ -73,38 +73,38 @@ void SSMColumn::setMaxLength (uInt maxLength)
     init();
 }
 
-uInt SSMColumn::ndim (uInt)
+uInt SSMColumn::ndim (rownr_t)
 {
     return itsShape.nelements();
 }
 
-IPosition SSMColumn::shape (uInt)
+IPosition SSMColumn::shape (rownr_t)
 {
     return itsShape;
 }
 
-void SSMColumn::doCreate(uInt)
+void SSMColumn::doCreate(rownr_t)
 {
 }
 
-void SSMColumn::getFile(uInt)
+void SSMColumn::getFile(rownr_t)
 {
 }
 
-void SSMColumn::addRow (uInt aNewNrRows, uInt, Bool doInit)
+void SSMColumn::addRow (rownr_t aNewNrRows, rownr_t, Bool doInit)
 {
   if (doInit  &&  dataType() == TpString) {
-    uInt aRowNr=0;
-    uInt aNrRows=aNewNrRows;
+    rownr_t aRowNr=0;
+    rownr_t aNrRows=aNewNrRows;
     
     while (aNrRows > 0) {
-      uInt  aStartRow;
-      uInt  anEndRow;
-      char* aValPtr;
+      rownr_t aStartRow;
+      rownr_t anEndRow;
+      char*   aValPtr;
       aValPtr = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                                  columnName());
       aRowNr = anEndRow+1;
-      uInt aNr = anEndRow-aStartRow+1;
+      rownr_t aNr = anEndRow-aStartRow+1;
       aNrRows -= aNr;
       memset(aValPtr, 0, aNr * itsExternalSizeBytes);
       itsSSMPtr->setBucketDirty();
@@ -112,11 +112,11 @@ void SSMColumn::addRow (uInt aNewNrRows, uInt, Bool doInit)
   }
 }
 
-void SSMColumn::deleteRow(uInt aRowNr)
+void SSMColumn::deleteRow(rownr_t aRowNr)
 {
-  char* aValue;
-  uInt  aSRow;
-  uInt  anERow;
+  char*   aValue;
+  rownr_t aSRow;
+  rownr_t anERow;
   int aDT = dataType();
 
   if (aDT == TpString  &&  itsMaxLen == 0) {
@@ -139,25 +139,23 @@ void SSMColumn::deleteRow(uInt aRowNr)
 
   if (isBool  && aRowNr < anERow) {
     Bool aVal;
-    getBoolV(aRowNr,&aVal);
+    getBool(aRowNr,&aVal);
   }
 
   // first check if aRowNr is in cache, if not, fill cache
   // In both cases remove row from cache
-  uInt  aStartRow = columnCache().start();
-  uInt  anEndRow  = columnCache().end();
+  rownr_t aStartRow = columnCache().start();
+  rownr_t anEndRow  = columnCache().end();
 
   // Remove from cache if needed
   if (aRowNr >= aStartRow  &&  aRowNr <= anEndRow) {
     //  remove the row in itsData if not last
     if (aRowNr < anEndRow) {
-      char* aToPtr  = getDataPtr() + (aRowNr-aStartRow)
-	* itsLocalSize;
-      char* aFromPtr = getDataPtr() + (aRowNr+1-aStartRow)
-	* itsLocalSize;
+      char* aToPtr   = getDataPtr() + (aRowNr-aStartRow) * itsLocalSize;
+      char* aFromPtr = getDataPtr() + (aRowNr+1-aStartRow) * itsLocalSize;
 
       // decrement anEndrow
-      uInt aLength = (anEndRow - aRowNr) * itsLocalSize;
+      uInt64 aLength = (anEndRow - aRowNr) * itsLocalSize;
       memmove(aToPtr,aFromPtr,aLength);
     }
     // Fill cache again with actual itsData.
@@ -181,76 +179,77 @@ void SSMColumn::deleteRow(uInt aRowNr)
   }
 }
 
-void SSMColumn::shiftRows(char* aValue, uInt aRowNr, uInt aSRow, uInt anERow)
+void SSMColumn::shiftRows(char* aValue, rownr_t aRowNr,
+                          rownr_t aSRow, rownr_t anERow)
 {
   // Shift from aRrowNr on 1 to the left.
   char* aToPtr = aValue + (aRowNr-aSRow) * itsExternalSizeBytes;
   char* aFromPtr = aToPtr + itsExternalSizeBytes;
-  uInt aLength = (anERow - aRowNr) * itsExternalSizeBytes;
+  uInt64 aLength = (anERow - aRowNr) * itsExternalSizeBytes;
   memmove(aToPtr,aFromPtr,aLength);
   // Clear last entry (so a putString on a new row finds zeroes).
   memset (aToPtr + aLength, 0, itsExternalSizeBytes);
 }
 
 
-void SSMColumn::getBoolV (uInt aRowNr, Bool* aValue)
+void SSMColumn::getBool (rownr_t aRowNr, Bool* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<Bool*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getuCharV (uInt aRowNr, uChar* aValue)
+void SSMColumn::getuChar (rownr_t aRowNr, uChar* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<uChar*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getShortV (uInt aRowNr, Short* aValue)
+void SSMColumn::getShort (rownr_t aRowNr, Short* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<Short*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getuShortV (uInt aRowNr, uShort* aValue)
+void SSMColumn::getuShort (rownr_t aRowNr, uShort* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<uShort*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getIntV (uInt aRowNr, Int* aValue)
+void SSMColumn::getInt (rownr_t aRowNr, Int* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<Int*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getuIntV (uInt aRowNr, uInt* aValue)
+void SSMColumn::getuInt (rownr_t aRowNr, uInt* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<uInt*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getInt64V (uInt aRowNr, Int64* aValue)
+void SSMColumn::getInt64 (rownr_t aRowNr, Int64* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<Int64*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getfloatV (uInt aRowNr, float* aValue)
+void SSMColumn::getfloat (rownr_t aRowNr, float* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<float*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getdoubleV (uInt aRowNr, double* aValue)
+void SSMColumn::getdouble (rownr_t aRowNr, double* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<double*>(itsData)[aRowNr-columnCache().start()];
 }
-void SSMColumn::getComplexV (uInt aRowNr, Complex* aValue)
+void SSMColumn::getComplex (rownr_t aRowNr, Complex* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<Complex*>(itsData)[aRowNr-columnCache().start()];
 }
 
-void SSMColumn::getDComplexV (uInt aRowNr,DComplex* aValue)
+void SSMColumn::getDComplex (rownr_t aRowNr,DComplex* aValue)
 {
   getValue(aRowNr);
   *aValue = static_cast<DComplex*>(itsData)[aRowNr-columnCache().start()];
 }
 
-void SSMColumn::getStringV (uInt aRowNr, String* aValue)
+void SSMColumn::getString (rownr_t aRowNr, String* aValue)
 {
   if (itsMaxLen > 0) {
     // Allocate the maximum number of characters needed
@@ -258,8 +257,8 @@ void SSMColumn::getStringV (uInt aRowNr, String* aValue)
     // Should be changed to use real Char*
     aValue->alloc(itsMaxLen+1);
     char* sp = const_cast<char*>(aValue->chars());
-    uInt  aStartRow;
-    uInt  anEndRow;
+    rownr_t aStartRow;
+    rownr_t anEndRow;
     char* buf = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                                  columnName());
     itsReadFunc (sp, buf+(aRowNr-aStartRow)*itsExternalSizeBytes,
@@ -296,11 +295,11 @@ void SSMColumn::getStringV (uInt aRowNr, String* aValue)
   }
 }
 
-Char* SSMColumn::getRowValue(Int* data, uInt aRowNr)
+Char* SSMColumn::getRowValue(Int* data, rownr_t aRowNr)
 {
-  uInt  aStartRow;
-  uInt  anEndRow;
-  char* aValue;
+  rownr_t aStartRow;
+  rownr_t anEndRow;
+  char*   aValue;
   aValue = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                             columnName());
   itsReadFunc (data, aValue+(aRowNr-aStartRow)*itsExternalSizeBytes,
@@ -308,12 +307,12 @@ Char* SSMColumn::getRowValue(Int* data, uInt aRowNr)
   return aValue+(aRowNr-aStartRow)*itsExternalSizeBytes;
 }
 
-void SSMColumn::getValue(uInt aRowNr)
+void SSMColumn::getValue(rownr_t aRowNr)
 {
   if (aRowNr < columnCache().start()  ||  aRowNr > columnCache().end()) {
-    uInt  aStartRow;
-    uInt  anEndRow;
-    char* aValue;
+    rownr_t aStartRow;
+    rownr_t anEndRow;
+    char*   aValue;
     aValue = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                               columnName());
     itsReadFunc (getDataPtr(), aValue, (anEndRow-aStartRow+1) * itsNrCopy);
@@ -321,16 +320,16 @@ void SSMColumn::getValue(uInt aRowNr)
   }
 }
 
-void SSMColumn::putBoolV (uInt aRowNr, const Bool* aValue)
+void SSMColumn::putBool (rownr_t aRowNr, const Bool* aValue)
 {
-  uInt  aStartRow;
-  uInt  anEndRow;
-  char* aDummy;
+  rownr_t aStartRow;
+  rownr_t anEndRow;
+  char*   aDummy;
 
   aDummy = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                             columnName());
 
-  uInt anOff    = aRowNr-aStartRow;
+  uInt64 anOff    = aRowNr-aStartRow;
 
   Conversion::boolToBit(aDummy+(anOff/8),
 			aValue,anOff%8,1);
@@ -341,7 +340,7 @@ void SSMColumn::putBoolV (uInt aRowNr, const Bool* aValue)
       *aValue;
   }
 }
-void SSMColumn::putuCharV (uInt aRowNr, const uChar* aValue)
+void SSMColumn::putuChar (rownr_t aRowNr, const uChar* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -349,7 +348,7 @@ void SSMColumn::putuCharV (uInt aRowNr, const uChar* aValue)
       *aValue;
   }
 }
-void SSMColumn::putShortV (uInt aRowNr, const Short* aValue)
+void SSMColumn::putShort (rownr_t aRowNr, const Short* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -357,7 +356,7 @@ void SSMColumn::putShortV (uInt aRowNr, const Short* aValue)
       *aValue;
   }
 }
-void SSMColumn::putuShortV (uInt aRowNr, const uShort* aValue)
+void SSMColumn::putuShort (rownr_t aRowNr, const uShort* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -365,7 +364,7 @@ void SSMColumn::putuShortV (uInt aRowNr, const uShort* aValue)
       *aValue;
   }
 }
-void SSMColumn::putIntV (uInt aRowNr, const Int* aValue)
+void SSMColumn::putInt (rownr_t aRowNr, const Int* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -373,7 +372,7 @@ void SSMColumn::putIntV (uInt aRowNr, const Int* aValue)
       *aValue;
   }
 }
-void SSMColumn::putuIntV (uInt aRowNr, const uInt* aValue)
+void SSMColumn::putuInt (rownr_t aRowNr, const uInt* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -381,7 +380,7 @@ void SSMColumn::putuIntV (uInt aRowNr, const uInt* aValue)
       *aValue;
   }
 }
-void SSMColumn::putInt64V (uInt aRowNr, const Int64* aValue)
+void SSMColumn::putInt64 (rownr_t aRowNr, const Int64* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -389,7 +388,7 @@ void SSMColumn::putInt64V (uInt aRowNr, const Int64* aValue)
       *aValue;
   }
 }
-void SSMColumn::putfloatV (uInt aRowNr, const float* aValue)
+void SSMColumn::putfloat (rownr_t aRowNr, const float* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -397,7 +396,7 @@ void SSMColumn::putfloatV (uInt aRowNr, const float* aValue)
       *aValue;
   }
 }
-void SSMColumn::putdoubleV (uInt aRowNr, const double* aValue)
+void SSMColumn::putdouble (rownr_t aRowNr, const double* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -405,7 +404,7 @@ void SSMColumn::putdoubleV (uInt aRowNr, const double* aValue)
       *aValue;
   }
 }
-void SSMColumn::putComplexV (uInt aRowNr, const Complex* aValue)
+void SSMColumn::putComplex (rownr_t aRowNr, const Complex* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -414,7 +413,7 @@ void SSMColumn::putComplexV (uInt aRowNr, const Complex* aValue)
   }
 }
 
-void SSMColumn::putDComplexV (uInt aRowNr, const DComplex* aValue)
+void SSMColumn::putDComplex (rownr_t aRowNr, const DComplex* aValue)
 {
   putValue(aRowNr,aValue);
   if (aRowNr >= columnCache().start()  &&  aRowNr <= columnCache().end()) {
@@ -423,14 +422,14 @@ void SSMColumn::putDComplexV (uInt aRowNr, const DComplex* aValue)
   }
 }
 
-void SSMColumn::putStringV (uInt aRowNr, const String* aValue)
+void SSMColumn::putString (rownr_t aRowNr, const String* aValue)
 {
   // Fixed length strings are written directly.
   if (itsMaxLen > 0) {
-    uInt  aStartRow;
-    uInt  anEndRow;
-    char* aDummy = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
-                                    columnName());
+    rownr_t aStartRow;
+    rownr_t anEndRow;
+    char*   aDummy = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
+                                      columnName());
     itsWriteFunc (aDummy+(aRowNr-aStartRow)*itsExternalSizeBytes,
 		  aValue->chars(), min(itsMaxLen, aValue->length()+1));
     itsSSMPtr->setBucketDirty();
@@ -464,23 +463,23 @@ void SSMColumn::putStringV (uInt aRowNr, const String* aValue)
   }
 }
 
-void SSMColumn::putValue(uInt aRowNr, const void* aValue)
+void SSMColumn::putValue(rownr_t aRowNr, const void* aValue)
 {
-  uInt  aStartRow;
-  uInt  anEndRow;
-  char* aDummy = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
-                                  columnName());
+  rownr_t aStartRow;
+  rownr_t anEndRow;
+  char*   aDummy = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
+                                    columnName());
   itsWriteFunc (aDummy+(aRowNr-aStartRow)*itsExternalSizeBytes,
   		aValue, itsNrCopy);
   itsSSMPtr->setBucketDirty();
 }
 
-void SSMColumn::putValueShortString(uInt aRowNr, const void* aValue,
+void SSMColumn::putValueShortString(rownr_t aRowNr, const void* aValue,
 				    const String& string)
 {
-  uInt  aStartRow;
-  uInt  anEndRow;
-  char* aDummy;
+  rownr_t aStartRow;
+  rownr_t anEndRow;
+  char*   aDummy;
 
   aDummy = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                             columnName());
@@ -492,231 +491,70 @@ void SSMColumn::putValueShortString(uInt aRowNr, const void* aValue,
   itsSSMPtr->setBucketDirty();
 }
 
-void SSMColumn::getScalarColumnBoolV     (Vector<Bool>* aDataPtr)
+void SSMColumn::getScalarColumnV (ArrayBase& aDataPtr)
 {
-  Bool deleteIt;
-  Bool* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnuCharV    (Vector<uChar>* aDataPtr)
-{
-  Bool deleteIt;
-  uChar* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnShortV    (Vector<Short>* aDataPtr)
-{
-  Bool deleteIt;
-  Short* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-
-}
-
-void SSMColumn::getScalarColumnuShortV   (Vector<uShort>* aDataPtr)
-{
-  Bool deleteIt;
-  uShort* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnIntV      (Vector<Int>* aDataPtr)
-{
-  Bool deleteIt;
-  Int* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnuIntV     (Vector<uInt>* aDataPtr)
-{
-  Bool deleteIt;
-  uInt* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnInt64V    (Vector<Int64>* aDataPtr)
-{
-  Bool deleteIt;
-  Int64* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnfloatV    (Vector<float>* aDataPtr)
-{
-  Bool deleteIt;
-  float* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumndoubleV   (Vector<double>* aDataPtr)
-{
-  Bool deleteIt;
-  double* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnComplexV  (Vector<Complex>* aDataPtr)
-{
-  Bool deleteIt;
-  Complex* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnDComplexV (Vector<DComplex>* aDataPtr)
-{
-  Bool deleteIt;
-  DComplex* anArray=aDataPtr->getStorage(deleteIt);
-  getColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->putStorage(anArray,deleteIt);
-}
-
-void SSMColumn::getScalarColumnStringV (Vector<String>* aDataPtr)
-{
-  for (uInt i=0;i<aDataPtr->nelements(); i++) {
-    getStringV(i,&(*aDataPtr)(i));
+  if (dtype() == TpString) {
+    Vector<String>& vec = static_cast<Vector<String>&>(aDataPtr);
+    for (uInt64 i=0; i<aDataPtr.nelements(); i++) {
+      getString (i, &(vec[i]));
+    }
+  } else {
+    Bool deleteIt;
+    void* anArray = aDataPtr.getVStorage(deleteIt);
+    getColumnValue(anArray, aDataPtr.nelements());
+    aDataPtr.putVStorage(anArray, deleteIt);
   }
 }
 
-void SSMColumn::getColumnValue(void* anArray,uInt aNrRows)
+void SSMColumn::getColumnValue(void* anArray,rownr_t aNrRows)
 {
-  char* aDataPtr = static_cast<char*>(anArray);
-  uInt aRowNr=0;
-  Int rowsToDo = aNrRows;
+  char*   aDataPtr = static_cast<char*>(anArray);
+  rownr_t aRowNr=0;
+  rownr_t rowsToDo = aNrRows;
   
   while (rowsToDo > 0) {
-    uInt  aStartRow;
-    uInt  anEndRow;
-    char* aValue;
+    rownr_t aStartRow;
+    rownr_t anEndRow;
+    char*   aValue;
     aValue = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                               columnName());
     aRowNr = anEndRow+1;
-    uInt aNr = anEndRow-aStartRow+1;
+    rownr_t aNr = anEndRow-aStartRow+1;
     rowsToDo -= aNr;
     itsReadFunc (aDataPtr, aValue, aNr * itsNrCopy);
     aDataPtr += aNr * itsLocalSize;
   }
 }
 
-void SSMColumn::putScalarColumnBoolV     (const Vector<Bool>* aDataPtr)
+void SSMColumn::putScalarColumnV (const ArrayBase& aDataPtr)
 {
-  Bool deleteIt;
-  const Bool* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnuCharV    (const Vector<uChar>* aDataPtr)
-{
-  Bool deleteIt;
-  const uChar* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnShortV    (const Vector<Short>* aDataPtr)
-{
-  Bool deleteIt;
-  const Short* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnuShortV   (const Vector<uShort>* aDataPtr)
-{
-  Bool deleteIt;
-  const uShort* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnIntV      (const Vector<Int>* aDataPtr)
-{
-  Bool deleteIt;
-  const Int* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnuIntV     (const Vector<uInt>* aDataPtr)
-{
-  Bool deleteIt;
-  const uInt* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnInt64V    (const Vector<Int64>* aDataPtr)
-{
-  Bool deleteIt;
-  const Int64* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnfloatV    (const Vector<float>* aDataPtr)
-{
-  Bool deleteIt;
-  const float* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumndoubleV   (const Vector<double>* aDataPtr)
-{
-  Bool deleteIt;
-  const double* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnComplexV  (const Vector<Complex>* aDataPtr)
-{
-  Bool deleteIt;
-  const Complex* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnDComplexV (const Vector<DComplex>* aDataPtr)
-{
-  Bool deleteIt;
-  const DComplex* anArray=aDataPtr->getStorage(deleteIt);
-  putColumnValue(anArray,aDataPtr->nelements());
-  aDataPtr->freeStorage(anArray,deleteIt);
-}
-
-void SSMColumn::putScalarColumnStringV (const Vector<String>* aDataPtr)
-{
-  for (uInt i=0;i<aDataPtr->nelements(); i++) {
-    putStringV(i,&(*aDataPtr)(i));
+  if (dtype() == TpString) {
+    const Vector<String>& vec = static_cast<const Vector<String>&>(aDataPtr);
+    for (uInt64 i=0 ; i<aDataPtr.nelements(); i++) {
+      putString (i, &(vec[i]));
+    }
+  } else {
+    Bool deleteIt;
+    const void* anArray = aDataPtr.getVStorage(deleteIt);
+    putColumnValue (anArray, aDataPtr.nelements());
+    aDataPtr.freeVStorage(anArray, deleteIt);
   }
 }
 
-void SSMColumn::putColumnValue(const void* anArray,uInt aNrRows)
+void SSMColumn::putColumnValue(const void* anArray,rownr_t aNrRows)
 {
   const char* aDataPtr = static_cast<const char*>(anArray);
-  uInt aRowNr=0;
-  Int rowsToDo=aNrRows;
+  rownr_t aRowNr=0;
+  rownr_t rowsToDo=aNrRows;
 
   while (rowsToDo > 0) {
-    uInt  aStartRow;
-    uInt  anEndRow;
-    char* aValPtr;
+    rownr_t aStartRow;
+    rownr_t anEndRow;
+    char*   aValPtr;
     aValPtr = itsSSMPtr->find (aRowNr, itsColNr, aStartRow, anEndRow,
                                columnName());
     aRowNr = anEndRow+1;
-    uInt aNr = anEndRow-aStartRow+1;
+    rownr_t aNr = anEndRow-aStartRow+1;
     rowsToDo -= aNr;
     itsWriteFunc (aValPtr, aDataPtr, aNr * itsNrCopy);
     aDataPtr += aNr * itsLocalSize;
@@ -731,7 +569,7 @@ void SSMColumn::removeColumn()
 {
   if (dataType() == TpString  &&  itsMaxLen == 0) {
     Int buf[3];
-    for (uInt i=0;i<itsSSMPtr->getNRow();i++) {
+    for (rownr_t i=0; i<itsSSMPtr->getNRow(); i++) {
       getRowValue(buf, i);
       if (buf[2] > 8 ) {
 	itsSSMPtr->getStringHandler()->remove(buf[0], buf[1], buf[2]);
@@ -786,7 +624,7 @@ void SSMColumn::init()
   }
 }
 
-void SSMColumn::resync (uInt)
+void SSMColumn::resync (rownr_t)
 {
     // Invalidate the last value read.
     columnCache().invalidate();
