@@ -23,13 +23,14 @@
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
 //#
-//# $Id$
+//# $Id: StIndArrAIO.cc 21051 2011-04-20 11:46:29Z gervandiepen $
 
 #include <casacore/tables/DataMan/StIndArrAIO.h>
 #include <casacore/tables/DataMan/StArrayFile.h>
 #include <casacore/tables/DataMan/StIndArray.h>
 #include <casacore/casa/Utilities/DataType.h>
 #include <casacore/casa/IO/AipsIO.h>
+#include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/BasicSL/Complex.h>
 #include <casacore/casa/BasicSL/String.h>
 #include <casacore/tables/DataMan/DataManError.h>
@@ -48,6 +49,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 StManColumnIndArrayAipsIO::StManColumnIndArrayAipsIO (StManAipsIO* smptr,
 						      int dataType)
 : StManColumnAipsIO (smptr, dataType, True),
+  staioPtr_p    (smptr),
   seqnr_p       (smptr->uniqueNr()),
   shapeIsFixed_p(False),
   version_p     (2),
@@ -57,8 +59,8 @@ StManColumnIndArrayAipsIO::StManColumnIndArrayAipsIO (StManAipsIO* smptr,
 //# Delete all objects created.
 StManColumnIndArrayAipsIO::~StManColumnIndArrayAipsIO()
 {
-    uInt nr = stmanPtr_p->nrow();
-    for (uInt i=0; i<nr; i++) {
+    rownr_t nr = stmanPtr_p->nrow();
+    for (rownr_t i=0; i<nr; i++) {
 	deleteArray (i);
     }
     if (version_p <= 1) {
@@ -71,7 +73,7 @@ StManColumnIndArrayAipsIO::~StManColumnIndArrayAipsIO()
 //# Compose the file name from the mother file name extended with
 //# the unique column sequence nr.
 //# Create the given nr of rows in it.
-void StManColumnIndArrayAipsIO::doCreate (uInt nrrow)
+void StManColumnIndArrayAipsIO::doCreate (rownr_t nrrow)
 {
     //# Create the file.
     openFile (ByteIO::New);
@@ -84,7 +86,7 @@ void StManColumnIndArrayAipsIO::openFile (ByteIO::OpenOption opt)
     //# For newer versions one file is maintained by the parent
     //# for all indirect columns.
     if (version_p > 1) {
-        iosfile_p = stmanPtr_p->openArrayFile (opt);
+        iosfile_p = staioPtr_p->openArrayFile (opt);
     } else {
         //# Open/create the file holding the arrays in the column.
         if (iosfile_p == 0) {
@@ -110,7 +112,7 @@ void StManColumnIndArrayAipsIO::setShapeColumn (const IPosition& shape)
 }
 
 
-void StManColumnIndArrayAipsIO::addRow (uInt nrnew, uInt nrold)
+void StManColumnIndArrayAipsIO::addRow (rownr_t nrnew, rownr_t nrold)
 {
     //# Extend data blocks if needed.
     StManColumnAipsIO::addRow (nrnew, nrold);
@@ -123,7 +125,7 @@ void StManColumnIndArrayAipsIO::addRow (uInt nrnew, uInt nrold)
 }
 
 
-void StManColumnIndArrayAipsIO::setShape (uInt rownr, const IPosition& shape)
+void StManColumnIndArrayAipsIO::setShape (rownr_t rownr, const IPosition& shape)
 {
     StIndArray* ptr = STMANINDGETBLOCK(rownr);
     if (ptr == 0) {
@@ -131,14 +133,14 @@ void StManColumnIndArrayAipsIO::setShape (uInt rownr, const IPosition& shape)
     }
     //# Put the new shape (if changed).
     //# When changed, put the file offset.
-    if (ptr->setShape (*iosfile_p, dtype_p, shape)) {
+    if (ptr->setShape (*iosfile_p, dtype(), shape)) {
 	putArrayPtr (rownr, ptr);
     }
 }
 
 //# Get the shape for the array (if any) in the given row.
 //# Read shape if not read yet.
-StIndArray* StManColumnIndArrayAipsIO::getShape (uInt rownr)
+StIndArray* StManColumnIndArrayAipsIO::getShape (rownr_t rownr)
 {
     StIndArray* ptr = STMANINDGETBLOCK(rownr);
     if (ptr == 0) {
@@ -150,91 +152,50 @@ StIndArray* StManColumnIndArrayAipsIO::getShape (uInt rownr)
     return ptr;
 }
 
-Bool StManColumnIndArrayAipsIO::isShapeDefined (uInt rownr)
+Bool StManColumnIndArrayAipsIO::isShapeDefined (rownr_t rownr)
     { return (STMANINDGETBLOCK(rownr) == 0  ?  False : True); }
 
-uInt StManColumnIndArrayAipsIO::ndim (uInt rownr)
+uInt StManColumnIndArrayAipsIO::ndim (rownr_t rownr)
     { return getShape(rownr)->shape().nelements(); }
 
-IPosition StManColumnIndArrayAipsIO::shape (uInt rownr)
+IPosition StManColumnIndArrayAipsIO::shape (rownr_t rownr)
     { return getShape(rownr)->shape(); }
 
 Bool StManColumnIndArrayAipsIO::canChangeShape() const
     { return (shapeIsFixed_p  ?  False : True); }
 
 
-Bool StManColumnIndArrayAipsIO::canAccessSlice (Bool& reask) const
+void StManColumnIndArrayAipsIO::getArrayV (rownr_t rownr, ArrayBase& arr)
 {
-    reask = False;
-    return True;
+  StIndArray* sia = getShape (rownr);
+  sia->getArrayV (*iosfile_p, arr, dtype());
 }
 
-
-void StManColumnIndArrayAipsIO::getArrayfloatV (uInt rownr, Array<float>* arr)
+void StManColumnIndArrayAipsIO::putArrayV (rownr_t rownr,
+                                           const ArrayBase& arr)
 {
-    getShape(rownr)->getArrayfloatV (*iosfile_p, arr);
+  StIndArray* sia = getShape (rownr);
+  sia->putArrayV (*iosfile_p, arr, dtype());
+  stmanPtr_p->setHasPut();
 }
 
-void StManColumnIndArrayAipsIO::putArrayfloatV (uInt rownr,
-						const Array<float>* arr)
+void StManColumnIndArrayAipsIO::getSliceV (rownr_t rownr, const Slicer& ns,
+                                           ArrayBase& arr)
 {
-    getShape(rownr)->putArrayfloatV (*iosfile_p, arr);
-    stmanPtr_p->setHasPut();
+  StIndArray* sia = getShape (rownr);
+  sia->getSliceV (*iosfile_p, ns, arr, dtype());
 }
 
-void StManColumnIndArrayAipsIO::getSlicefloatV (uInt rownr, const Slicer& ns,
-						Array<float>* arr)
+void StManColumnIndArrayAipsIO::putSliceV (rownr_t rownr, const Slicer& ns,
+                                           const ArrayBase& arr)
 {
-    getShape(rownr)->getSlicefloatV (*iosfile_p, ns, arr);
+  StIndArray* sia = getShape (rownr);
+  sia->putSliceV (*iosfile_p, ns, arr, dtype());
+  stmanPtr_p->setHasPut();
 }
 
-void StManColumnIndArrayAipsIO::putSlicefloatV (uInt rownr, const Slicer& ns,
-						const Array<float>* arr)
-{
-    getShape(rownr)->putSlicefloatV (*iosfile_p, ns, arr);
-    stmanPtr_p->setHasPut();
-}
-    
 
-#define STMANCOLUMNINDARRAYAIPSIO_GETPUT(T,NM) \
-void StManColumnIndArrayAipsIO::aips_name2(getArray,NM) (uInt rownr, \
-							 Array<T>* arr) \
-{ \
-    getShape(rownr)->aips_name2(getArray,NM) (*iosfile_p, arr); \
-} \
-void StManColumnIndArrayAipsIO::aips_name2(putArray,NM) (uInt rownr, \
-						         const Array<T>* arr) \
-{ \
-    getShape(rownr)->aips_name2(putArray,NM) (*iosfile_p, arr); \
-    stmanPtr_p->setHasPut(); \
-} \
-void StManColumnIndArrayAipsIO::aips_name2(getSlice,NM) \
-                             (uInt rownr, const Slicer& ns, Array<T>* arr) \
-{ \
-    getShape(rownr)->aips_name2(getSlice,NM) (*iosfile_p, ns, arr); \
-} \
-void StManColumnIndArrayAipsIO::aips_name2(putSlice,NM) \
-                        (uInt rownr, const Slicer& ns, const Array<T>* arr) \
-{ \
-    getShape(rownr)->aips_name2(putSlice,NM) (*iosfile_p, ns, arr); \
-    stmanPtr_p->setHasPut(); \
-}
-
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(Bool,BoolV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(uChar,uCharV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(Short,ShortV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(uShort,uShortV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(Int,IntV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(uInt,uIntV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(Int64,Int64V)
-//#//STMANCOLUMNINDARRAYAIPSIO_GETPUT(float,floatV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(double,doubleV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(Complex,ComplexV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(DComplex,DComplexV)
-STMANCOLUMNINDARRAYAIPSIO_GETPUT(String,StringV)
-
-
-void StManColumnIndArrayAipsIO::remove (uInt rownr)
+  void StManColumnIndArrayAipsIO::remove (rownr_t rownr)
 {
     deleteArray (rownr);
     StManColumnAipsIO::remove (rownr);
@@ -247,17 +208,17 @@ Bool StManColumnIndArrayAipsIO::ok() const
 }
 
 
-void StManColumnIndArrayAipsIO::deleteArray (uInt rownr)
+void StManColumnIndArrayAipsIO::deleteArray (rownr_t rownr)
 {
     delete STMANINDGETBLOCK(rownr);
 }
 
 
 //# Write all data into AipsIO.
-void StManColumnIndArrayAipsIO::putFile (uInt nrval, AipsIO& ios)
+void StManColumnIndArrayAipsIO::putFile (rownr_t nrval, AipsIO& ios)
 {
     ios.putstart ("StManColumnIndArrayAipsIO", version_p);
-    ios << dtype_p;                    // for backward compatibility
+    ios << dtype();                    // for backward compatibility
     ios << seqnr_p;
     StManColumnAipsIO::putFile (nrval, ios);
     ios.putend();
@@ -285,7 +246,7 @@ void StManColumnIndArrayAipsIO::putData (void* dp, uInt nrval, AipsIO& ios)
 
 
 //# Read all data from AipsIO.
-void StManColumnIndArrayAipsIO::getFile (uInt nrval, AipsIO& ios)
+void StManColumnIndArrayAipsIO::getFile (rownr_t nrval, AipsIO& ios)
 {
     int dtype;
     version_p = ios.getstart ("StManColumnIndArrayAipsIO");
