@@ -219,6 +219,8 @@ void StIndArray::copyData (StManArrayFile& ios, int dataType,
 			     other.fileOffset_p + other.arrOffset_p,
 			     shape_p.product());
 	break;
+    default:
+      throw DataManInternalError("Unhandled data type in StIndArray::copyData");
     }
 }
 
@@ -232,36 +234,262 @@ void StIndArray::checkShape (const IPosition& userArrayShape,
     }
 }
 
+void StIndArray::getArrayV (StManArrayFile& ios, ArrayBase& arr,
+                            DataType dtype)
+{
+    checkShape (arr.shape(), shape_p);
+    Bool deleteIt;
+    void* value = arr.getVStorage (deleteIt);
+    switch (dtype) {
+    case TpBool:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<Bool*>(value));
+      break;
+    case TpUChar:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<uChar*>(value));
+      break;
+    case TpShort:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<Short*>(value));
+      break;
+    case TpUShort:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<uShort*>(value));
+      break;
+    case TpInt:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<Int*>(value));
+      break;
+    case TpUInt:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<uInt*>(value));
+      break;
+    case TpInt64:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<Int64*>(value));
+      break;
+    case TpFloat:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<float*>(value));
+      break;
+    case TpDouble:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<double*>(value));
+      break;
+    case TpComplex:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<Complex*>(value));
+      break;
+    case TpDComplex:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<DComplex*>(value));
+      break;
+    case TpString:
+      ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<String*>(value));
+      break;
+    default:
+      const void* cvalue = value;
+      arr.freeVStorage (cvalue, deleteIt);
+      throw DataManInternalError("Unhandled data type in StIndArray::getArrayV");
+      break;
+    }
+    arr.putVStorage (value, deleteIt);
+}
 
-void StIndArray::getArrayfloatV (StManArrayFile& ios, Array<float>* arr)
+void StIndArray::putArrayV (StManArrayFile& ios, const ArrayBase& arr,
+                            DataType dtype)
 {
-    checkShape (arr->shape(), shape_p);
+    checkShape (arr.shape(), shape_p);
     Bool deleteIt;
-    float* value = arr->getStorage (deleteIt);
-    ios.get (fileOffset_p + arrOffset_p, 0, shape_p.product(), value);
-    arr->putStorage (value, deleteIt);
+    const void* value = arr.getVStorage (deleteIt);
+    switch (dtype) {
+    case TpBool:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const Bool*>(value));
+      break;
+    case TpUChar:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const uChar*>(value));
+      break;
+    case TpShort:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const Short*>(value));
+      break;
+    case TpUShort:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const uShort*>(value));
+      break;
+    case TpInt:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const Int*>(value));
+      break;
+    case TpUInt:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const uInt*>(value));
+      break;
+    case TpInt64:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const Int64*>(value));
+      break;
+    case TpFloat:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const float*>(value));
+      break;
+    case TpDouble:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const double*>(value));
+      break;
+    case TpComplex:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const Complex*>(value));
+      break;
+    case TpDComplex:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const DComplex*>(value));
+      break;
+    case TpString:
+      ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(),
+               static_cast<const String*>(value));
+      break;
+    default:
+      arr.freeVStorage (value, deleteIt);
+      throw DataManInternalError("Unhandled data type in StIndArray::putArrayV");
+      break;
+    }
+    arr.freeVStorage (value, deleteIt);
 }
-void StIndArray::putArrayfloatV (StManArrayFile& ios, const Array<float>* arr)
-{
-    checkShape (arr->shape(), shape_p);
-    Bool deleteIt;
-    const float* value = arr->getStorage (deleteIt);
-    ios.put (fileOffset_p + arrOffset_p, 0, shape_p.product(), value);
-    arr->freeStorage (value, deleteIt);
-}
-void StIndArray::getSlicefloatV (StManArrayFile& ios, const Slicer& ns,
-				 Array<float>* arr)
+
+void StIndArray::getSliceV (StManArrayFile& ios, const Slicer& ns,
+                            ArrayBase& arr, DataType dtype)
 {
     Bool deleteIt;
-    float* value = arr->getStorage (deleteIt);
-    getSliceData (ios, ns, value, arr->shape(),
-		  &StIndArray::getVecfloatV);
-    arr->putStorage (value, deleteIt);
+    void* value = arr.getVStorage (deleteIt);
+    switch (dtype) {
+    case TpBool:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecBoolV);
+      break;
+    case TpUChar:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecuCharV);
+      break;
+    case TpShort:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecShortV);
+      break;
+    case TpUShort:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecuShortV);
+      break;
+    case TpInt:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecIntV);
+      break;
+    case TpUInt:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecuIntV);
+      break;
+    case TpInt64:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecInt64V);
+      break;
+    case TpFloat:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecfloatV);
+      break;
+    case TpDouble:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecdoubleV);
+      break;
+    case TpComplex:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecComplexV);
+      break;
+    case TpDComplex:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecDComplexV);
+      break;
+    case TpString:
+      getSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::getVecStringV);
+      break;
+    default:
+      const void* cvalue = value;
+      arr.freeVStorage (cvalue, deleteIt);
+      throw DataManInternalError("Unhandled data type in StIndArray::getSliceV");
+      break;
+    }
+    arr.putVStorage (value, deleteIt);
 }
+
+void StIndArray::putSliceV (StManArrayFile& ios, const Slicer& ns,
+                            const ArrayBase& arr, DataType dtype)
+{
+    Bool deleteIt;
+    const void* value = arr.getVStorage (deleteIt);
+    switch (dtype) {
+    case TpBool:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecBoolV);
+      break;
+    case TpUChar:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecuCharV);
+      break;
+    case TpShort:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecShortV);
+      break;
+    case TpUShort:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecuShortV);
+      break;
+    case TpInt:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecIntV);
+      break;
+    case TpUInt:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecuIntV);
+      break;
+    case TpInt64:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecInt64V);
+      break;
+    case TpFloat:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecfloatV);
+      break;
+    case TpDouble:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecdoubleV);
+      break;
+    case TpComplex:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecComplexV);
+      break;
+    case TpDComplex:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecDComplexV);
+      break;
+    case TpString:
+      putSliceData (ios, ns, value, arr.shape(),
+                    &StIndArray::putVecStringV);
+      break;
+    default:
+      arr.freeVStorage (value, deleteIt);
+      throw DataManInternalError("Unhandled data type in StIndArray::putSliceV");
+      break;
+    }
+    arr.freeVStorage (value, deleteIt);
+}
+
 void StIndArray::getVecfloatV (StManArrayFile& ios,
 			       Int64 fileOffset,
-			       uInt start, uInt leng, uInt inc,
-			       uInt valInx, void* value)
+			       uInt64 start, uInt64 leng, uInt64 inc,
+			       uInt64 valInx, void* value)
 {
     float* valp = (float*)value + valInx;
     if (inc == 1) {
@@ -275,7 +503,7 @@ void StIndArray::getVecfloatV (StManArrayFile& ios,
 }
 void StIndArray::getSliceData (StManArrayFile& ios, const Slicer& ns,
       void* value, const IPosition& userShape,
-      void (*getVec) (StManArrayFile&, Int64, uInt, uInt, uInt, uInt, void*))
+      void (*getVec) (StManArrayFile&, Int64, uInt64, uInt64, uInt64, uInt64, void*))
 {
     //# Check if the shape of the slice and user array match.
     uInt ndim = ns.ndim();
@@ -285,7 +513,7 @@ void StIndArray::getSliceData (StManArrayFile& ios, const Slicer& ns,
     //# We'll get a vector at the time; get its length.
     //# Get the offset of the array in the file.
     //# If the array is 1-dim, we can just use the vector get.
-    uInt leng = shape(0);
+    uInt64 leng = shape(0);
     Int64 fileOffset = fileOffset_p + arrOffset_p;
     if (ndim == 1) {
 	getVec (ios, fileOffset, blc(0), leng, inc(0), 0, value);
@@ -293,15 +521,14 @@ void StIndArray::getSliceData (StManArrayFile& ios, const Slicer& ns,
 	//# Loop through the slice a vector at a time.
 	ArrayPositionIterator iter(shape, 1);
 	IPosition pos(ndim);
-	uInt i, offset;
-	uInt count=0;
+	uInt64 count=0;
 	while (! iter.pastEnd()) {
 	    //# Get the iterator position in the slice and transform
 	    //# that to the file-offset for the corresponding part in
 	    //# the table array.
 	    pos = iter.pos();
-	    offset = 0;
-	    for (i=ndim-1; i>0; i--) {
+	    uInt64 offset = 0;
+	    for (uInt i=ndim-1; i>0; i--) {
 		offset += blc(i) + pos(i) * inc(i);
 		offset *= shape_p(i-1);
 	    }
@@ -314,19 +541,10 @@ void StIndArray::getSliceData (StManArrayFile& ios, const Slicer& ns,
     }
 }
 
-void StIndArray::putSlicefloatV (StManArrayFile& ios, const Slicer& ns,
-				 const Array<float>* arr)
-{
-    Bool deleteIt;
-    const float* value = arr->getStorage (deleteIt);
-    putSliceData (ios, ns, value, arr->shape(),
-		  &StIndArray::putVecfloatV);
-    arr->freeStorage (value, deleteIt);
-}
 void StIndArray::putVecfloatV (StManArrayFile& ios,
 			       Int64 fileOffset,
-			       uInt start, uInt leng, uInt inc,
-			       uInt valInx, const void* value)
+			       uInt64 start, uInt64 leng, uInt64 inc,
+			       uInt64 valInx, const void* value)
 {
     float* valp = (float*)value + valInx;
     if (inc == 1) {
@@ -341,26 +559,25 @@ void StIndArray::putVecfloatV (StManArrayFile& ios,
 //# putSliceData works similar to getSliceData.
 void StIndArray::putSliceData (StManArrayFile& ios, const Slicer& ns,
 	const void* value, const IPosition& userShape,
-        void (*putVec) (StManArrayFile&, Int64, uInt, uInt, uInt, uInt,
+        void (*putVec) (StManArrayFile&, Int64, uInt64, uInt64, uInt64, uInt64,
 			const void*))
 {
     uInt ndim = ns.ndim();
     IPosition blc(ndim), trc(ndim), inc(ndim), shape(ndim);
     shape = ns.inferShapeFromSource (shape_p, blc,trc,inc);
     checkShape (userShape, shape);
-    uInt leng = shape(0);
+    uInt64 leng = shape(0);
     Int64 fileOffset = fileOffset_p + arrOffset_p;
     if (ndim == 1) {
 	putVec (ios, fileOffset, blc(0), leng, inc(0), 0, value);
     }else{
 	ArrayPositionIterator iter(shape, 1);
 	IPosition pos(ndim);
-	uInt i, offset;
-	uInt count=0;
+	uInt64 count=0;
 	while (! iter.pastEnd()) {
 	    pos = iter.pos();
-	    offset = 0;
-	    for (i=ndim-1; i>0; i--) {
+	    uInt64 offset = 0;
+	    for (uInt i=ndim-1; i>0; i--) {
 		offset += blc(i) + pos(i) * inc(i);
 		offset *= shape_p(i-1);
 	    }
@@ -375,37 +592,10 @@ void StIndArray::putSliceData (StManArrayFile& ios, const Slicer& ns,
     
 
 #define STINDARRAY_GETPUT(T,NM) \
-void StIndArray::aips_name2(getArray,NM) (StManArrayFile& ios, Array<T>* arr) \
-{ \
-    checkShape (arr->shape(), shape_p); \
-    Bool deleteIt; \
-    T* value = arr->getStorage (deleteIt); \
-    ios.get (fileOffset_p + arrOffset_p, \
-	     0, shape_p.product(), value); \
-    arr->putStorage (value, deleteIt); \
-} \
-void StIndArray::aips_name2(putArray,NM) (StManArrayFile& ios, \
-					  const Array<T>* arr) \
-{ \
-    checkShape (arr->shape(), shape_p); \
-    Bool deleteIt; \
-    const T* value = arr->getStorage (deleteIt); \
-    ios.put (fileOffset_p + arrOffset_p, \
-	     0, shape_p.product(), value); \
-    arr->freeStorage (value, deleteIt); \
-} \
-void StIndArray::aips_name2(getSlice,NM) (StManArrayFile& ios, \
-                                          const Slicer& ns, Array<T>* arr) \
-{  \
-    Bool deleteIt; \
-    T* value = arr->getStorage (deleteIt); \
-    getSliceData (ios, ns, value, arr->shape(), \
-		  &StIndArray::aips_name2(getVec,NM)); \
-    arr->putStorage (value, deleteIt); \
-} \
 void StIndArray::aips_name2(getVec,NM) \
                   (StManArrayFile& ios, Int64 fileOffset, \
-		   uInt start, uInt leng, uInt inc, uInt valInx, void* value) \
+		   uInt64 start, uInt64 leng, uInt64 inc, uInt64 valInx, \
+                   void* value) \
 { \
     T* valp = (T*)value + valInx; \
     if (inc == 1) { \
@@ -417,19 +607,9 @@ void StIndArray::aips_name2(getVec,NM) \
 	} \
     } \
 } \
-void StIndArray::aips_name2(putSlice,NM) (StManArrayFile& ios, \
-                                          const Slicer& ns, \
-                                          const Array<T>* arr) \
-{ \
-    Bool deleteIt; \
-    const T* value = arr->getStorage (deleteIt); \
-    putSliceData (ios, ns, value, arr->shape(), \
-		  &StIndArray::aips_name2(putVec,NM)); \
-    arr->freeStorage (value, deleteIt); \
-} \
 void StIndArray::aips_name2(putVec,NM) \
                   (StManArrayFile& ios, Int64 fileOffset, \
-		   uInt start, uInt leng, uInt inc, uInt valInx, \
+		   uInt64 start, uInt64 leng, uInt64 inc, uInt64 valInx, \
                    const void* value) \
 { \
     T* valp = (T*)value + valInx; \
@@ -450,7 +630,7 @@ STINDARRAY_GETPUT(uShort,uShortV)
 STINDARRAY_GETPUT(Int,IntV)
 STINDARRAY_GETPUT(uInt,uIntV)
 STINDARRAY_GETPUT(Int64,Int64V)
-//#//STINDARRAY_GETPUT(float,floatV)
+//#//STINDARRAY_GETPUT(float,floatV)   // done explicitly for debug purposes
 STINDARRAY_GETPUT(double,doubleV)
 STINDARRAY_GETPUT(Complex,ComplexV)
 STINDARRAY_GETPUT(DComplex,DComplexV)
