@@ -42,7 +42,7 @@
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/Slicer.h>
 #include <casacore/casa/Arrays/Slice.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/tables/Tables/TableError.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/iostream.h>
@@ -59,14 +59,6 @@
 // Build a description.
 void createTable()
 {
-  {
-    // First ensure it can do the things it should.
-    BitFlagsEngine<Short> engine("", "");
-    Bool reask;
-    AlwaysAssertExit (engine.canAccessArrayColumn(reask));
-    AlwaysAssertExit (engine.canAccessSlice(reask));
-    AlwaysAssertExit (engine.canAccessColumnSlice(reask));
-  }
   // First register the virtual column engine.
   BitFlagsEngine<Short>::registerClass();
   BitFlagsEngine<Int>::registerClass();
@@ -280,8 +272,8 @@ int main ()
   try {
     createTable();
     readTable();
-  } catch (AipsError& x) {
-    cout << "Caught an exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Caught an exception: " << x.what() << endl;
     return 1;
   } 
   return 0;                           // exit with success status
