@@ -74,8 +74,8 @@ int main (int argc, const char* argv[])
 	    c (False, off1, off2, off3, off4);
 	    c (False, offc1, offc2, offc3, offc4);
 	}
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     return 0;                           // exit with success status
