@@ -64,10 +64,6 @@ TableExprNode::TableExprNode (const Bool& val)
 {
     node_p = new TableExprNodeConstBool (val);
 }
-TableExprNode::TableExprNode (const Int64& val)
-{
-    node_p = new TableExprNodeConstInt (val);
-}
 TableExprNode::TableExprNode (const Int& val)
 {
     node_p = new TableExprNodeConstInt (val);
@@ -76,6 +72,14 @@ TableExprNode::TableExprNode (const uInt& val)
 {
     node_p = new TableExprNodeConstInt (val);
 }
+TableExprNode::TableExprNode (const Int64& val)
+{
+    node_p = new TableExprNodeConstInt (val);
+}
+TableExprNode::TableExprNode (const uInt64& val)
+{
+    node_p = new TableExprNodeConstInt (val);
+}
 TableExprNode::TableExprNode (const Float& val)
 {
     node_p = new TableExprNodeConstDouble (Double (val));
@@ -148,6 +152,10 @@ TableExprNode::TableExprNode (const Array<Int64>& val)
 {
     node_p = new TableExprNodeArrayConstInt (val);
 }
+TableExprNode::TableExprNode (const Array<uInt64>& val)
+{
+    node_p = new TableExprNodeArrayConstInt (val);
+}
 TableExprNode::TableExprNode (const Array<Float>& val)
 {
     node_p = new TableExprNodeArrayConstDouble (val);
@@ -201,6 +209,10 @@ TableExprNode::TableExprNode (const MArray<Int64>& val)
 {
     node_p = new TableExprNodeArrayConstInt (val);
 }
+TableExprNode::TableExprNode (const MArray<uInt64>& val)
+{
+    node_p = new TableExprNodeArrayConstInt (val);
+}
 TableExprNode::TableExprNode (const MArray<Float>& val)
 {
     node_p = new TableExprNodeArrayConstDouble (val);
