@@ -102,7 +102,7 @@ void TableExprNodeRep::show (ostream& os, uInt indent) const
 void TableExprNodeRep::disableApplySelection()
 {}
 
-void TableExprNodeRep::applySelection (const Vector<uInt>&)
+void TableExprNodeRep::applySelection (const Vector<rownr_t>&)
 {}
 
 void TableExprNodeRep::getAggrNodes (vector<TableExprNodeRep*>&)
@@ -138,7 +138,7 @@ void TableExprNodeRep::adaptSetUnits (const Unit&)
 {}
 
 //# Determine the number of rows in the table used in the expression.
-uInt TableExprNodeRep::nrow() const
+rownr_t TableExprNodeRep::nrow() const
 {
     if (exprtype_p == Constant) {
         return 1;
@@ -405,108 +405,108 @@ MArray<Bool> TableExprNodeRep::hasArrayDate (const TableExprId& id,
 
 
 Array<Bool>     TableExprNodeRep::getColumnBool
-(const Vector<uInt>& rownrs)
+(const Vector<rownr_t>& rownrs)
 {
     TableExprId id;
-    uInt nrrow = rownrs.size();
+    rownr_t nrrow = rownrs.size();
     Vector<Bool> vec (nrrow);
-    for (uInt i=0; i<nrrow; i++) {
+    for (rownr_t i=0; i<nrrow; i++) {
       id.setRownr   (rownrs[i]);
       vec[i] = getBool (id);
     }
     return vec;
 }
 Array<uChar>    TableExprNodeRep::getColumnuChar
-(const Vector<uInt>&)
+(const Vector<rownr_t>&)
 {
     TableExprNode::throwInvDT ("(getColumnuChar not implemented)");
     return Array<uChar>();
 }
 Array<Short>    TableExprNodeRep::getColumnShort
-(const Vector<uInt>&)
+(const Vector<rownr_t>&)
 {
     TableExprNode::throwInvDT ("(getColumnShort not implemented)");
     return Array<Short>();
 }
 Array<uShort>   TableExprNodeRep::getColumnuShort
-(const Vector<uInt>&)
+(const Vector<rownr_t>&)
 {
     TableExprNode::throwInvDT ("(getColumnuShort not implemented)");
     return Array<uShort>();
 }
 Array<Int>      TableExprNodeRep::getColumnInt
-(const Vector<uInt>& rownrs)
+(const Vector<rownr_t>& rownrs)
 {
     TableExprId id;
-    uInt nrrow = rownrs.size();
+    rownr_t nrrow = rownrs.size();
     Vector<Int> vec (nrrow);
-    for (uInt i=0; i<nrrow; i++) {
+    for (rownr_t i=0; i<nrrow; i++) {
       id.setRownr   (rownrs[i]);
       vec[i] = getInt (id);
     }
     return vec;
 }
 Array<uInt>     TableExprNodeRep::getColumnuInt
-(const Vector<uInt>&)
+(const Vector<rownr_t>&)
 {
     TableExprNode::throwInvDT ("(getColumnuInt not implemented)");
     return Array<uInt>();
 }
 Array<Int64>    TableExprNodeRep::getColumnInt64
-(const Vector<uInt>& rownrs)
+(const Vector<rownr_t>& rownrs)
 {
     TableExprId id;
-    uInt nrrow = rownrs.size();
+    rownr_t nrrow = rownrs.size();
     Vector<Int64> vec (nrrow);
-    for (uInt i=0; i<nrrow; i++) {
+    for (rownr_t i=0; i<nrrow; i++) {
       id.setRownr   (rownrs[i]);
       vec[i] = getInt (id);
     }
     return vec;
 }
 Array<Float>    TableExprNodeRep::getColumnFloat
-(const Vector<uInt>&)
+(const Vector<rownr_t>&)
 {
     TableExprNode::throwInvDT ("(getColumnFloat not implemented)");
     return Array<Float>();
 }
 Array<Double>   TableExprNodeRep::getColumnDouble
-(const Vector<uInt>& rownrs)
+(const Vector<rownr_t>& rownrs)
 {
     TableExprId id;
-    uInt nrrow = rownrs.size();
+    rownr_t nrrow = rownrs.size();
     Vector<Double> vec (nrrow);
-    for (uInt i=0; i<nrrow; i++) {
+    for (rownr_t i=0; i<nrrow; i++) {
       id.setRownr   (rownrs[i]);
       vec[i] = getDouble (id);
     }
     return vec;
 }
 Array<Complex>  TableExprNodeRep::getColumnComplex
-(const Vector<uInt>&)
+(const Vector<rownr_t>&)
 {
     TableExprNode::throwInvDT ("(getColumnComplex not implemented)");
     return Array<Complex>();
 }
 Array<DComplex> TableExprNodeRep::getColumnDComplex
-(const Vector<uInt>& rownrs)
+(const Vector<rownr_t>& rownrs)
 {
     TableExprId id;
-    uInt nrrow = rownrs.size();
+    rownr_t nrrow = rownrs.size();
     Vector<DComplex> vec (nrrow);
-    for (uInt i=0; i<nrrow; i++) {
+    for (rownr_t i=0; i<nrrow; i++) {
       id.setRownr   (rownrs[i]);
       vec[i] = getDComplex (id);
     }
     return vec;
 }
 Array<String>   TableExprNodeRep::getColumnString
-(const Vector<uInt>& rownrs)
+(const Vector<rownr_t>& rownrs)
 {
     TableExprId id;
-    uInt nrrow = rownrs.size();
+    rownr_t nrrow = rownrs.size();
     Vector<String> vec (nrrow);
-    for (uInt i=0; i<nrrow; i++) {
+    for (rownr_t i=0; i<nrrow; i++) {
       id.setRownr   (rownrs[i]);
       vec[i] = getString (id);
     }
@@ -1078,13 +1078,12 @@ TableExprNodeRep::NodeDataType TableExprNodeMulti::checkDT
             dtIn = NTNumeric;
         }
     }
-    uInt i;
     NodeDataType resultType = dtIn;
     if (dtIn == NTNumeric) {
         // NTNumeric -> dtIn must be NTComplex or NTDouble or NTInt
         //              and set resultType to the highest type of dtIn
         resultType = (dtOut==NTDouCom ? NTDouble : NTInt);
-        for (i=0; i<nelem; i++) {
+        for (uInt i=0; i<nelem; i++) {
             if (nodes[i]->dataType() == NTComplex) {
                 resultType = NTComplex;
             } else if (nodes[i]->dataType() == NTDouble) {
@@ -1099,7 +1098,7 @@ TableExprNodeRep::NodeDataType TableExprNodeMulti::checkDT
         // NTReal -> dtIn must be NTDouble or NTInt
         //           and set resultType to the highest type of dtIn
         resultType = (dtOut==NTDouCom ? NTDouble : NTInt);
-        for (i=0; i<nelem; i++) {
+        for (uInt i=0; i<nelem; i++) {
             if (nodes[i]->dataType() == NTDouble) {
                 resultType = NTDouble;
             } else if (nodes[i]->dataType() != NTInt) {
@@ -1108,7 +1107,7 @@ TableExprNodeRep::NodeDataType TableExprNodeMulti::checkDT
         }
     } else {
         // Data types of the nodes must match dtIn
-        for (i=0; i<nelem; i++) {
+        for (uInt i=0; i<nelem; i++) {
             // Double or String to Date conversion can be possible.
             if (nodes[i]->dataType() != dtIn) {
                 if (dateConv  &&  dtIn == NTDate) {
