@@ -46,11 +46,19 @@
 //# So undefine WHERE first.
 #undef WHERE
 #include <casacore/casa/stdlib.h>
-//# Define register as empty string to avoid warnings in C++11 compilers
-//# because keyword register is not supported anymore.
-#define register
+
+//# Let clang and gcc ignore some warnings in bison/flex code.
+//# Undef YY_NULL because flex can redefine it slightly differently (giving a warning).
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wdeprecated-register"
+#pragma GCC diagnostic ignored "-Wsign-compare"
 #include "TableGram.ycc"                  // bison output
+#ifdef YY_NULL
+# undef YY_NULL
+#endif
 #include "TableGram.lcc"                  // flex output
+#pragma GCC diagnostic pop
 
 
 // Define the yywrap function for flex.
@@ -66,21 +74,51 @@ static const char*  strpTableGram = 0;
 static Int          posTableGram = 0;
 
 
+// Define a class to delete the yy_buffer in case of an exception.
+class TableGramState {
+public:
+  TableGramState (YY_BUFFER_STATE state)
+    : itsState (state)
+  {}
+  ~TableGramState()
+    { clear(); }
+  void clear()
+    { if (itsState) {
+        TableGram_delete_buffer(itsState);
+        itsState=0;
+      }
+    }
+  YY_BUFFER_STATE state() const
+    { return itsState; }
+private:
+  TableGramState (const TableGramState&);
+  TableGramState& operator= (const TableGramState&);
+  YY_BUFFER_STATE itsState;      //# this is a pointer to yy_buffer_state
+};
+
+  
 //# Parse the command.
-//# Do a yyrestart(yyin) first to make the flex scanner reentrant.
 int tableGramParseCommand (const String& command)
 {
-    TableGramrestart (TableGramin);
-    yy_start = 1;
-    // Save global state for re-entrancy.
+    // Save current state for re-entrancy.
+    int sav_yy_start = yy_start;
     const char* savStrpTableGram = strpTableGram;
     Int savPosTableGram= posTableGram;
+    YY_BUFFER_STATE sav_state = YY_CURRENT_BUFFER;
+    // Create a new state buffer for new expression.
+    TableGramState next (TableGram_create_buffer (TableGramin, YY_BUF_SIZE));
+    TableGram_switch_to_buffer (next.state());
+    yy_start = 1;
     strpTableGram = command.chars();     // get pointer to command string
     posTableGram  = 0;                   // initialize string position
     int sts = TableGramparse();          // parse command string
-    // Restore global state.
+    // The current state has to be deleted before switching back to previous.
+    next.clear();
+    // Restore previous state.
+    yy_start = sav_yy_start;
     strpTableGram = savStrpTableGram;
     posTableGram= savPosTableGram;
+    TableGram_switch_to_buffer (sav_state);
     return sts;
 }
 
@@ -95,10 +133,10 @@ int tableGramInput (char* buf, int max_size)
 {
     int nr=0;
     while (*strpTableGram != 0) {
-	if (nr >= max_size) {
-	    break;                         // get max. max_size char.
-	}
-	buf[nr++] = *strpTableGram++;
+        if (nr >= max_size) {
+            break;                         // get max. max_size char.
+        }
+        buf[nr++] = *strpTableGram++;
     }
     return nr;
 }
@@ -113,10 +151,34 @@ String tableGramRemoveEscapes (const String& in)
     String out;
     int leng = in.length();
     for (int i=0; i<leng; i++) {
-	if (in[i] == '\\') {
-	    i++;
-	}
-	out += in[i];
+        if (in[i] == '\\') {
+            i++;
+        }
+        out += in[i];
+    }
+    return out;
+}
+
+String tableGramRemoveEscapesQuotes (const String& in)
+{
+    String out;
+    char quote = 0;
+    int leng = in.length();
+    for (int i=0; i<leng; i++) {
+      if (quote) {
+        if (in[i] == quote) {
+          quote = 0;
+        } else {
+          out += in[i];
+        }
+      } else if (in[i] == '"'  ||  in[i] == '\'') {
+        quote = in[i];
+      } else {
+        if (in[i] == '\\') {
+          i++;
+        }
+        out += in[i];
+      }
     }
     return out;
 }
@@ -130,13 +192,13 @@ String tableGramRemoveQuotes (const String& in)
     int leng = str.length();
     int pos = 0;
     while (pos < leng) {
-	//# Find next occurrence of leading ' or ""
-	int inx = str.index (str[pos], pos+1);
-	if (inx < 0) {
-	    throw (TableError ("ill-formed quoted string: " + str));
-	}
-	out += str.at (pos+1, inx-pos-1);             // add substring
-	pos = inx+1;
+        //# Find next occurrence of leading ' or ""
+        int inx = str.index (str[pos], pos+1);
+        if (inx < 0) {
+            throw (TableError ("ill-formed quoted string: " + str));
+        }
+        out += str.at (pos+1, inx-pos-1);             // add substring
+        pos = inx+1;
     }
     return out;
 }
