@@ -66,31 +66,34 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     return keywordSet_p;
   }
 
-  uInt ConcatColumn::nrow() const
+  rownr_t ConcatColumn::nrow() const
   {
     return refTabPtr_p->nrow();
   }
 
-  void ConcatColumn::initialize (uInt startRow, uInt endRow)
+  void ConcatColumn::initialize (rownr_t startRow, rownr_t endRow)
   {
-    uInt tableNr, tabRownr;
-    for (uInt i=startRow; i<endRow; ++i) {
+    uInt tableNr;
+    rownr_t tabRownr;
+    for (rownr_t i=startRow; i<endRow; ++i) {
       refTabPtr_p->rows().mapRownr (tableNr, tabRownr, i);
       refColPtr_p[tableNr]->initialize (tabRownr, tabRownr);
     }
   }
 
-  void ConcatColumn::setShape (uInt rownr, const IPosition& shape)
+  void ConcatColumn::setShape (rownr_t rownr, const IPosition& shape)
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     refColPtr_p[tableNr]->setShape (tabRownr, shape);
   }
 
-  void ConcatColumn::setShape (uInt rownr, const IPosition& shape,
+  void ConcatColumn::setShape (rownr_t rownr, const IPosition& shape,
 			       const IPosition& tileShape)
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     refColPtr_p[tableNr]->setShape (tabRownr, shape, tileShape);
   }
@@ -105,98 +108,97 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     return refColPtr_p[0]->shapeColumn();
   }
 
-  uInt ConcatColumn::ndim (uInt rownr) const
+  uInt ConcatColumn::ndim (rownr_t rownr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     return refColPtr_p[tableNr]->ndim (tabRownr);
   }
 
-  IPosition ConcatColumn::shape(uInt rownr) const
+  IPosition ConcatColumn::shape(rownr_t rownr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     return refColPtr_p[tableNr]->shape (tabRownr);
   }
 
-  IPosition ConcatColumn::tileShape(uInt rownr) const
+  IPosition ConcatColumn::tileShape(rownr_t rownr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     return refColPtr_p[tableNr]->tileShape (tabRownr);
   }
 
-  Bool ConcatColumn::isDefined (uInt rownr) const
+  Bool ConcatColumn::isDefined (rownr_t rownr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     return refColPtr_p[tableNr]->isDefined (tabRownr);
   }
 
 
-  Bool ConcatColumn::canAccessScalarColumn (Bool& reask) const
-  {
-    return refColPtr_p[0]->canAccessScalarColumn (reask);
-  }
-  Bool ConcatColumn::canAccessScalarColumnCells (Bool& reask) const
-  {
-    return refColPtr_p[0]->canAccessScalarColumnCells (reask);
-  }
-  Bool ConcatColumn::canAccessArrayColumn (Bool& reask) const
-  {
-    return refColPtr_p[0]->canAccessArrayColumn (reask);
-  }
-  Bool ConcatColumn::canAccessArrayColumnCells (Bool& reask) const
-  {
-    return refColPtr_p[0]->canAccessArrayColumnCells (reask);
-  }
-  Bool ConcatColumn::canAccessSlice (Bool& reask) const
-  {
-    return refColPtr_p[0]->canAccessSlice (reask);
-  }
-  Bool ConcatColumn::canAccessColumnSlice (Bool& reask) const
-  {
-    return refColPtr_p[0]->canAccessColumnSlice (reask);
-  }
-
   Bool ConcatColumn::canChangeShape() const
   {
     return refColPtr_p[0]->canChangeShape();
   }
 
 
-  void ConcatColumn::get (uInt rownr, void* dataPtr) const
+  void ConcatColumn::get (rownr_t rownr, void* dataPtr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     refColPtr_p[tableNr]->get (tabRownr, dataPtr);
     // Set the column cache to the table used.
     ///setColumnCache (tableNr, refColPtr_p[tableNr]->columnCache());
   }
 
-  void ConcatColumn::getSlice (uInt rownr, const Slicer& ns,
-			       void* dataPtr) const
+  void ConcatColumn::getArray (rownr_t rownr, ArrayBase& arr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
-    refColPtr_p[tableNr]->getSlice (tabRownr, ns, dataPtr);
+    refColPtr_p[tableNr]->getArray (tabRownr, arr);
   }
 
-  void ConcatColumn::put (uInt rownr, const void* dataPtr)
+  void ConcatColumn::getSlice (rownr_t rownr, const Slicer& ns,
+			       ArrayBase& arr) const
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
+    refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
+    refColPtr_p[tableNr]->getSlice (tabRownr, ns, arr);
+  }
+
+  void ConcatColumn::put (rownr_t rownr, const void* dataPtr)
+  {
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
     refColPtr_p[tableNr]->put (tabRownr, dataPtr);
     // Set the column cache to the table used.
     ///setColumnCache (tableNr, refColPtr_p[tableNr]->columnCache());
   }
 
-  void ConcatColumn::putSlice (uInt rownr, const Slicer& ns,
-			       const void* dataPtr)
+  void ConcatColumn::putArray (rownr_t rownr, const ArrayBase& arr)
   {
-    uInt tableNr, tabRownr;
+    uInt tableNr;
+    rownr_t tabRownr;
     refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
-    refColPtr_p[tableNr]->putSlice (tabRownr, ns, dataPtr);
+    refColPtr_p[tableNr]->putArray (tabRownr, arr);
+  }
+
+  void ConcatColumn::putSlice (rownr_t rownr, const Slicer& ns,
+			       const ArrayBase& arr)
+  {
+    uInt tableNr;
+    rownr_t tabRownr;
+    refTabPtr_p->rows().mapRownr (tableNr, tabRownr, rownr);
+    refColPtr_p[tableNr]->putSlice (tabRownr, ns, arr);
   }
 
   void ConcatColumn::setMaximumCacheSize (uInt nbytes)
@@ -214,91 +216,85 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     { refColPtr_p[0]->freeIterBuf (lastVal, curVal); }
 
 
-  void ConcatColumn::getArrayColumn (void* dataPtr) const
+  void ConcatColumn::getArrayColumn (ArrayBase& arr) const
   {
-    accessColumn (0, dataPtr, &getColumnPart);
+    accessColumn (0, arr, &getColumnPart);
   }
 
   void ConcatColumn::getColumnSlice (const Slicer& ns,
-				     void* dataPtr) const
+				     ArrayBase& arr) const
   {
-    accessColumn (&ns, dataPtr, &getColumnSlicePart);
+    accessColumn (&ns, arr, &getColumnSlicePart);
   }
 
   void ConcatColumn::getArrayColumnCells (const RefRows& rownrs,
-					  void* dataPtr) const
+					  ArrayBase& arr) const
   {
-    accessRows (rownrs, 0, dataPtr, &getRowsPart);
+    accessRows (rownrs, 0, arr, &getRowsPart);
   }
 
   void ConcatColumn::getColumnSliceCells (const RefRows& rownrs,
 					  const Slicer& ns,
-					  void* dataPtr) const
+					  ArrayBase& arr) const
   {
-    accessRows (rownrs, &ns, dataPtr, &getRowsSlicePart);
+    accessRows (rownrs, &ns, arr, &getRowsSlicePart);
   }
 
-  void ConcatColumn::putArrayColumn (const void* dataPtr)
+  void ConcatColumn::putArrayColumn (const ArrayBase& arr)
   {
-    accessColumn (0, const_cast<void*>(dataPtr), &putColumnPart);
+    accessColumn (0, const_cast<ArrayBase&>(arr), &putColumnPart);
   }
 
   void ConcatColumn::putColumnSlice (const Slicer& ns,
-				     const void* dataPtr)
+				     const ArrayBase& arr)
   {
-    accessColumn (&ns, const_cast<void*>(dataPtr), &putColumnSlicePart);
+    accessColumn (&ns, const_cast<ArrayBase&>(arr), &putColumnSlicePart);
   }
 
   void ConcatColumn::putArrayColumnCells (const RefRows& rownrs,
-					  const void* dataPtr)
+					  const ArrayBase& arr)
   {
-    accessRows (rownrs, 0, const_cast<void*>(dataPtr), &putRowsPart);
+    accessRows (rownrs, 0, const_cast<ArrayBase&>(arr), &putRowsPart);
   }
 
   void ConcatColumn::putColumnSliceCells (const RefRows& rownrs,
 					  const Slicer& ns,
-					  const void* dataPtr)
+					  const ArrayBase& arr)
   {
-    accessRows (rownrs, &ns, const_cast<void*>(dataPtr), &putRowsSlicePart);
+    accessRows (rownrs, &ns, const_cast<ArrayBase&>(arr), &putRowsSlicePart);
   }
 
   void ConcatColumn::accessColumn (const Slicer* ns,
-				   void* dataPtr,
+				   ArrayBase& arr,
 				   AccessColumnFunc* accessFunc) const
   {
-    ArrayBase& arr = *static_cast<ArrayBase*>(dataPtr);
     IPosition st(arr.ndim(), 0);
     IPosition sz(arr.shape());
     uInt nlast = arr.ndim() - 1;
-    CountedPtr<ArrayBase> part;
     for (uInt i=0; i<refColPtr_p.nelements(); ++i) {
-      uInt nr = refColPtr_p[i]->nrow();
+      rownr_t nr = refColPtr_p[i]->nrow();
       sz[nlast] = nr;
-      // Store in CountedPtr, so deleted in case of exception.
-      part = arr.getSection (Slicer(st, sz));
-      accessFunc (refColPtr_p[i], ns, part.operator->());
+      std::unique_ptr<ArrayBase> part (arr.getSection (Slicer(st, sz)));
+      accessFunc (refColPtr_p[i], ns, *part);
       st[nlast] += nr;
     }
   }
 
   void ConcatColumn::accessRows (const RefRows& rownrs,
 				 const Slicer* ns,
-				 void* dataPtr,
+				 ArrayBase& arr,
 				 AccessRowsFunc* accessFunc) const
   {
-    ArrayBase& arr = *static_cast<ArrayBase*>(dataPtr);
     // The rows to access.
-    Vector<uInt> rows = rownrs.convert();
+    Vector<rownr_t> rows = rownrs.convert();
     // We have one or more slices of rows.
     // Try to access them also in a sliced way, because that is faster.
     // First make resources.
     // The row number mapping.
     const ConcatRows& ccRows = refTabPtr_p->rows();
-    // The holder for the array part to handle.
-    CountedPtr<ArrayBase> part;
     // The RefRows vector for the rownrs to be handled in an underlying table.
     // Make it as large as needed to avoid resizes.
-    Vector<uInt> tabRowNrs(rows.nelements());
+    Vector<rownr_t> tabRowNrs(rows.nelements());
     // The rows are handled by combining them as much as possible in a RefRows
     // slice. This is possible until a different underlying table needs to
     // be accessed.
@@ -309,71 +305,69 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     Int lastTabNr = -1;
     uInt tableNr;
     // Step through all concat rownrs.
-    for (uInt i=0; i<rows.nelements(); ++i) {
+    for (rownr_t i=0; i<rows.nelements(); ++i) {
       // Map to the table and rownr in it.
       ccRows.mapRownr (tableNr, tabRowNrs[i], rows[i]);
       // An access has to be done if we have another table.
       if (Int(tableNr) != lastTabNr) {
 	// Access the cells if not the first time.
 	if (lastTabNr >= 0) {
-	  uInt nrrow = i - st[rowAxis];
+	  rownr_t nrrow = i - st[rowAxis];
 	  sz[rowAxis] = nrrow;
-	  Vector<uInt> rowPart(tabRowNrs(Slice(st[rowAxis], nrrow))); 
-	  part = arr.getSection (Slicer(st, sz));
-	  accessFunc (refColPtr_p[lastTabNr], RefRows(rowPart), ns,
-		      part.operator->());
+	  Vector<rownr_t> rowPart(tabRowNrs(Slice(st[rowAxis], nrrow))); 
+	  std::unique_ptr<ArrayBase> part (arr.getSection (Slicer(st, sz)));
+	  accessFunc (refColPtr_p[lastTabNr], RefRows(rowPart), ns, *part);
 	}
         st[rowAxis] = i;
         lastTabNr = tableNr;
       }
     }
     if (lastTabNr >= 0) {
-      uInt nrrow = rows.nelements() - st[rowAxis];
+      rownr_t nrrow = rows.nelements() - st[rowAxis];
       sz[rowAxis] = nrrow;
-      Vector<uInt> rowPart(tabRowNrs(Slice(st[rowAxis], nrrow))); 
-      part = arr.getSection (Slicer(st, sz));
-      accessFunc (refColPtr_p[lastTabNr], RefRows(rowPart), ns,
-		  part.operator->());
+      Vector<rownr_t> rowPart(tabRowNrs(Slice(st[rowAxis], nrrow))); 
+      CountedPtr<ArrayBase> part (arr.getSection (Slicer(st, sz)));
+      accessFunc (refColPtr_p[lastTabNr], RefRows(rowPart), ns, *part);
     }
   }
 
   void ConcatColumn::getColumnPart (BaseColumn* col,
-				    const Slicer*, ArrayBase* arr)
+				    const Slicer*, ArrayBase& arr)
   {
     col->getArrayColumn (arr);
   }
   void ConcatColumn::putColumnPart (BaseColumn* col,
-				    const Slicer*, ArrayBase* arr)
+				    const Slicer*, ArrayBase& arr)
   {
     col->putArrayColumn (arr);
   }
   void ConcatColumn::getColumnSlicePart (BaseColumn* col,
-					 const Slicer* ns, ArrayBase* arr)
+					 const Slicer* ns, ArrayBase& arr)
   {
     col->getColumnSlice (*ns, arr);
   }
   void ConcatColumn::putColumnSlicePart (BaseColumn* col,
-					 const Slicer* ns, ArrayBase* arr)
+					 const Slicer* ns, ArrayBase& arr)
   {
     col->putColumnSlice (*ns, arr);
   }
   void ConcatColumn::getRowsPart (BaseColumn* col, const RefRows& rows,
-				  const Slicer*, ArrayBase* arr)
+				  const Slicer*, ArrayBase& arr)
   {
     col->getArrayColumnCells (rows, arr);
   }
   void ConcatColumn::putRowsPart (BaseColumn* col, const RefRows& rows,
-				  const Slicer*, ArrayBase* arr)
+				  const Slicer*, ArrayBase& arr)
   {
     col->putArrayColumnCells (rows, arr);
   }
   void ConcatColumn::getRowsSlicePart (BaseColumn* col, const RefRows& rows,
-				       const Slicer* ns, ArrayBase* arr)
+				       const Slicer* ns, ArrayBase& arr)
   {
     col->getColumnSliceCells (rows, *ns, arr);
   }
   void ConcatColumn::putRowsSlicePart (BaseColumn* col, const RefRows& rows,
-				       const Slicer* ns, ArrayBase* arr)
+				       const Slicer* ns, ArrayBase& arr)
   {
     col->putColumnSliceCells (rows, *ns, arr);
   }
