@@ -33,7 +33,9 @@
 #include <casacore/casa/aips.h>
 #include <casacore/tables/Tables/BaseTable.h>
 #include <casacore/tables/Tables/TableLock.h>
+#include <casacore/tables/Tables/RowNumbers.h>
 #include <casacore/tables/DataMan/TSMOption.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 #include <casacore/casa/Utilities/DataType.h>
 #include <casacore/casa/Utilities/Sort.h>
 
@@ -52,7 +54,6 @@ class Record;
 class TableExprNode;
 class DataManager;
 class IPosition;
-template<class T> class Vector;
 template<class T> class Block;
 template<class T> class CountedPtr;
 
@@ -129,8 +130,8 @@ template<class T> class CountedPtr;
 // Table myTable ("theTable", Table::Update);
 // // Write the column containing the scalar RA.
 // ScalarColumn<double> raColumn(myTable, "RA");
-// uInt nrrow = myTable.nrow();
-// for (uInt i=0; i<nrrow; i++) {
+// rownr_t nrrow = myTable.nrow();
+// for (rownr_t i=0; i<nrrow; i++) {
 //    raColumn.put (i, i+10);    // Put value i+10 into row i
 // }
 // </srcblock>
@@ -274,38 +275,39 @@ public:
     // inspection interval of 5 seconds.
     // <br>The data will be stored in the given endian format.
     // <group>
-    explicit Table (SetupNewTable&, uInt nrrow = 0, Bool initialize = False,
+    explicit Table (SetupNewTable&, rownr_t nrrow = 0, Bool initialize = False,
 		    EndianFormat = Table::AipsrcEndian,
                     const TSMOption& = TSMOption());
     Table (SetupNewTable&, TableType,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
     Table (SetupNewTable&, TableType, const TableLock& lockOptions,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
     Table (SetupNewTable&, TableLock::LockOption,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
     Table (SetupNewTable&, const TableLock& lockOptions,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
 #ifdef HAVE_MPI
     explicit Table (MPI_Comm mpiComm, TableType, EndianFormat = Table::AipsrcEndian,
                     const TSMOption& = TSMOption());
-    explicit Table (MPI_Comm mpiComm, SetupNewTable&, uInt nrrow = 0, Bool initialize = False,
+    explicit Table (MPI_Comm mpiComm, SetupNewTable&, rownr_t nrrow = 0,
+                    Bool initialize = False,
 		    EndianFormat = Table::AipsrcEndian,
                     const TSMOption& = TSMOption());
     Table (MPI_Comm mpiComm, SetupNewTable&, TableType,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
     Table (MPI_Comm mpiComm, SetupNewTable&, TableType, const TableLock& lockOptions,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
     Table (MPI_Comm mpiComm, SetupNewTable&, TableLock::LockOption,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
     Table (MPI_Comm mpiComm, SetupNewTable&, const TableLock& lockOptions,
-	   uInt nrrow = 0, Bool initialize = False,
+	   rownr_t nrrow = 0, Bool initialize = False,
 	   EndianFormat = Table::AipsrcEndian, const TSMOption& = TSMOption());
 #endif
     // </group>
@@ -553,7 +555,7 @@ public:
     // <br> The number of rows is returned. The description of the table
     // is stored in desc (its contents will be overwritten).
     // <br> An exception is thrown if the table does not exist.
-    static uInt getLayout (TableDesc& desc, const String& tableName);
+    static rownr_t getLayout (TableDesc& desc, const String& tableName);
 
     // Get the table info of the table with the given name.
     // An empty object is returned if the table is unknown.
@@ -755,7 +757,7 @@ public:
     // process updated the table, thus possible increased the number of rows.
     // If one wants to take that into account, he should acquire a
     // read-lock (using the lock function) before using nrow().
-    uInt nrow() const;
+    rownr_t nrow() const;
 
     // Test if it is possible to add a row to this table.
     // It is possible if all storage managers used for the table
@@ -766,7 +768,7 @@ public:
     // This will fail for tables not supporting addition of rows.
     // Optionally the rows can be initialized with the default
     // values as defined in the column descriptions.
-    void addRow (uInt nrrow = 1, Bool initialize = False);
+    void addRow (rownr_t nrrow = 1, Bool initialize = False);
 
     // Test if it is possible to remove a row from this table.
     // It is possible if all storage managers used for the table
@@ -782,7 +784,7 @@ public:
     // <srcblock>
     //    tab.removeRow (10);      // remove row 10
     //    tab.removeRow (20);      // remove row 20, which was 21
-    //    Vector<uInt> vec(2);
+    //    Vector<rownr_t> vec(2);
     //    vec(0) = 10;
     //    vec(1) = 20;
     //    tab.removeRow (vec);     // remove row 10 and 20
@@ -791,8 +793,8 @@ public:
     // row 21 into row 20.
     // </note>
     // <group>
-    void removeRow (uInt rownr);
-    void removeRow (const Vector<uInt>& rownrs);
+    void removeRow (rownr_t rownr);
+    void removeRow (const RowNumbers& rownrs);
     // </group>
 
     // Create a TableExprNode object for a column or for a keyword
@@ -817,7 +819,7 @@ public:
     // 'origin' Indicates which rownumber is the first.
     // C++ uses origin = 0 (default)
     // Glish and TaQL both use origin = 1
-    TableExprNode nodeRownr (uInt origin=0) const;
+    TableExprNode nodeRownr (rownr_t origin=0) const;
 
     // Create a TableExprNode object for the rand function.
     TableExprNode nodeRandom () const;
@@ -843,7 +845,7 @@ public:
     // when <src>maxRow</src> rows are selected.
     // <br>The TableExprNode argument can be empty (null) meaning that only
     // the <src>maxRow/offset</src> arguments are taken into account.
-    Table operator() (const TableExprNode&, uInt maxRow=0, uInt offset=0) const;
+    Table operator() (const TableExprNode&, rownr_t maxRow=0, rownr_t offset=0) const;
 
     // Select rows using a vector of row numbers.
     // This can, for instance, be used to select the same rows as
@@ -851,7 +853,7 @@ public:
     // <srcblock>
     //     Table result = thisTable (otherTable.rowNumbers());
     // </srcblock>
-    Table operator() (const Vector<uInt>& rownrs) const;
+    Table operator() (const RowNumbers& rownrs) const;
 
     // Select rows using a mask block.
     // The length of the block must match the number of rows in the table.
@@ -923,7 +925,7 @@ public:
     // containing the row numbers 0 .. #rows-1.
     // <br>Note that in general it is better to use the next
     // <src>rowNumbers(Table)</src> function.
-    Vector<uInt> rowNumbers() const;
+    RowNumbers rowNumbers() const;
 
     // Get a vector of row numbers in that table of rows in this table.
     // In case the table is a subset of that table, this tells which
@@ -946,15 +948,15 @@ public:
     // <srcblock>
     // Table tab("somename");
     // Table subset = tab(some_select_expression);
-    // Vector<uInt> rownrs = subset.rowNumbers(tab);
+    // RowNumbers rownrs = subset.rowNumbers(tab);
     // </srcblock>
     // Note that one cannot be sure that table "somename" is the root
     // (i.e. original) table. It may also be a subset of another table.
     // In the latter case doing
-    // <br> <src>    Vector<uInt> rownrs = subset.rowNumbers()</src>
+    // <br> <src>    RowNumbers rownrs = subset.rowNumbers()</src>
     // does not give the row numbers in <src>tab</src>, but in the root table
     // (which is probably not what you want).
-  Vector<uInt> rowNumbers (const Table& that, Bool tryFast=False) const;
+    RowNumbers rowNumbers (const Table& that, Bool tryFast=False) const;
 
     // Add a column to the table.
     // The data manager used for the column depend on the function used.
@@ -1112,8 +1114,8 @@ private:
 
     // Try if v1 is a subset of v2 and fill rows with its indices in v2.
     // Return False if not a proper subset.
-    Bool fastRowNumbers (const Vector<uInt>& v1, const Vector<uInt>& v2,
-                         Vector<uInt>& rows) const;
+    Bool fastRowNumbers (const Vector<rownr_t>& v1, const Vector<rownr_t>& v2,
+                         Vector<rownr_t>& rows) const;
 
     // Show the info of the given columns.
     // Sort the columns if needed.
@@ -1198,7 +1200,7 @@ inline void Table::unmarkForDelete()
 inline Bool Table::isMarkedForDelete() const
     { return baseTabPtr_p->isMarkedForDelete(); }
 
-inline uInt Table::nrow() const
+inline rownr_t Table::nrow() const
     { return baseTabPtr_p->nrow(); }
 inline BaseTable* Table::baseTablePtr() const
     { return baseTabPtr_p; }
@@ -1232,11 +1234,11 @@ inline Bool Table::canRemoveColumn (const Vector<String>& columnNames) const
 inline Bool Table::canRenameColumn (const String& columnName) const
     { return baseTabPtr_p->canRenameColumn (columnName); }
 
-inline void Table::addRow (uInt nrrow, Bool initialize)
+inline void Table::addRow (rownr_t nrrow, Bool initialize)
     { baseTabPtr_p->addRow (nrrow, initialize); }
-inline void Table::removeRow (uInt rownr)
+inline void Table::removeRow (rownr_t rownr)
     { baseTabPtr_p->removeRow (rownr); }
-inline void Table::removeRow (const Vector<uInt>& rownrs)
+inline void Table::removeRow (const RowNumbers& rownrs)
     { baseTabPtr_p->removeRow (rownrs); }
 inline void Table::addColumn (const ColumnDesc& columnDesc, Bool addToParent)
     { baseTabPtr_p->addColumn (columnDesc, addToParent); }
