@@ -34,6 +34,8 @@
 #include <casacore/tables/Tables/ColDescSet.h>
 #include <casacore/casa/IO/AipsIO.h>
 #include <casacore/casa/iosfwd.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
+
 #include <map>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
@@ -42,7 +44,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 class TableRecord;
 class TableAttr;
 class TabPath;
-template<class T> class Vector;
 
 // <summary>
 // Define the structure of a Casacore table
