@@ -57,7 +57,7 @@
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/ArrayUtil.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/Slice.h>
 #include <casacore/casa/Arrays/Slicer.h>
 #include <casacore/casa/Logging/LogIO.h>
@@ -83,7 +83,7 @@ TableProxy::TableProxy (const String& tableName,
 			const Record& lockOptions,
 			const String& endianFormat,
 			const String& memType,
-			Int nrow,
+			Int64 nrow,
 			const Record& tableDesc,
 			const Record& dmInfo)
 {
@@ -173,8 +173,8 @@ TableProxy::TableProxy (const String& fileName,
 			const IPosition& autoShape,
 			const String& separator,
 			const String& commentMarker,
-			Int firstLine,
-			Int lastLine,
+			Int64 firstLine,
+			Int64 lastLine,
 			const Vector<String>& columnNames,
 			const Vector<String>& dataTypes)
 {
@@ -365,7 +365,7 @@ String TableProxy::toAscii (const String& asciiFile,
     ofs2.close();
   }
   // Write the data
-  for (Int i=0; i<nrows(); i++) {
+  for (Int64 i=0; i<nrows(); i++) {
     for (Int j=0; j<ncols; j++) {
       Int prec = (j < Int(precision.size())  ?  precision[j] : 0);
       if (col_is_good[j]) {
@@ -692,9 +692,9 @@ TableProxy TableProxy::copy (const String& newTableName,
 }
 
 void TableProxy::copyRows (TableProxy& out,
-			   Int startIn,
-			   Int startOut,
-			   Int nrow)
+			   Int64 startIn,
+			   Int64 startOut,
+			   Int64 nrow)
 {
   Table tableOut = out.table();
   if (startOut < 0) {
@@ -702,7 +702,7 @@ void TableProxy::copyRows (TableProxy& out,
   }
   nrow = checkRowColumn (table_p, "", startIn, nrow, 1,
 			 "TableProxy::copyRows");
-  if (startOut > Int(tableOut.nrow())) {
+  if (startOut > Int64(tableOut.nrow())) {
     throw TableError ("TableProxy::copyRows: start output row too high");
   }
   TableCopy::copyRows (tableOut, table_p, startOut, startIn, nrow);
@@ -724,18 +724,18 @@ void TableProxy::deleteTable (Bool checkSubTables)
   table_p.markForDelete();
 }
 
-TableProxy TableProxy::selectRows (const Vector<Int>& rownrs,
+TableProxy TableProxy::selectRows (const Vector<Int64>& rownrs,
 				   const String& outName)
 {
   // If needed, synchronize table to get up-to-date number of rows.
   syncTable (table_p);
-  if (anyLT (rownrs, 0) || anyGE (rownrs, Int(table_p.nrow()))) {
+  if (anyLT (rownrs, Int64(0))  ||  anyGE (rownrs, Int64(table_p.nrow()))) {
     throw TableError("rownumbers should be >= 1 and <= nrow");
   }
   table_p.unlock();
   // Create a table from the selected rows.
   // Rename it and make it non-scratch if a name is given.
-  Vector<uInt> rows(rownrs.nelements());
+  Vector<rownr_t> rows(rownrs.nelements());
   convertArray (rows, rownrs);
   Table ntable = table_p(rows);
   if (! outName.empty()) {
@@ -759,7 +759,7 @@ void TableProxy::stillSameShape (Int& same, IPosition& shape,
 void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
 {
   if (expr.isScalar()) {
-    Vector<uInt> rownrs(expr.nrow());
+    Vector<rownr_t> rownrs(expr.nrow());
     indgen (rownrs);
     switch (expr.getColumnDataType()) {
     case TpBool:
@@ -785,7 +785,7 @@ void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
     case TpUInt:
     {
       Vector<uInt> vs = expr.getColumnuInt (rownrs);
-      Vector<Int> vi(vs.nelements());
+      Vector<Int64> vi(vs.nelements());
       convertArray (vi, vs);
       rec.define ("values", vi);
       break;
@@ -818,7 +818,7 @@ void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
     Record res;
     switch (expr.dataType()) {
     case TpBool:
-      for (uInt i=0; i<expr.nrow(); i++) {
+      for (rownr_t i=0; i<expr.nrow(); i++) {
 	MArray<Bool> arr;
 	expr.get (i, arr);
 	res.define (String::toString(i), arr.array());
@@ -826,7 +826,7 @@ void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
       }
       break;
     case TpInt64:
-      for (uInt i=0; i<expr.nrow(); i++) {
+      for (rownr_t i=0; i<expr.nrow(); i++) {
 	MArray<Int64> arr;
 	expr.get (i, arr);
 	res.define (String::toString(i), arr.array());
@@ -834,7 +834,7 @@ void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
       }
       break;
     case TpDouble:
-      for (uInt i=0; i<expr.nrow(); i++) {
+      for (rownr_t i=0; i<expr.nrow(); i++) {
 	MArray<Double> arr;
 	expr.get (i, arr);
 	res.define (String::toString(i), arr.array());
@@ -842,7 +842,7 @@ void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
       }
       break;
     case TpDComplex:
-      for (uInt i=0; i<expr.nrow(); i++) {
+      for (rownr_t i=0; i<expr.nrow(); i++) {
 	MArray<DComplex> arr;
 	expr.get (i, arr);
 	res.define (String::toString(i), arr.array());
@@ -850,7 +850,7 @@ void TableProxy::calcValues (Record& rec, const TableExprNode& expr)
       }
       break;
     case TpString:
-      for (uInt i=0; i<expr.nrow(); i++) {
+      for (rownr_t i=0; i<expr.nrow(); i++) {
 	MArray<String> arr;
 	expr.get (i, arr);
 	res.define (String::toString(i), arr.array());
@@ -970,7 +970,8 @@ String TableProxy::tableName()
 
 Vector<String> TableProxy::getPartNames (Bool recursive)
 {
-  return Vector<String>(table_p.getPartNames (recursive));
+	Block<String> partNames(table_p.getPartNames (recursive));
+  return Vector<String>(partNames.begin(), partNames.end());
 }
 
 String TableProxy::getAsciiFormat() const
@@ -992,7 +993,7 @@ String TableProxy::showStructure (Bool showDataMan, Bool showColumns,
   return ostr.str();
 }
 
-Int TableProxy::nrows()
+Int64 TableProxy::nrows()
 {
   // If needed synchronize table to get up-to-date number of rows.
   syncTable (table_p);
@@ -1004,22 +1005,22 @@ Int TableProxy::ncolumns()
   return table_p.tableDesc().ncolumn();
 }
 
-Vector<Int> TableProxy::shape()
+Vector<Int64> TableProxy::shape()
 {
   // If needed synchronize table to get up-to-date number of rows.
   syncTable (table_p);
-  Vector<Int> result(2);
+  Vector<Int64> result(2);
   result(0) = table_p.tableDesc().ncolumn();
   result(1) = table_p.nrow();
   return result;
 }
 
-Vector<Int> TableProxy::rowNumbers (TableProxy& other)
+Vector<Int64> TableProxy::rowNumbers (TableProxy& other)
 {
   // If needed synchronize table to get up-to-date number of rows.
   syncTable (table_p);
   table_p.unlock();
-  Vector<Int> result(table_p.nrow());
+  Vector<Int64> result(table_p.nrow());
   if (other.table().isNull()) {
     convertArray (result, table_p.rowNumbers());
   } else {
@@ -1083,21 +1084,21 @@ String TableProxy::columnArrayType (const String& columnName)
 }
 
 ValueHolder TableProxy::getCell (const String& columnName,
-				 Int row)
+				 Int64 row)
 {
   Int64 nrow = getRowsCheck (columnName, row, 1, 1, "getCell");
   return getValueFromTable (columnName, row, nrow, 1, True);
 }
 
 void TableProxy::getCellVH (const String& columnName,
-                            Int row, const ValueHolder& vh)
+                            Int64 row, const ValueHolder& vh)
 {
   Int64 nrow = getRowsCheck (columnName, row, 1, 1, "getCellVH");
   getValueFromTable (columnName, row, nrow, 1, True, vh);
 }
 
 ValueHolder TableProxy::getCellSlice (const String& columnName,
-				      Int row,
+				      Int64 row,
 				      const Vector<Int>& blc,
 				      const Vector<Int>& trc,
 				      const Vector<Int>& inc)
@@ -1106,7 +1107,7 @@ ValueHolder TableProxy::getCellSlice (const String& columnName,
 }
 
 void TableProxy::getCellSliceVH (const String& columnName,
-                                 Int row,
+                                 Int64 row,
                                  const Vector<Int>& blc,
                                  const Vector<Int>& trc,
                                  const Vector<Int>& inc,
@@ -1116,7 +1117,7 @@ void TableProxy::getCellSliceVH (const String& columnName,
 }
 
 ValueHolder TableProxy::getCellSliceIP (const String& columnName,
-                                        Int row,
+                                        Int64 row,
                                         const IPosition& blc,
                                         const IPosition& trc,
                                         const IPosition& inc)
@@ -1128,7 +1129,7 @@ ValueHolder TableProxy::getCellSliceIP (const String& columnName,
 }
 
 void TableProxy::getCellSliceVHIP (const String& columnName,
-                                   Int row,
+                                   Int64 row,
                                    const IPosition& blc,
                                    const IPosition& trc,
                                    const IPosition& inc,
@@ -1141,18 +1142,18 @@ void TableProxy::getCellSliceVHIP (const String& columnName,
 }
 
 ValueHolder TableProxy::getColumn (const String& columnName,
-				   Int row,
-				   Int nrow,
-				   Int incr)
+				   Int64 row,
+				   Int64 nrow,
+				   Int64 incr)
 {
   Int64 nrows = getRowsCheck (columnName, row, nrow, incr, "getColumn");
   return getValueFromTable (columnName, row, nrows, incr, False);
 }
 
 void TableProxy::getColumnVH (const String& columnName,
-                              Int row,
-                              Int nrow,
-                              Int incr,
+                              Int64 row,
+                              Int64 nrow,
+                              Int64 incr,
                               const ValueHolder& vh)
 {
   Int64 nrows = getRowsCheck (columnName, row, nrow, incr, "getColumnVH");
@@ -1160,9 +1161,9 @@ void TableProxy::getColumnVH (const String& columnName,
 }
 
 Record TableProxy::getVarColumn (const String& columnName,
-				 Int row,
-				 Int nrow,
-				 Int incr)
+				 Int64 row,
+				 Int64 nrow,
+				 Int64 incr)
 {
   Int64 nrows = getRowsCheck (columnName, row, nrow, incr, "getVarColumn");
   TableColumn tabcol (table_p, columnName);
@@ -1170,7 +1171,7 @@ Record TableProxy::getVarColumn (const String& columnName,
   char namebuf[16];
   for (Int64 i=0; i<nrows; i++) {
     // Add the result to the record with field name formed from 1-based rownr.
-    sprintf (namebuf, "r%i", row+1);
+    sprintf (namebuf, "r%lli", row+1);
     if (tabcol.isDefined(row)) {
       getValueFromTable(columnName, row, 1, 1, False).toRecord (rec, namebuf);
     } else {
@@ -1183,9 +1184,9 @@ Record TableProxy::getVarColumn (const String& columnName,
 }
 
 ValueHolder TableProxy::getColumnSlice (const String& columnName,
-					Int row,
-					Int nrow,
-					Int incr,
+					Int64 row,
+					Int64 nrow,
+					Int64 incr,
 					const Vector<Int>& blc,
 					const Vector<Int>& trc,
 					const Vector<Int>& inc)
@@ -1197,9 +1198,9 @@ ValueHolder TableProxy::getColumnSliceIP (const String& columnName,
 					  const IPosition& blc,
 					  const IPosition& trc,
 					  const IPosition& inc,
-					  Int row,
-					  Int nrow,
-					  Int incr)
+					  Int64 row,
+					  Int64 nrow,
+					  Int64 incr)
 {
   Slicer slicer;
   Int64 nrows = getRowsSliceCheck (slicer, columnName, row, nrow, incr,
@@ -1208,9 +1209,9 @@ ValueHolder TableProxy::getColumnSliceIP (const String& columnName,
 }
 
 void TableProxy::getColumnSliceVH (const String& columnName,
-                                   Int row,
-                                   Int nrow,
-                                   Int incr,
+                                   Int64 row,
+                                   Int64 nrow,
+                                   Int64 incr,
                                    const Vector<Int>& blc,
                                    const Vector<Int>& trc,
                                    const Vector<Int>& inc,
@@ -1223,9 +1224,9 @@ void TableProxy::getColumnSliceVHIP (const String& columnName,
                                      const IPosition& blc,
                                      const IPosition& trc,
                                      const IPosition& inc,
-                                     Int row,
-                                     Int nrow,
-                                     Int incr,
+                                     Int64 row,
+                                     Int64 nrow,
+                                     Int64 incr,
                                      const ValueHolder& vh)
 {
   Slicer slicer;
@@ -1235,9 +1236,9 @@ void TableProxy::getColumnSliceVHIP (const String& columnName,
 }
 
 void TableProxy::putColumn (const String& columnName,
-			    Int row,
-			    Int nrow,
-			    Int incr,
+			    Int64 row,
+			    Int64 nrow,
+			    Int64 incr,
 			    const ValueHolder& value)
 {
   // Synchronize table to get up-to-date #rows.
@@ -1249,9 +1250,9 @@ void TableProxy::putColumn (const String& columnName,
 }
 
 void TableProxy::putVarColumn (const String& columnName,
-			       Int row,
-			       Int nrow,
-			       Int incr,
+			       Int64 row,
+			       Int64 nrow,
+			       Int64 incr,
 			       const Record& values)
 {
   // Synchronize table to get up-to-date #rows.
@@ -1263,7 +1264,7 @@ void TableProxy::putVarColumn (const String& columnName,
     throw TableError("TableProxy::putVarColumn: "
 		     "#rows mismatches #elem in value");
   }
-  for (Int i=0; i<nrow; i++) {
+  for (Int64 i=0; i<nrow; i++) {
     putValueInTable (columnName, row, 1, 1, False,
 		     ValueHolder::fromRecord(values, i));
     row += incr;
@@ -1271,9 +1272,9 @@ void TableProxy::putVarColumn (const String& columnName,
 }
 
 void TableProxy::putColumnSlice (const String& columnName,
-				 Int row,
-				 Int nrow,
-				 Int incr,
+				 Int64 row,
+				 Int64 nrow,
+				 Int64 incr,
 				 const Vector<Int>& blc,
 				 const Vector<Int>& trc,
 				 const Vector<Int>& inc,
@@ -1287,9 +1288,9 @@ void TableProxy::putColumnSliceIP (const String& columnName,
 				   const IPosition& blc,
 				   const IPosition& trc,
 				   const IPosition& inc,
-				   Int row,
-				   Int nrow,
-				   Int incr)
+				   Int64 row,
+				   Int64 nrow,
+				   Int64 incr)
 {
   IPosition cblc, ctrc;
   cblc = blc;
@@ -1311,22 +1312,22 @@ void TableProxy::putColumnSliceIP (const String& columnName,
 }
 
 void TableProxy::putCell (const String& columnName,
-			  const Vector<Int>& rownrs,
+			  const Vector<Int64>& rownrs,
 			  const ValueHolder& value)
 {
   // Synchronize table to get up-to-date #rows.
   syncTable (table_p);
-  for (uInt i=0; i<rownrs.nelements(); i++) {
+  for (rownr_t i=0; i<rownrs.nelements(); i++) {
     // Check that the row number is within the table bounds.
-    Int row = rownrs(i);
-    Int nrow = checkRowColumn (table_p, columnName, row, 1, 1,
+    Int64 row = rownrs(i);
+    Int64 nrow = checkRowColumn (table_p, columnName, row, 1, 1,
 			       "TableProxy::putColumn");
     putValueInTable (columnName, row, nrow, 1, True, value);
   }
 }
 
 void TableProxy::putCellSlice (const String& columnName,
-			       Int row,
+			       Int64 row,
 			       const Vector<Int>& blc,
 			       const Vector<Int>& trc,
 			       const Vector<Int>& inc,
@@ -1336,7 +1337,7 @@ void TableProxy::putCellSlice (const String& columnName,
 }
 
 void TableProxy::putCellSliceIP (const String& columnName,
-				 Int row,
+				 Int64 row,
 				 const ValueHolder& value,
 				 const IPosition& blc,
 				 const IPosition& trc,
@@ -1356,22 +1357,22 @@ void TableProxy::putCellSliceIP (const String& columnName,
   // Synchronize table to get up-to-date #rows.
   // Check that the row number is within the table bounds.
   syncTable (table_p);
-  Int nrow = checkRowColumn (table_p, columnName, row, 1, 1,
+  Int64 nrow = checkRowColumn (table_p, columnName, row, 1, 1,
 			     "TableProxy::putColumn");
   putValueSliceInTable (columnName, slicer, row, nrow, 1, True, value);
 }
 
 Vector<String> TableProxy::getColumnShapeString (const String& columnName,
-						 Int rownr,
-						 Int nrow,
-						 Int incr,
+						 Int64 rownr,
+						 Int64 nrow,
+						 Int64 incr,
 						 Bool cOrder)
 {
   // If needed synchronize table to get up-to-date number of rows.
   syncTable (table_p);
   // Check that the row number is within the table bounds.
   // However, accept a row number equal to nrow when no rows are needed.
-  Int tabnrow = table_p.nrow();
+  Int64 tabnrow = table_p.nrow();
   if (rownr < 0  ||  rownr > tabnrow  ||  (rownr==tabnrow && nrow>0)) {
     throw TableError("TableProxy::getColumnShapeString: no such row");
   }
@@ -1382,7 +1383,7 @@ Vector<String> TableProxy::getColumnShapeString (const String& columnName,
     throw TableError("TableProxy::getColumnShapeString: column " +
 		     columnName + " does not exist");
   }
-  Int maxnrow = (tabnrow - rownr + incr - 1) / incr;
+  Int64 maxnrow = (tabnrow - rownr + incr - 1) / incr;
   if (nrow < 0  ||  nrow > maxnrow) {
     nrow = maxnrow;
   }
@@ -1397,8 +1398,8 @@ Vector<String> TableProxy::getColumnShapeString (const String& columnName,
     result(0) = os.str();
   } else {
     result.resize (nrow);
-    Int lastRow(nrow+rownr);
-    for (Int i=0; i<nrow && rownr<lastRow; i++) {
+    Int64 lastRow(nrow+rownr);
+    for (Int64 i=0; i<nrow && rownr<lastRow; i++) {
       ostringstream os;
       os << fillAxes (col.shape (rownr), cOrder);
       result(i) = os.str();
@@ -1410,7 +1411,7 @@ Vector<String> TableProxy::getColumnShapeString (const String& columnName,
 }
 
 Bool TableProxy::cellContentsDefined (const String& columnName,
-				      Int rownr)
+				      Int64 rownr)
 {
   TableColumn tabColumn (table_p, columnName);
   return tabColumn.isDefined (rownr);
@@ -1649,16 +1650,16 @@ void TableProxy::removeColumns (const Vector<String>& columnNames)
   table_p.removeColumn (columnNames);
 }
 
-void TableProxy::addRow (Int nrow)
+void TableProxy::addRow (Int64 nrow)
 {
   table_p.addRow (nrow);
 }
 
-void TableProxy::removeRow (const Vector<Int>& rownrs)
+void TableProxy::removeRow (const Vector<Int64>& rownrs)
 {
   // If needed synchronize table to get up-to-date number of rows.
   syncTable (table_p);
-  Vector<uInt> rows(rownrs.nelements());
+  Vector<rownr_t> rows(rownrs.nelements());
   convertArray (rows, rownrs);
   table_p.removeRow (rows);
 }
@@ -1751,12 +1752,12 @@ Bool TableProxy::makeTableDesc (const Record& gdesc, TableDesc& tabdesc,
 
         Bool isArray = cold.isDefined("ndim");
         Int ndim;
-        Vector<Int> shape;
+        Vector<Int64> shape;
 
         if (isArray) {
             ndim = cold.asInt("ndim");
             if (cold.isDefined("shape")) {
-                shape = cold.toArrayInt ("shape");
+                shape = cold.toArrayInt64 ("shape");
             }
             Bool cOrder = False;
             if (cold.isDefined("_c_order")) {
@@ -1840,7 +1841,7 @@ Bool TableProxy::addArrayColumnDesc (TableDesc& tabdesc,
 				     const String& name, const String& comment,
 				     const String& dmtype, const String& dmgrp,
 				     int option,
-				     Int ndim, const Vector<Int>& shape,
+				     Int ndim, const Vector<Int64>& shape,
 				     Bool cOrder,
 				     String& message)
 {
@@ -1855,7 +1856,7 @@ Bool TableProxy::addArrayColumnDesc (TableDesc& tabdesc,
   }
   IPosition shp;
   if (shape.nelements() > 0) {
-    if (anyLE (shape, 0)) {
+    if (anyLE (shape, Int64(0))) {
       message = "arrayColumnDesc: shape < 0";
       return False;
     }
@@ -2014,7 +2015,7 @@ Record TableProxy::recordColumnDesc (const ColumnDesc& cold, Bool cOrder)
     cdesc.define ("ndim", Int(cold.ndim()));
     IPosition shape = fillAxes (cold.shape(), cOrder);
     if (shape.nelements() > 0) {
-      Vector<Int> vec(shape.nelements());
+      Vector<Int64> vec(shape.nelements());
       for (uInt i=0; i<shape.nelements(); i++) {
 	vec(i) = shape(i);
       }
@@ -2083,14 +2084,14 @@ Int64 TableProxy::getRowsSliceCheck (Slicer& slicer,
   return getRowsCheck (columnName, row, nrow, incr, caller);
 }
 
-Int TableProxy::checkRowColumn (Table& table,
+Int64 TableProxy::checkRowColumn (Table& table,
 				const String& colName,
 				Int64 rownr, Int64 nrow, Int64 incr,
 				const String& caller)
 {
   // Check that the row number is within the table bounds.
   // However, accept a row number equal to nrow when no rows are needed.
-  Int tabnrow = table.nrow();
+  Int64 tabnrow = table.nrow();
   if (rownr < 0  ||  rownr > tabnrow  ||  (rownr==tabnrow && nrow>0)) {
     throw TableError ("TableProxy::" + caller + ": no such row");
   } else if (incr <= 0) {
@@ -2101,7 +2102,7 @@ Int TableProxy::checkRowColumn (Table& table,
                         " does not exist");
     }
   }
-  Int maxnrow = (tabnrow - rownr + incr - 1) / incr;
+  Int64 maxnrow = (tabnrow - rownr + incr - 1) / incr;
   if (nrow < 0  ||  nrow > maxnrow) {
     nrow = maxnrow;
   }
@@ -2143,8 +2144,8 @@ ValueHolder TableProxy::makeEmptyArray (DataType dtype)
 }
 
 ValueHolder TableProxy::getValueFromTable (const String& colName,
-					   Int rownr, Int nrow,
-					   Int incr,
+					   Int64 rownr, Int64 nrow,
+					   Int64 incr,
 					   Bool isCell)
 {
   // Exit immediately if no rows have to be done.
@@ -2421,8 +2422,8 @@ ValueHolder TableProxy::getValueFromTable (const String& colName,
 }
 
 void TableProxy::getValueFromTable (const String& colName,
-                                    Int rownr, Int nrow,
-                                    Int incr,
+                                    Int64 rownr, Int64 nrow,
+                                    Int64 incr,
                                     Bool isCell,
                                     const ValueHolder& vh)
 {
@@ -2571,7 +2572,7 @@ void TableProxy::getValueFromTable (const String& colName,
 
 ValueHolder TableProxy::getValueSliceFromTable (const String& colName,
 						const Slicer& slicer,
-						Int rownr, Int nrow, Int incr,
+						Int64 rownr, Int64 nrow, Int64 incr,
 						Bool isCell)
 {
   // Check that the column is an array.
@@ -2724,7 +2725,7 @@ ValueHolder TableProxy::getValueSliceFromTable (const String& colName,
 
 void TableProxy::getValueSliceFromTable (const String& colName,
                                          const Slicer& slicer,
-                                         Int rownr, Int nrow, Int incr,
+                                         Int64 rownr, Int64 nrow, Int64 incr,
                                          Bool isCell,
                                          const ValueHolder& vh)
 {
@@ -2849,7 +2850,7 @@ void TableProxy::getValueSliceFromTable (const String& colName,
 
 
 void TableProxy::putValueInTable (const String& colName,
-				  Int rownr, Int nrow, Int incr,
+				  Int64 rownr, Int64 nrow, Int64 incr,
 				  Bool isCell, const ValueHolder& value)
 {
   // Exit immediately if no rows have to be done.
@@ -3151,7 +3152,7 @@ void TableProxy::putValueInTable (const String& colName,
 
 void TableProxy::putValueSliceInTable (const String& colName,
 				       const Slicer& slicer,
-				       Int rownr, Int nrow, Int incr,
+				       Int64 rownr, Int64 nrow, Int64 incr,
 				       Bool isCell, const ValueHolder& value)
 {
   // Exit immediately if no rows have to be done.
