@@ -31,7 +31,7 @@
 #include <casacore/tables/Tables/ScaColDesc.h>
 #include <casacore/tables/Tables/ScalarColumn.h>
 #include <casacore/tables/Tables/ColumnsIndex.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/ArrayUtil.h>
 #include <casacore/casa/Containers/Record.h>
 #include <casacore/casa/Containers/RecordField.h>
@@ -122,7 +122,7 @@ void b()
     RecordFieldPtr<DComplex> adcomplex (colInx8.accessKey(), "adcomplex");
     RecordFieldPtr<String> astring (colInx9.accessKey(), "astring");
     Record rec;
-    Vector<uInt> rows;
+    RowNumbers rows;
     Bool found;
     char str[8];
     // Test each individual type.
@@ -162,8 +162,8 @@ void b()
     *abool = True;
     try {
         colInx0.getRowNumber(found);
-    } catch (AipsError& x) {
-        cout << x.getMesg() << endl;       // values are not unique
+    } catch (std::exception& x) {
+        cout << x.what() << endl;       // values are not unique
     } 
     rows = colInx0.getRowNumbers();
     AlwaysAssertExit (rows.nelements() == (nrrow+1)/2);
@@ -194,7 +194,7 @@ void b()
 }
 
 Int tcompare (const Block<void*>& fieldPtrs, const Block<void*>& dataPtrs,
-	      const Block<Int>& dataTypes, Int index)
+	      const Block<Int>& dataTypes, rownr_t index)
 {
     AlwaysAssert (dataTypes.nelements() == 2, AipsError);
     AlwaysAssert (dataTypes[0] == TpDouble  &&  dataTypes[1] == TpFloat,
@@ -332,8 +332,8 @@ int main()
 	b();
 	c();
 	d();
-    } catch (AipsError& x) {
-        cout << "Exception caught: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+        cout << "Exception caught: " << x.what() << endl;
 	return 1;
     } 
     return 0;
