@@ -45,6 +45,7 @@
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/OS/Time.h>
 #include <casacore/casa/Exceptions/Error.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/iostream.h>
 #include <casacore/casa/sstream.h>
 #include <unistd.h>
@@ -343,8 +344,8 @@ int main (int argc, const char* argv[])
 	}else{
 	    c (lockMode, var[2], var[4], show);
 	}
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     return 0;                           // exit with success status
