@@ -107,14 +107,14 @@ void a (uInt nrrow)
 						     IPosition(1,nrrow-1)));
 	timer.show("range ISM");
 	for (i=0; i<nrrow-1; i++) {
-	    if (abv1(i) != i  ||  adv1(i) != Int(i/10)) {
-		cout << i << ',';
-	    }
+	    AlwaysAssertExit (abv1(i) == i);
+	    AlwaysAssertExit (adv1(i) == Int(i/10));
 	}
-	cout << endl;
     }
     {
-	Table rtab (tab(abv));
+        Vector<rownr_t> abvcp(abv.size());
+        convertArray (abvcp, abv);
+	Table rtab (tab(abvcp));
 	ScalarColumn<uInt> ab1(rtab,"ab");
 	ScalarColumn<Int> ad(rtab,"ad");
 	Timer timer;
@@ -137,11 +137,9 @@ void a (uInt nrrow)
 	    }	
 	    timer.show("b");
 	    for (i=0; i<nrrow; i++) {
-		if (abv(i) != i  ||  adv(i) != Int(i/10)) {
-		    cout << i << ',';
-		}
+                AlwaysAssertExit (abv(i) == i);
+                AlwaysAssertExit (adv(i) == Int(i/10));
 	    }
-	    cout << endl;
 	}
 	{
 	    // Get entire column (minus last cell) to test range performance.
@@ -154,11 +152,9 @@ void a (uInt nrrow)
 							 IPosition(1,nrrow-1)));
 	    timer.show("cells/range ISM");
 	    for (i=0; i<nrrow-1; i++) {
-		if (abv1(i) != i  ||  adv1(i) != Int(i/10)) {
-		    cout << i << ',';
-		}
+                AlwaysAssertExit (abv1(i) == i);
+                AlwaysAssertExit (adv1(i) == Int(i/10));
 	    }
-	    cout << endl;
 	}
     }
 }
@@ -172,8 +168,8 @@ int main (int argc, const char* argv[])
 	}
 	cout << nrrow << " rows" << endl;
 	a (nrrow);
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     return 0;                           // exit with success status
